/* wizard-toolbar.c generated by valac 0.25.2.7-aa52, the Vala compiler
 * generated from wizard-toolbar.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>


#define BOXES_TYPE_WIZARD_TOOLBAR (boxes_wizard_toolbar_get_type ())
#define BOXES_WIZARD_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_TOOLBAR, BoxesWizardToolbar))
#define BOXES_WIZARD_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_TOOLBAR, BoxesWizardToolbarClass))
#define BOXES_IS_WIZARD_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_TOOLBAR))
#define BOXES_IS_WIZARD_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_TOOLBAR))
#define BOXES_WIZARD_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_TOOLBAR, BoxesWizardToolbarClass))

typedef struct _BoxesWizardToolbar BoxesWizardToolbar;
typedef struct _BoxesWizardToolbarClass BoxesWizardToolbarClass;
typedef struct _BoxesWizardToolbarPrivate BoxesWizardToolbarPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

struct _BoxesWizardToolbar {
	GtkHeaderBar parent_instance;
	BoxesWizardToolbarPrivate * priv;
	GtkButton* cancel_btn;
	GtkButton* back_btn;
	GtkButton* continue_btn;
	GtkButton* create_btn;
};

struct _BoxesWizardToolbarClass {
	GtkHeaderBarClass parent_class;
};


static gpointer boxes_wizard_toolbar_parent_class = NULL;

GType boxes_wizard_toolbar_get_type (void) G_GNUC_CONST;
enum  {
	BOXES_WIZARD_TOOLBAR_DUMMY_PROPERTY
};
void boxes_wizard_toolbar_click_back_button (BoxesWizardToolbar* self);
void boxes_wizard_toolbar_click_forward_button (BoxesWizardToolbar* self);
BoxesWizardToolbar* boxes_wizard_toolbar_new (void);
BoxesWizardToolbar* boxes_wizard_toolbar_construct (GType object_type);
static void boxes_wizard_toolbar_finalize (GObject* obj);


void boxes_wizard_toolbar_click_back_button (BoxesWizardToolbar* self) {
	GtkButton* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	_tmp0_ = self->back_btn;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	_tmp1_ = gtk_widget_get_sensitive ((GtkWidget*) _tmp0_);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	_tmp2_ = _tmp1_;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	if (_tmp2_) {
#line 65 "wizard-toolbar.c"
		GtkButton* _tmp3_ = NULL;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
		_tmp3_ = self->back_btn;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
		gtk_button_clicked (_tmp3_);
#line 71 "wizard-toolbar.c"
	}
}


void boxes_wizard_toolbar_click_forward_button (BoxesWizardToolbar* self) {
	GtkButton* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	_tmp0_ = self->continue_btn;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	_tmp1_ = gtk_widget_get_sensitive ((GtkWidget*) _tmp0_);
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	_tmp2_ = _tmp1_;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	if (_tmp2_) {
#line 90 "wizard-toolbar.c"
		GtkButton* _tmp3_ = NULL;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
		_tmp3_ = self->continue_btn;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
		gtk_button_clicked (_tmp3_);
#line 96 "wizard-toolbar.c"
	}
}


BoxesWizardToolbar* boxes_wizard_toolbar_construct (GType object_type) {
	BoxesWizardToolbar * self = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	self = (BoxesWizardToolbar*) g_object_new (object_type, NULL);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	return self;
#line 107 "wizard-toolbar.c"
}


BoxesWizardToolbar* boxes_wizard_toolbar_new (void) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	return boxes_wizard_toolbar_construct (BOXES_TYPE_WIZARD_TOOLBAR);
#line 114 "wizard-toolbar.c"
}


static void boxes_wizard_toolbar_class_init (BoxesWizardToolbarClass * klass) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	boxes_wizard_toolbar_parent_class = g_type_class_peek_parent (klass);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_wizard_toolbar_finalize;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/wizard-toolbar.ui");
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "cancel_btn", FALSE, G_STRUCT_OFFSET (BoxesWizardToolbar, cancel_btn));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "back_btn", FALSE, G_STRUCT_OFFSET (BoxesWizardToolbar, back_btn));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "continue_btn", FALSE, G_STRUCT_OFFSET (BoxesWizardToolbar, continue_btn));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "create_btn", FALSE, G_STRUCT_OFFSET (BoxesWizardToolbar, create_btn));
#line 133 "wizard-toolbar.c"
}


static void boxes_wizard_toolbar_instance_init (BoxesWizardToolbar * self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 140 "wizard-toolbar.c"
}


static void boxes_wizard_toolbar_finalize (GObject* obj) {
	BoxesWizardToolbar * self;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIZARD_TOOLBAR, BoxesWizardToolbar);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	_g_object_unref0 (self->cancel_btn);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	_g_object_unref0 (self->back_btn);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	_g_object_unref0 (self->continue_btn);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	_g_object_unref0 (self->create_btn);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	G_OBJECT_CLASS (boxes_wizard_toolbar_parent_class)->finalize (obj);
#line 158 "wizard-toolbar.c"
}


GType boxes_wizard_toolbar_get_type (void) {
	static volatile gsize boxes_wizard_toolbar_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_wizard_toolbar_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesWizardToolbarClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_wizard_toolbar_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesWizardToolbar), 0, (GInstanceInitFunc) boxes_wizard_toolbar_instance_init, NULL };
		GType boxes_wizard_toolbar_type_id;
		boxes_wizard_toolbar_type_id = g_type_register_static (gtk_header_bar_get_type (), "BoxesWizardToolbar", &g_define_type_info, 0);
		g_once_init_leave (&boxes_wizard_toolbar_type_id__volatile, boxes_wizard_toolbar_type_id);
	}
	return boxes_wizard_toolbar_type_id__volatile;
}



