/* snapshots-property.c generated by valac 0.25.2.7-aa52, the Vala compiler
 * generated from snapshots-property.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <libcommon.h>
#include <float.h>
#include <math.h>
#include <libvirt-gobject/libvirt-gobject.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <glib/gi18n-lib.h>
#include <libgd/gd.h>


#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;
typedef struct _BoxesPropertyPrivate BoxesPropertyPrivate;

#define BOXES_TYPE_SNAPSHOTS_PROPERTY (boxes_snapshots_property_get_type ())
#define BOXES_SNAPSHOTS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SNAPSHOTS_PROPERTY, BoxesSnapshotsProperty))
#define BOXES_SNAPSHOTS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SNAPSHOTS_PROPERTY, BoxesSnapshotsPropertyClass))
#define BOXES_IS_SNAPSHOTS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SNAPSHOTS_PROPERTY))
#define BOXES_IS_SNAPSHOTS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SNAPSHOTS_PROPERTY))
#define BOXES_SNAPSHOTS_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SNAPSHOTS_PROPERTY, BoxesSnapshotsPropertyClass))

typedef struct _BoxesSnapshotsProperty BoxesSnapshotsProperty;
typedef struct _BoxesSnapshotsPropertyClass BoxesSnapshotsPropertyClass;
typedef struct _BoxesSnapshotsPropertyPrivate BoxesSnapshotsPropertyPrivate;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define TYPE_PROPERTY_CREATION_FLAG (property_creation_flag_get_type ())
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())
typedef struct _BoxesLibvirtMachinePrivate BoxesLibvirtMachinePrivate;

#define BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES (boxes_libvirt_machine_properties_get_type ())
#define BOXES_LIBVIRT_MACHINE_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachineProperties))
#define BOXES_LIBVIRT_MACHINE_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachinePropertiesClass))
#define BOXES_IS_LIBVIRT_MACHINE_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES))
#define BOXES_IS_LIBVIRT_MACHINE_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES))
#define BOXES_LIBVIRT_MACHINE_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachinePropertiesClass))

typedef struct _BoxesLibvirtMachineProperties BoxesLibvirtMachineProperties;
typedef struct _BoxesLibvirtMachinePropertiesClass BoxesLibvirtMachinePropertiesClass;

#define BOXES_TYPE_SNAPSHOT_LIST_ROW (boxes_snapshot_list_row_get_type ())
#define BOXES_SNAPSHOT_LIST_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SNAPSHOT_LIST_ROW, BoxesSnapshotListRow))
#define BOXES_SNAPSHOT_LIST_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SNAPSHOT_LIST_ROW, BoxesSnapshotListRowClass))
#define BOXES_IS_SNAPSHOT_LIST_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SNAPSHOT_LIST_ROW))
#define BOXES_IS_SNAPSHOT_LIST_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SNAPSHOT_LIST_ROW))
#define BOXES_SNAPSHOT_LIST_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SNAPSHOT_LIST_ROW, BoxesSnapshotListRowClass))

typedef struct _BoxesSnapshotListRow BoxesSnapshotListRow;
typedef struct _BoxesSnapshotListRowClass BoxesSnapshotListRowClass;
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _BoxesSnapshotsPropertyFetchSnapshotsData BoxesSnapshotsPropertyFetchSnapshotsData;
typedef struct _BoxesSnapshotListRowPrivate BoxesSnapshotListRowPrivate;

#define BOXES_MACHINE_TYPE_MACHINE_STATE (boxes_machine_machine_state_get_type ())

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;
typedef struct _BoxesAppWindowPrivate BoxesAppWindowPrivate;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _BoxesSnapshotsPropertyCreateSnapshotData BoxesSnapshotsPropertyCreateSnapshotData;
typedef struct _BoxesTopbarPrivate BoxesTopbarPrivate;

#define BOXES_TYPE_PROPERTIES_TOOLBAR (boxes_properties_toolbar_get_type ())
#define BOXES_PROPERTIES_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES_TOOLBAR, BoxesPropertiesToolbar))
#define BOXES_PROPERTIES_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES_TOOLBAR, BoxesPropertiesToolbarClass))
#define BOXES_IS_PROPERTIES_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES_TOOLBAR))
#define BOXES_IS_PROPERTIES_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES_TOOLBAR))
#define BOXES_PROPERTIES_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES_TOOLBAR, BoxesPropertiesToolbarClass))

typedef struct _BoxesPropertiesToolbar BoxesPropertiesToolbar;
typedef struct _BoxesPropertiesToolbarClass BoxesPropertiesToolbarClass;

#define BOXES_TYPE_WIZARD_TOOLBAR (boxes_wizard_toolbar_get_type ())
#define BOXES_WIZARD_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_TOOLBAR, BoxesWizardToolbar))
#define BOXES_WIZARD_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_TOOLBAR, BoxesWizardToolbarClass))
#define BOXES_IS_WIZARD_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_TOOLBAR))
#define BOXES_IS_WIZARD_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_TOOLBAR))
#define BOXES_WIZARD_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_TOOLBAR, BoxesWizardToolbarClass))

typedef struct _BoxesWizardToolbar BoxesWizardToolbar;
typedef struct _BoxesWizardToolbarClass BoxesWizardToolbarClass;
typedef struct _BoxesPropertiesToolbarPrivate BoxesPropertiesToolbarPrivate;

struct _BoxesProperty {
	GObject parent_instance;
	BoxesPropertyPrivate * priv;
};

struct _BoxesPropertyClass {
	GObjectClass parent_class;
};

struct _BoxesSnapshotsProperty {
	BoxesProperty parent_instance;
	BoxesSnapshotsPropertyPrivate * priv;
};

struct _BoxesSnapshotsPropertyClass {
	BoxesPropertyClass parent_class;
};

struct _BoxesSnapshotsPropertyPrivate {
	BoxesLibvirtMachine* machine;
	GtkListBox* snapshot_list;
	GtkStack* snapshot_stack;
	GtkLabel* activity_label;
	GtkBox* activity_box;
	GtkBox* snapshot_box;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesCollectionItem {
	GObject parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	GObjectClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_LOGIN,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DISPLAY,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_SNAPSHOTS,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

typedef enum  {
	PROPERTY_CREATION_FLAG_NONE = 1 << 0,
	PROPERTY_CREATION_FLAG_NO_USB = 1 << 1
} PropertyCreationFlag;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
	gboolean suspend_at_exit;
	gboolean deleted;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*restart) (BoxesMachine* self);
	void (*disconnect_display) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
};

struct _BoxesLibvirtMachine {
	BoxesMachine parent_instance;
	BoxesLibvirtMachinePrivate * priv;
	BoxesLibvirtMachineProperties* properties;
	gdouble* cpu_stats;
	gint cpu_stats_length1;
	gint _cpu_stats_size_;
	gdouble* io_stats;
	gint io_stats_length1;
	gint _io_stats_size_;
	gdouble* net_stats;
	gint net_stats_length1;
	gint _net_stats_size_;
};

struct _BoxesLibvirtMachineClass {
	BoxesMachineClass parent_class;
};

struct _BoxesSnapshotsPropertyFetchSnapshotsData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesSnapshotsProperty* self;
	BoxesLibvirtMachine* _tmp0_;
	BoxesLibvirtMachineProperties* _tmp1_;
	GList* snapshots;
	BoxesLibvirtMachine* _tmp2_;
	BoxesLibvirtMachineProperties* _tmp3_;
	GList* _tmp4_;
	GList* _tmp5_;
	GList* snapshot_collection;
	GList* snapshot_it;
	GVirDomainSnapshot* _tmp6_;
	GVirDomainSnapshot* snapshot;
	BoxesSnapshotListRow* row;
	GVirDomainSnapshot* _tmp7_;
	BoxesLibvirtMachine* _tmp8_;
	BoxesSnapshotListRow* _tmp9_;
	BoxesSnapshotListRow* _tmp10_;
	GtkListBox* _tmp11_;
	BoxesSnapshotListRow* _tmp12_;
	GError* e;
	GError* _tmp13_;
	const gchar* _tmp14_;
	GError * _inner_error_;
};

struct _BoxesSnapshotListRow {
	GtkListBoxRow parent_instance;
	BoxesSnapshotListRowPrivate * priv;
	GVirDomainSnapshot* snapshot;
};

struct _BoxesSnapshotListRowClass {
	GtkListBoxRowClass parent_class;
};

typedef enum  {
	BOXES_MACHINE_MACHINE_STATE_UNKNOWN,
	BOXES_MACHINE_MACHINE_STATE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_RUNNING,
	BOXES_MACHINE_MACHINE_STATE_PAUSED,
	BOXES_MACHINE_MACHINE_STATE_SAVED,
	BOXES_MACHINE_MACHINE_STATE_SLEEPING
} BoxesMachineMachineState;

struct _BoxesAppWindow {
	GtkApplicationWindow parent_instance;
	BoxesAppWindowPrivate * priv;
	BoxesCollectionItem* current_item;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesSelectionbar* selectionbar;
	BoxesSidebar* sidebar;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	GtkStack* below_bin;
	BoxesCollectionView* view;
	GSettings* settings;
};

struct _BoxesAppWindowClass {
	GtkApplicationWindowClass parent_class;
};

struct _BoxesSnapshotsPropertyCreateSnapshotData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesSnapshotsProperty* self;
	BoxesLibvirtMachine* _tmp0_;
	BoxesMachineMachineState _tmp1_;
	BoxesMachineMachineState _tmp2_;
	const gchar* _tmp3_;
	GVirDomainSnapshot* new_snapshot;
	BoxesLibvirtMachine* _tmp4_;
	BoxesLibvirtMachineProperties* _tmp5_;
	GVirDomainSnapshot* _tmp6_;
	BoxesSnapshotListRow* new_row;
	BoxesLibvirtMachine* _tmp7_;
	BoxesSnapshotListRow* _tmp8_;
	BoxesSnapshotListRow* _tmp9_;
	BoxesSnapshotListRow* _tmp10_;
	GtkListBox* _tmp11_;
	BoxesSnapshotListRow* _tmp12_;
	BoxesSnapshotListRow* _tmp13_;
	GError* e;
	gchar* msg;
	const gchar* _tmp14_;
	BoxesLibvirtMachine* _tmp15_;
	const gchar* _tmp16_;
	const gchar* _tmp17_;
	gchar* _tmp18_;
	BoxesLibvirtMachine* _tmp19_;
	BoxesAppWindow* _tmp20_;
	BoxesAppWindow* _tmp21_;
	BoxesNotificationbar* _tmp22_;
	const gchar* _tmp23_;
	GdNotification* _tmp24_;
	GdNotification* _tmp25_;
	GError* _tmp26_;
	const gchar* _tmp27_;
	GError * _inner_error_;
};

struct _BoxesTopbar {
	GtkStack parent_instance;
	BoxesTopbarPrivate * priv;
	BoxesPropertiesToolbar* props_toolbar;
	BoxesWizardToolbar* wizard_toolbar;
	gchar* _status;
};

struct _BoxesTopbarClass {
	GtkStackClass parent_class;
};

struct _BoxesPropertiesToolbar {
	GtkHeaderBar parent_instance;
	BoxesPropertiesToolbarPrivate * priv;
	GtkButton* back_button;
};

struct _BoxesPropertiesToolbarClass {
	GtkHeaderBarClass parent_class;
};


static gpointer boxes_snapshots_property_parent_class = NULL;

GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_snapshots_property_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
#define BOXES_SNAPSHOTS_PROPERTY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_SNAPSHOTS_PROPERTY, BoxesSnapshotsPropertyPrivate))
enum  {
	BOXES_SNAPSHOTS_PROPERTY_DUMMY_PROPERTY
};
BoxesSnapshotsProperty* boxes_snapshots_property_new (BoxesLibvirtMachine* machine);
BoxesSnapshotsProperty* boxes_snapshots_property_construct (GType object_type, BoxesLibvirtMachine* machine);
BoxesProperty* boxes_property_new (const gchar* description, GtkWidget* widget, GtkWidget* extra_widget);
BoxesProperty* boxes_property_construct (GType object_type, const gchar* description, GtkWidget* widget, GtkWidget* extra_widget);
static gint boxes_snapshots_property_config_sort_func (BoxesSnapshotsProperty* self, GtkListBoxRow* row1, GtkListBoxRow* row2);
static gint _boxes_snapshots_property_config_sort_func_gtk_list_box_sort_func (GtkListBoxRow* row1, GtkListBoxRow* row2, gpointer self);
static void __lambda143_ (BoxesSnapshotsProperty* self);
static void boxes_snapshots_property_create_snapshot (BoxesSnapshotsProperty* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_snapshots_property_create_snapshot_finish (BoxesSnapshotsProperty* self, GAsyncResult* _res_);
static void ___lambda143__gtk_tool_button_clicked (GtkToolButton* _sender, gpointer self);
static void boxes_snapshots_property_fetch_snapshots (BoxesSnapshotsProperty* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_snapshots_property_fetch_snapshots_finish (BoxesSnapshotsProperty* self, GAsyncResult* _res_);
static void boxes_snapshots_property_fetch_snapshots_data_free (gpointer _data);
static gboolean boxes_snapshots_property_fetch_snapshots_co (BoxesSnapshotsPropertyFetchSnapshotsData* _data_);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType property_creation_flag_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_properties_get_type (void) G_GNUC_CONST;
void boxes_libvirt_machine_properties_fetch_snapshots (BoxesLibvirtMachineProperties* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_libvirt_machine_properties_fetch_snapshots_finish (BoxesLibvirtMachineProperties* self, GAsyncResult* _res_, GError** error);
static void boxes_snapshots_property_fetch_snapshots_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
GList* boxes_libvirt_machine_properties_get_snapshots (BoxesLibvirtMachineProperties* self);
GType boxes_snapshot_list_row_get_type (void) G_GNUC_CONST;
BoxesSnapshotListRow* boxes_snapshot_list_row_new (GVirDomainSnapshot* snapshot, BoxesLibvirtMachine* machine);
BoxesSnapshotListRow* boxes_snapshot_list_row_construct (GType object_type, GVirDomainSnapshot* snapshot, BoxesLibvirtMachine* machine);
static void boxes_snapshots_property_row_activity_changed (BoxesSnapshotsProperty* self, GObject* source, GParamSpec* param_spec);
static void _boxes_snapshots_property_row_activity_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
static void boxes_snapshots_property_create_snapshot_data_free (gpointer _data);
static gboolean boxes_snapshots_property_create_snapshot_co (BoxesSnapshotsPropertyCreateSnapshotData* _data_);
GType boxes_machine_machine_state_get_type (void) G_GNUC_CONST;
BoxesMachineMachineState boxes_machine_get_state (BoxesMachine* self);
static void boxes_snapshots_property_set_activity (BoxesSnapshotsProperty* self, const gchar* value);
void boxes_libvirt_machine_properties_create_snapshot (BoxesLibvirtMachineProperties* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
GVirDomainSnapshot* boxes_libvirt_machine_properties_create_snapshot_finish (BoxesLibvirtMachineProperties* self, GAsyncResult* _res_, GError** error);
static void boxes_snapshots_property_create_snapshot_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
void boxes_snapshot_list_row_unreveal (BoxesSnapshotListRow* self);
void boxes_snapshot_list_row_reveal (BoxesSnapshotListRow* self);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
GType boxes_app_window_get_type (void) G_GNUC_CONST;
BoxesAppWindow* boxes_machine_get_window (BoxesMachine* self);
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
GdNotification* boxes_notificationbar_display_error (BoxesNotificationbar* self, const gchar* message, gint timeout);
#define BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT 6
const gchar* boxes_snapshot_list_row_get_activity_message (BoxesSnapshotListRow* self);
GType boxes_properties_toolbar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_toolbar_get_type (void) G_GNUC_CONST;
static void boxes_snapshots_property_finalize (GObject* obj);
static void _vala_boxes_snapshots_property_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


static gpointer _g_object_ref0 (gpointer self) {
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	return self ? g_object_ref (self) : NULL;
#line 599 "snapshots-property.c"
}


static gint _boxes_snapshots_property_config_sort_func_gtk_list_box_sort_func (GtkListBoxRow* row1, GtkListBoxRow* row2, gpointer self) {
	gint result;
	result = boxes_snapshots_property_config_sort_func ((BoxesSnapshotsProperty*) self, row1, row2);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	return result;
#line 608 "snapshots-property.c"
}


static void __lambda143_ (BoxesSnapshotsProperty* self) {
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	boxes_snapshots_property_create_snapshot (self, NULL, NULL);
#line 615 "snapshots-property.c"
}


static void ___lambda143__gtk_tool_button_clicked (GtkToolButton* _sender, gpointer self) {
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	__lambda143_ ((BoxesSnapshotsProperty*) self);
#line 622 "snapshots-property.c"
}


BoxesSnapshotsProperty* boxes_snapshots_property_construct (GType object_type, BoxesLibvirtMachine* machine) {
	BoxesSnapshotsProperty * self = NULL;
	GtkStack* snapshot_stack = NULL;
	GtkStack* _tmp0_ = NULL;
	BoxesLibvirtMachine* _tmp1_ = NULL;
	BoxesLibvirtMachine* _tmp2_ = NULL;
	GtkBox* _tmp3_ = NULL;
	GtkBox* _tmp4_ = NULL;
	GtkToolButton* create_snapshot_button = NULL;
	GtkToolButton* _tmp5_ = NULL;
	GtkToolbar* toolbar = NULL;
	GtkToolbar* _tmp6_ = NULL;
	GtkStyleContext* _tmp7_ = NULL;
	GtkBox* _tmp8_ = NULL;
	GtkListBox* _tmp9_ = NULL;
	GtkListBox* _tmp10_ = NULL;
	GtkListBox* _tmp11_ = NULL;
	GtkImage* icon_img = NULL;
	GtkImage* _tmp12_ = NULL;
	GtkFrame* snapshot_list_frame = NULL;
	GtkFrame* _tmp13_ = NULL;
	GtkListBox* _tmp14_ = NULL;
	GtkBox* _tmp15_ = NULL;
	GtkBox* _tmp16_ = NULL;
	GtkBox* _tmp17_ = NULL;
	GtkBox* _tmp18_ = NULL;
	GtkSpinner* activity_spinner = NULL;
	GtkSpinner* _tmp19_ = NULL;
	GtkBox* _tmp20_ = NULL;
	GtkLabel* _tmp21_ = NULL;
	GtkStyleContext* _tmp22_ = NULL;
	GtkBox* _tmp23_ = NULL;
	GtkLabel* _tmp24_ = NULL;
	GtkBox* _tmp25_ = NULL;
	GtkStack* _tmp26_ = NULL;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_return_val_if_fail (machine != NULL, NULL);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp0_ = (GtkStack*) gtk_stack_new ();
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_object_ref_sink (_tmp0_);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	snapshot_stack = _tmp0_;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	self = (BoxesSnapshotsProperty*) boxes_property_construct (object_type, NULL, (GtkWidget*) snapshot_stack, NULL);
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp1_ = machine;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (self->priv->machine);
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	self->priv->machine = _tmp2_;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_stack_set_transition_type (snapshot_stack, GTK_STACK_TRANSITION_TYPE_CROSSFADE);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp3_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_object_ref_sink (_tmp3_);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (self->priv->activity_box);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	self->priv->activity_box = _tmp3_;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp4_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_object_ref_sink (_tmp4_);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (self->priv->snapshot_box);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	self->priv->snapshot_box = _tmp4_;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp5_ = (GtkToolButton*) gtk_tool_button_new (NULL, NULL);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_object_ref_sink (_tmp5_);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	create_snapshot_button = _tmp5_;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp6_ = (GtkToolbar*) gtk_toolbar_new ();
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_object_ref_sink (_tmp6_);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	toolbar = _tmp6_;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp7_ = gtk_widget_get_style_context ((GtkWidget*) toolbar);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_style_context_add_class (_tmp7_, GTK_STYLE_CLASS_INLINE_TOOLBAR);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_toolbar_set_icon_size (toolbar, GTK_ICON_SIZE_MENU);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp8_ = self->priv->snapshot_box;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_object_set ((GtkWidget*) _tmp8_, "margin", 20, NULL);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp9_ = self->priv->snapshot_list;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_list_box_set_selection_mode (_tmp9_, GTK_SELECTION_NONE);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp10_ = self->priv->snapshot_list;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_widget_set_size_request ((GtkWidget*) _tmp10_, -1, 250);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp11_ = self->priv->snapshot_list;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_list_box_set_sort_func (_tmp11_, _boxes_snapshots_property_config_sort_func_gtk_list_box_sort_func, g_object_ref (self), g_object_unref);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_signal_connect_object (create_snapshot_button, "clicked", (GCallback) ___lambda143__gtk_tool_button_clicked, self, 0);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp12_ = (GtkImage*) gtk_image_new_from_icon_name ("list-add-symbolic", GTK_ICON_SIZE_MENU);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_object_ref_sink (_tmp12_);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	icon_img = _tmp12_;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_tool_button_set_icon_widget (create_snapshot_button, (GtkWidget*) icon_img);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp13_ = (GtkFrame*) gtk_frame_new (NULL);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_object_ref_sink (_tmp13_);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	snapshot_list_frame = _tmp13_;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp14_ = self->priv->snapshot_list;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_container_add ((GtkContainer*) snapshot_list_frame, (GtkWidget*) _tmp14_);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp15_ = self->priv->snapshot_box;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_box_pack_start (_tmp15_, (GtkWidget*) snapshot_list_frame, TRUE, TRUE, (guint) 0);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_container_add ((GtkContainer*) toolbar, (GtkWidget*) create_snapshot_button);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp16_ = self->priv->snapshot_box;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_box_pack_start (_tmp16_, (GtkWidget*) toolbar, TRUE, FALSE, (guint) 0);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp17_ = self->priv->snapshot_box;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_container_add ((GtkContainer*) snapshot_stack, (GtkWidget*) _tmp17_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp18_ = self->priv->activity_box;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp18_, GTK_ALIGN_CENTER);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp19_ = (GtkSpinner*) gtk_spinner_new ();
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_object_ref_sink (_tmp19_);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	activity_spinner = _tmp19_;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_widget_set_size_request ((GtkWidget*) activity_spinner, 64, 64);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_spinner_start (activity_spinner);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp20_ = self->priv->activity_box;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_box_pack_start (_tmp20_, (GtkWidget*) activity_spinner, FALSE, FALSE, (guint) 0);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp21_ = self->priv->activity_label;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp22_ = gtk_widget_get_style_context ((GtkWidget*) _tmp21_);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_style_context_add_class (_tmp22_, GTK_STYLE_CLASS_DIM_LABEL);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp23_ = self->priv->activity_box;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp24_ = self->priv->activity_label;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_box_pack_start (_tmp23_, (GtkWidget*) _tmp24_, FALSE, FALSE, (guint) 0);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp25_ = self->priv->activity_box;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	gtk_container_add ((GtkContainer*) snapshot_stack, (GtkWidget*) _tmp25_);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp26_ = _g_object_ref0 (snapshot_stack);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (self->priv->snapshot_stack);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	self->priv->snapshot_stack = _tmp26_;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	boxes_snapshots_property_fetch_snapshots (self, NULL, NULL);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (activity_spinner);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (snapshot_list_frame);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (icon_img);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (toolbar);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (create_snapshot_button);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (snapshot_stack);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	return self;
#line 821 "snapshots-property.c"
}


BoxesSnapshotsProperty* boxes_snapshots_property_new (BoxesLibvirtMachine* machine) {
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	return boxes_snapshots_property_construct (BOXES_TYPE_SNAPSHOTS_PROPERTY, machine);
#line 828 "snapshots-property.c"
}


static void boxes_snapshots_property_fetch_snapshots_data_free (gpointer _data) {
	BoxesSnapshotsPropertyFetchSnapshotsData* _data_;
	_data_ = _data;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (_data_->self);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_slice_free (BoxesSnapshotsPropertyFetchSnapshotsData, _data_);
#line 839 "snapshots-property.c"
}


static void boxes_snapshots_property_fetch_snapshots (BoxesSnapshotsProperty* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesSnapshotsPropertyFetchSnapshotsData* _data_;
	BoxesSnapshotsProperty* _tmp0_ = NULL;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_ = g_slice_new0 (BoxesSnapshotsPropertyFetchSnapshotsData);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_snapshots_property_fetch_snapshots);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_snapshots_property_fetch_snapshots_data_free);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_->self = _tmp0_;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	boxes_snapshots_property_fetch_snapshots_co (_data_);
#line 858 "snapshots-property.c"
}


static void boxes_snapshots_property_fetch_snapshots_finish (BoxesSnapshotsProperty* self, GAsyncResult* _res_) {
	BoxesSnapshotsPropertyFetchSnapshotsData* _data_;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 866 "snapshots-property.c"
}


static void boxes_snapshots_property_fetch_snapshots_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesSnapshotsPropertyFetchSnapshotsData* _data_;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_ = _user_data_;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_->_source_object_ = source_object;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_->_res_ = _res_;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	boxes_snapshots_property_fetch_snapshots_co (_data_);
#line 880 "snapshots-property.c"
}


static void _boxes_snapshots_property_row_activity_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	boxes_snapshots_property_row_activity_changed ((BoxesSnapshotsProperty*) self, _sender, pspec);
#line 887 "snapshots-property.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 894 "snapshots-property.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_list_free (self);
#line 903 "snapshots-property.c"
}


static gboolean boxes_snapshots_property_fetch_snapshots_co (BoxesSnapshotsPropertyFetchSnapshotsData* _data_) {
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	switch (_data_->_state_) {
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		case 0:
#line 912 "snapshots-property.c"
		goto _state_0;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		case 1:
#line 916 "snapshots-property.c"
		goto _state_1;
		default:
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		g_assert_not_reached ();
#line 921 "snapshots-property.c"
	}
	_state_0:
	{
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp0_ = NULL;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp0_ = _data_->self->priv->machine;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp1_ = NULL;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp1_ = _data_->_tmp0_->properties;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_state_ = 1;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		boxes_libvirt_machine_properties_fetch_snapshots (_data_->_tmp1_, NULL, boxes_snapshots_property_fetch_snapshots_ready, _data_);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		return FALSE;
#line 939 "snapshots-property.c"
		_state_1:
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		boxes_libvirt_machine_properties_fetch_snapshots_finish (_data_->_tmp1_, _data_->_res_, &_data_->_inner_error_);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 945 "snapshots-property.c"
			goto __catch133_g_error;
		}
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp2_ = NULL;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp2_ = _data_->self->priv->machine;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp3_ = NULL;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp3_ = _data_->_tmp2_->properties;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp4_ = NULL;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp4_ = boxes_libvirt_machine_properties_get_snapshots (_data_->_tmp3_);
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->snapshots = _data_->_tmp4_;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp5_ = NULL;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp5_ = _data_->snapshots;
#line 966 "snapshots-property.c"
		{
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
			_data_->snapshot_collection = _data_->_tmp5_;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
			for (_data_->snapshot_it = _data_->snapshot_collection; _data_->snapshot_it != NULL; _data_->snapshot_it = _data_->snapshot_it->next) {
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
				_data_->_tmp6_ = NULL;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
				_data_->_tmp6_ = _g_object_ref0 ((GVirDomainSnapshot*) _data_->snapshot_it->data);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
				_data_->snapshot = _data_->_tmp6_;
#line 978 "snapshots-property.c"
				{
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
					_data_->_tmp7_ = NULL;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
					_data_->_tmp7_ = _data_->snapshot;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
					_data_->_tmp8_ = NULL;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
					_data_->_tmp8_ = _data_->self->priv->machine;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
					_data_->_tmp9_ = NULL;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
					_data_->_tmp9_ = boxes_snapshot_list_row_new (_data_->_tmp7_, _data_->_tmp8_);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
					g_object_ref_sink (_data_->_tmp9_);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
					_data_->row = _data_->_tmp9_;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
					_data_->_tmp10_ = NULL;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
					_data_->_tmp10_ = _data_->row;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
					g_signal_connect_object ((GObject*) _data_->_tmp10_, "notify::activity-message", (GCallback) _boxes_snapshots_property_row_activity_changed_g_object_notify, _data_->self, 0);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
					_data_->_tmp11_ = NULL;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
					_data_->_tmp11_ = _data_->self->priv->snapshot_list;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
					_data_->_tmp12_ = NULL;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
					_data_->_tmp12_ = _data_->row;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
					gtk_container_add ((GtkContainer*) _data_->_tmp11_, (GtkWidget*) _data_->_tmp12_);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
					_g_object_unref0 (_data_->row);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
					_g_object_unref0 (_data_->snapshot);
#line 1016 "snapshots-property.c"
				}
			}
		}
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		__g_list_free__g_object_unref0_0 (_data_->snapshots);
#line 1022 "snapshots-property.c"
	}
	goto __finally133;
	__catch133_g_error:
	{
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->e = _data_->_inner_error_;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_inner_error_ = NULL;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp13_ = NULL;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp13_ = _data_->e;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp14_ = NULL;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp14_ = _data_->_tmp13_->message;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		g_warning ("snapshots-property.vala:83: Could not fetch snapshots: %s", _data_->_tmp14_);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_g_error_free0 (_data_->e);
#line 1043 "snapshots-property.c"
	}
	__finally133:
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		g_clear_error (&_data_->_inner_error_);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		return FALSE;
#line 1054 "snapshots-property.c"
	}
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	if (_data_->_state_ == 0) {
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1060 "snapshots-property.c"
	} else {
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1064 "snapshots-property.c"
	}
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_object_unref (_data_->_async_result);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	return FALSE;
#line 1070 "snapshots-property.c"
}


static gint boxes_snapshots_property_config_sort_func (BoxesSnapshotsProperty* self, GtkListBoxRow* row1, GtkListBoxRow* row2) {
	gint result = 0;
	GError * _inner_error_ = NULL;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_return_val_if_fail (row1 != NULL, 0);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_return_val_if_fail (row2 != NULL, 0);
#line 1083 "snapshots-property.c"
	{
		GVirConfigDomainSnapshot* conf1 = NULL;
		GtkListBoxRow* _tmp0_ = NULL;
		GVirDomainSnapshot* _tmp1_ = NULL;
		GVirConfigDomainSnapshot* _tmp2_ = NULL;
		GVirConfigDomainSnapshot* conf2 = NULL;
		GtkListBoxRow* _tmp3_ = NULL;
		GVirDomainSnapshot* _tmp4_ = NULL;
		GVirConfigDomainSnapshot* _tmp5_ = NULL;
		GVirConfigDomainSnapshot* _tmp6_ = NULL;
		glong _tmp7_ = 0L;
		GVirConfigDomainSnapshot* _tmp8_ = NULL;
		glong _tmp9_ = 0L;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp0_ = row1;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp1_ = (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, BOXES_TYPE_SNAPSHOT_LIST_ROW) ? ((BoxesSnapshotListRow*) _tmp0_) : NULL)->snapshot;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp2_ = gvir_domain_snapshot_get_config (_tmp1_, (guint) 0, &_inner_error_);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		conf1 = _tmp2_;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1107 "snapshots-property.c"
			goto __catch134_g_error;
		}
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp3_ = row2;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp4_ = (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, BOXES_TYPE_SNAPSHOT_LIST_ROW) ? ((BoxesSnapshotListRow*) _tmp3_) : NULL)->snapshot;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp5_ = gvir_domain_snapshot_get_config (_tmp4_, (guint) 0, &_inner_error_);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		conf2 = _tmp5_;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
			_g_object_unref0 (conf1);
#line 1122 "snapshots-property.c"
			goto __catch134_g_error;
		}
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp6_ = conf1;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp7_ = gvir_config_domain_snapshot_get_creation_time (_tmp6_);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp8_ = conf2;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp9_ = gvir_config_domain_snapshot_get_creation_time (_tmp8_);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		if (_tmp7_ < _tmp9_) {
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
			result = -1;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
			_g_object_unref0 (conf2);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
			_g_object_unref0 (conf1);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
			return result;
#line 1143 "snapshots-property.c"
		} else {
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
			result = 1;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
			_g_object_unref0 (conf2);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
			_g_object_unref0 (conf1);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
			return result;
#line 1153 "snapshots-property.c"
		}
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_g_object_unref0 (conf2);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_g_object_unref0 (conf1);
#line 1159 "snapshots-property.c"
	}
	goto __finally134;
	__catch134_g_error:
	{
		GError* e = NULL;
		GError* _tmp10_ = NULL;
		const gchar* _tmp11_ = NULL;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		e = _inner_error_;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_inner_error_ = NULL;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp10_ = e;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp11_ = _tmp10_->message;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		g_warning ("snapshots-property.vala:96: Failed to fetch snapshot config: %s", _tmp11_);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		result = 0;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_g_error_free0 (e);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		return result;
#line 1183 "snapshots-property.c"
	}
	__finally134:
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_clear_error (&_inner_error_);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	return 0;
#line 1192 "snapshots-property.c"
}


static void boxes_snapshots_property_create_snapshot_data_free (gpointer _data) {
	BoxesSnapshotsPropertyCreateSnapshotData* _data_;
	_data_ = _data;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (_data_->self);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_slice_free (BoxesSnapshotsPropertyCreateSnapshotData, _data_);
#line 1203 "snapshots-property.c"
}


static void boxes_snapshots_property_create_snapshot (BoxesSnapshotsProperty* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesSnapshotsPropertyCreateSnapshotData* _data_;
	BoxesSnapshotsProperty* _tmp0_ = NULL;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_ = g_slice_new0 (BoxesSnapshotsPropertyCreateSnapshotData);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_snapshots_property_create_snapshot);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_snapshots_property_create_snapshot_data_free);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_->self = _tmp0_;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	boxes_snapshots_property_create_snapshot_co (_data_);
#line 1222 "snapshots-property.c"
}


static void boxes_snapshots_property_create_snapshot_finish (BoxesSnapshotsProperty* self, GAsyncResult* _res_) {
	BoxesSnapshotsPropertyCreateSnapshotData* _data_;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1230 "snapshots-property.c"
}


static void boxes_snapshots_property_create_snapshot_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesSnapshotsPropertyCreateSnapshotData* _data_;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_ = _user_data_;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_->_source_object_ = source_object;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_->_res_ = _res_;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	boxes_snapshots_property_create_snapshot_co (_data_);
#line 1244 "snapshots-property.c"
}


static gboolean boxes_snapshots_property_create_snapshot_co (BoxesSnapshotsPropertyCreateSnapshotData* _data_) {
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	switch (_data_->_state_) {
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		case 0:
#line 1253 "snapshots-property.c"
		goto _state_0;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		case 1:
#line 1257 "snapshots-property.c"
		goto _state_1;
		default:
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		g_assert_not_reached ();
#line 1262 "snapshots-property.c"
	}
	_state_0:
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_->_tmp0_ = NULL;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_->_tmp0_ = _data_->self->priv->machine;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_->_tmp1_ = 0;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_->_tmp1_ = boxes_machine_get_state ((BoxesMachine*) _data_->_tmp0_);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_->_tmp2_ = 0;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_data_->_tmp2_ = _data_->_tmp1_;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	if (_data_->_tmp2_ == BOXES_MACHINE_MACHINE_STATE_RUNNING) {
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp3_ = NULL;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp3_ = _ ("Creating new snapshot…");
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		boxes_snapshots_property_set_activity (_data_->self, _data_->_tmp3_);
#line 1285 "snapshots-property.c"
	}
	{
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp4_ = NULL;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp4_ = _data_->self->priv->machine;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp5_ = NULL;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp5_ = _data_->_tmp4_->properties;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_state_ = 1;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		boxes_libvirt_machine_properties_create_snapshot (_data_->_tmp5_, boxes_snapshots_property_create_snapshot_ready, _data_);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		return FALSE;
#line 1302 "snapshots-property.c"
		_state_1:
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp6_ = NULL;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp6_ = boxes_libvirt_machine_properties_create_snapshot_finish (_data_->_tmp5_, _data_->_res_, &_data_->_inner_error_);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->new_snapshot = _data_->_tmp6_;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 1312 "snapshots-property.c"
			goto __catch135_g_error;
		}
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp7_ = NULL;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp7_ = _data_->self->priv->machine;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp8_ = NULL;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp8_ = boxes_snapshot_list_row_new (_data_->new_snapshot, _data_->_tmp7_);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		g_object_ref_sink (_data_->_tmp8_);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->new_row = _data_->_tmp8_;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp9_ = NULL;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp9_ = _data_->new_row;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		g_signal_connect_object ((GObject*) _data_->_tmp9_, "notify::activity-message", (GCallback) _boxes_snapshots_property_row_activity_changed_g_object_notify, _data_->self, 0);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp10_ = NULL;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp10_ = _data_->new_row;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		boxes_snapshot_list_row_unreveal (_data_->_tmp10_);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp11_ = NULL;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp11_ = _data_->self->priv->snapshot_list;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp12_ = NULL;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp12_ = _data_->new_row;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		gtk_container_add ((GtkContainer*) _data_->_tmp11_, (GtkWidget*) _data_->_tmp12_);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp13_ = NULL;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp13_ = _data_->new_row;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		boxes_snapshot_list_row_reveal (_data_->_tmp13_);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_g_object_unref0 (_data_->new_row);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_g_object_unref0 (_data_->new_snapshot);
#line 1359 "snapshots-property.c"
	}
	goto __finally135;
	__catch135_g_error:
	{
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->e = _data_->_inner_error_;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_inner_error_ = NULL;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp14_ = NULL;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp14_ = _ ("Failed to create snapshot of %s");
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp15_ = NULL;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp15_ = _data_->self->priv->machine;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp16_ = NULL;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp16_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->_tmp15_);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp17_ = NULL;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp17_ = _data_->_tmp16_;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp18_ = NULL;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp18_ = g_strdup_printf (_data_->_tmp14_, _data_->_tmp17_);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->msg = _data_->_tmp18_;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp19_ = NULL;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp19_ = _data_->self->priv->machine;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp20_ = NULL;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp20_ = boxes_machine_get_window ((BoxesMachine*) _data_->_tmp19_);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp21_ = NULL;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp21_ = _data_->_tmp20_;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp22_ = NULL;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp22_ = _data_->_tmp21_->notificationbar;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp23_ = NULL;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp23_ = _data_->msg;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp24_ = NULL;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp24_ = boxes_notificationbar_display_error (_data_->_tmp22_, _data_->_tmp23_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp25_ = NULL;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp25_ = _data_->_tmp24_;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_g_object_unref0 (_data_->_tmp25_);
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp26_ = NULL;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp26_ = _data_->e;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp27_ = NULL;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_data_->_tmp27_ = _data_->_tmp26_->message;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		g_warning ("snapshots-property.vala:115: %s", _data_->_tmp27_);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_g_free0 (_data_->msg);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_g_error_free0 (_data_->e);
#line 1434 "snapshots-property.c"
	}
	__finally135:
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		g_clear_error (&_data_->_inner_error_);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		return FALSE;
#line 1445 "snapshots-property.c"
	}
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	boxes_snapshots_property_set_activity (_data_->self, NULL);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	if (_data_->_state_ == 0) {
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1453 "snapshots-property.c"
	} else {
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1457 "snapshots-property.c"
	}
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_object_unref (_data_->_async_result);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	return FALSE;
#line 1463 "snapshots-property.c"
}


static void boxes_snapshots_property_row_activity_changed (BoxesSnapshotsProperty* self, GObject* source, GParamSpec* param_spec) {
	BoxesSnapshotListRow* row = NULL;
	GObject* _tmp0_ = NULL;
	BoxesSnapshotListRow* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_return_if_fail (self != NULL);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_return_if_fail (source != NULL);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_return_if_fail (param_spec != NULL);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp0_ = source;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, BOXES_TYPE_SNAPSHOT_LIST_ROW) ? ((BoxesSnapshotListRow*) _tmp0_) : NULL);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	row = _tmp1_;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp2_ = boxes_snapshot_list_row_get_activity_message (row);
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp3_ = _tmp2_;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	boxes_snapshots_property_set_activity (self, _tmp3_);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (row);
#line 1493 "snapshots-property.c"
}


static void boxes_snapshots_property_set_activity (BoxesSnapshotsProperty* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_return_if_fail (self != NULL);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp0_ = value;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	if (_tmp0_ == NULL) {
#line 1505 "snapshots-property.c"
		GtkStack* _tmp1_ = NULL;
		GtkBox* _tmp2_ = NULL;
		BoxesLibvirtMachine* _tmp3_ = NULL;
		BoxesAppWindow* _tmp4_ = NULL;
		BoxesAppWindow* _tmp5_ = NULL;
		BoxesSidebar* _tmp6_ = NULL;
		BoxesLibvirtMachine* _tmp7_ = NULL;
		BoxesAppWindow* _tmp8_ = NULL;
		BoxesAppWindow* _tmp9_ = NULL;
		BoxesTopbar* _tmp10_ = NULL;
		BoxesPropertiesToolbar* _tmp11_ = NULL;
		GtkButton* _tmp12_ = NULL;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp1_ = self->priv->snapshot_stack;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp2_ = self->priv->snapshot_box;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		gtk_stack_set_visible_child (_tmp1_, (GtkWidget*) _tmp2_);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp3_ = self->priv->machine;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp4_ = boxes_machine_get_window ((BoxesMachine*) _tmp3_);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp5_ = _tmp4_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp6_ = _tmp5_->sidebar;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		gtk_widget_set_sensitive ((GtkWidget*) _tmp6_, TRUE);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp7_ = self->priv->machine;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp8_ = boxes_machine_get_window ((BoxesMachine*) _tmp7_);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp9_ = _tmp8_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp10_ = _tmp9_->topbar;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp11_ = _tmp10_->props_toolbar;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp12_ = _tmp11_->back_button;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		gtk_widget_set_sensitive ((GtkWidget*) _tmp12_, TRUE);
#line 1548 "snapshots-property.c"
	} else {
		GtkLabel* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
		GtkStack* _tmp15_ = NULL;
		GtkBox* _tmp16_ = NULL;
		BoxesLibvirtMachine* _tmp17_ = NULL;
		BoxesAppWindow* _tmp18_ = NULL;
		BoxesAppWindow* _tmp19_ = NULL;
		BoxesSidebar* _tmp20_ = NULL;
		BoxesLibvirtMachine* _tmp21_ = NULL;
		BoxesAppWindow* _tmp22_ = NULL;
		BoxesAppWindow* _tmp23_ = NULL;
		BoxesTopbar* _tmp24_ = NULL;
		BoxesPropertiesToolbar* _tmp25_ = NULL;
		GtkButton* _tmp26_ = NULL;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp13_ = self->priv->activity_label;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp14_ = value;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		gtk_label_set_label (_tmp13_, _tmp14_);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp15_ = self->priv->snapshot_stack;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp16_ = self->priv->activity_box;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		gtk_stack_set_visible_child (_tmp15_, (GtkWidget*) _tmp16_);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp17_ = self->priv->machine;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp18_ = boxes_machine_get_window ((BoxesMachine*) _tmp17_);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp19_ = _tmp18_;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp20_ = _tmp19_->sidebar;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		gtk_widget_set_sensitive ((GtkWidget*) _tmp20_, FALSE);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp21_ = self->priv->machine;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp22_ = boxes_machine_get_window ((BoxesMachine*) _tmp21_);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp23_ = _tmp22_;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp24_ = _tmp23_->topbar;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp25_ = _tmp24_->props_toolbar;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		_tmp26_ = _tmp25_->back_button;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		gtk_widget_set_sensitive ((GtkWidget*) _tmp26_, FALSE);
#line 1600 "snapshots-property.c"
	}
}


static void boxes_snapshots_property_class_init (BoxesSnapshotsPropertyClass * klass) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	boxes_snapshots_property_parent_class = g_type_class_peek_parent (klass);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_type_class_add_private (klass, sizeof (BoxesSnapshotsPropertyPrivate));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_snapshots_property_set_property;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_snapshots_property_finalize;
#line 1614 "snapshots-property.c"
}


static void boxes_snapshots_property_instance_init (BoxesSnapshotsProperty * self) {
	GtkListBox* _tmp0_ = NULL;
	GtkLabel* _tmp1_ = NULL;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	self->priv = BOXES_SNAPSHOTS_PROPERTY_GET_PRIVATE (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp0_ = (GtkListBox*) gtk_list_box_new ();
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_object_ref_sink (_tmp0_);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	self->priv->snapshot_list = _tmp0_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_tmp1_ = (GtkLabel*) gtk_label_new ("");
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	g_object_ref_sink (_tmp1_);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	self->priv->activity_label = _tmp1_;
#line 1635 "snapshots-property.c"
}


static void boxes_snapshots_property_finalize (GObject* obj) {
	BoxesSnapshotsProperty * self;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_SNAPSHOTS_PROPERTY, BoxesSnapshotsProperty);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (self->priv->machine);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (self->priv->snapshot_list);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (self->priv->snapshot_stack);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (self->priv->activity_label);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (self->priv->activity_box);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	_g_object_unref0 (self->priv->snapshot_box);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	G_OBJECT_CLASS (boxes_snapshots_property_parent_class)->finalize (obj);
#line 1657 "snapshots-property.c"
}


GType boxes_snapshots_property_get_type (void) {
	static volatile gsize boxes_snapshots_property_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_snapshots_property_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesSnapshotsPropertyClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_snapshots_property_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesSnapshotsProperty), 0, (GInstanceInitFunc) boxes_snapshots_property_instance_init, NULL };
		GType boxes_snapshots_property_type_id;
		boxes_snapshots_property_type_id = g_type_register_static (BOXES_TYPE_PROPERTY, "BoxesSnapshotsProperty", &g_define_type_info, 0);
		g_once_init_leave (&boxes_snapshots_property_type_id__volatile, boxes_snapshots_property_type_id);
	}
	return boxes_snapshots_property_type_id__volatile;
}


static void _vala_boxes_snapshots_property_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesSnapshotsProperty * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_SNAPSHOTS_PROPERTY, BoxesSnapshotsProperty);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
	switch (property_id) {
#line 1678 "snapshots-property.c"
		default:
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshots-property.vala"
		break;
#line 1684 "snapshots-property.c"
	}
}



