/* vm-creator.c generated by valac 0.25.2.7-aa52, the Vala compiler
 * generated from vm-creator.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <libvirt-gobject/libvirt-gobject.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <gtk/gtk.h>
#include <glib/gi18n-lib.h>
#include <libgd/gd.h>
#include <libcommon.h>
#include <osinfo/osinfo.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <glib/gstdio.h>
#include <gobject/gvaluecollector.h>


#define BOXES_TYPE_VM_CREATOR (boxes_vm_creator_get_type ())
#define BOXES_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreator))
#define BOXES_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))
#define BOXES_IS_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VM_CREATOR))
#define BOXES_IS_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VM_CREATOR))
#define BOXES_VM_CREATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))

typedef struct _BoxesVMCreator BoxesVMCreator;
typedef struct _BoxesVMCreatorClass BoxesVMCreatorClass;
typedef struct _BoxesVMCreatorPrivate BoxesVMCreatorPrivate;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;

#define BOXES_TYPE_INSTALLER_MEDIA (boxes_installer_media_get_type ())
#define BOXES_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia))
#define BOXES_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))
#define BOXES_IS_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_IS_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_INSTALLER_MEDIA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))

typedef struct _BoxesInstallerMedia BoxesInstallerMedia;
typedef struct _BoxesInstallerMediaClass BoxesInstallerMediaClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _boxes_vm_creator_unref0(var) ((var == NULL) ? NULL : (var = (boxes_vm_creator_unref (var), NULL)))
typedef struct _Block74Data Block74Data;
typedef struct _Block75Data Block75Data;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
#define _g_free0(var) (var = (g_free (var), NULL))

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesAppWindowPrivate BoxesAppWindowPrivate;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _BoxesInstallerMediaPrivate BoxesInstallerMediaPrivate;

#define BOXES_TYPE_BROKER (boxes_broker_get_type ())
#define BOXES_BROKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_BROKER, BoxesBroker))
#define BOXES_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_BROKER, BoxesBrokerClass))
#define BOXES_IS_BROKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_BROKER))
#define BOXES_IS_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_BROKER))
#define BOXES_BROKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_BROKER, BoxesBrokerClass))

typedef struct _BoxesBroker BoxesBroker;
typedef struct _BoxesBrokerClass BoxesBrokerClass;

#define BOXES_TYPE_LIBVIRT_BROKER (boxes_libvirt_broker_get_type ())
#define BOXES_LIBVIRT_BROKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_BROKER, BoxesLibvirtBroker))
#define BOXES_LIBVIRT_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_BROKER, BoxesLibvirtBrokerClass))
#define BOXES_IS_LIBVIRT_BROKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_BROKER))
#define BOXES_IS_LIBVIRT_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_BROKER))
#define BOXES_LIBVIRT_BROKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_BROKER, BoxesLibvirtBrokerClass))

typedef struct _BoxesLibvirtBroker BoxesLibvirtBroker;
typedef struct _BoxesLibvirtBrokerClass BoxesLibvirtBrokerClass;
typedef struct _BoxesVmCreatorCreateVmData BoxesVmCreatorCreateVmData;
typedef struct _Block76Data Block76Data;

#define BOXES_TYPE_UNATTENDED_INSTALLER (boxes_unattended_installer_get_type ())
#define BOXES_UNATTENDED_INSTALLER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstaller))
#define BOXES_UNATTENDED_INSTALLER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstallerClass))
#define BOXES_IS_UNATTENDED_INSTALLER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_INSTALLER))
#define BOXES_IS_UNATTENDED_INSTALLER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UNATTENDED_INSTALLER))
#define BOXES_UNATTENDED_INSTALLER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstallerClass))

typedef struct _BoxesUnattendedInstaller BoxesUnattendedInstaller;
typedef struct _BoxesUnattendedInstallerClass BoxesUnattendedInstallerClass;
typedef struct _BoxesUnattendedInstallerPrivate BoxesUnattendedInstallerPrivate;

#define BOXES_TYPE_UNATTENDED_SETUP_BOX (boxes_unattended_setup_box_get_type ())
#define BOXES_UNATTENDED_SETUP_BOX(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_SETUP_BOX, BoxesUnattendedSetupBox))
#define BOXES_UNATTENDED_SETUP_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UNATTENDED_SETUP_BOX, BoxesUnattendedSetupBoxClass))
#define BOXES_IS_UNATTENDED_SETUP_BOX(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_SETUP_BOX))
#define BOXES_IS_UNATTENDED_SETUP_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UNATTENDED_SETUP_BOX))
#define BOXES_UNATTENDED_SETUP_BOX_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UNATTENDED_SETUP_BOX, BoxesUnattendedSetupBoxClass))

typedef struct _BoxesUnattendedSetupBox BoxesUnattendedSetupBox;
typedef struct _BoxesUnattendedSetupBoxClass BoxesUnattendedSetupBoxClass;
typedef struct _Block77Data Block77Data;
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define TYPE_PROPERTY_CREATION_FLAG (property_creation_flag_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())

#define BOXES_TYPE_MEDIA_MANAGER (boxes_media_manager_get_type ())
#define BOXES_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManager))
#define BOXES_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))
#define BOXES_IS_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_IS_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_MEDIA_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))

typedef struct _BoxesMediaManager BoxesMediaManager;
typedef struct _BoxesMediaManagerClass BoxesMediaManagerClass;

#define BOXES_MACHINE_TYPE_MACHINE_STATE (boxes_machine_machine_state_get_type ())
typedef struct _BoxesVmCreatorContinueInstallationData BoxesVmCreatorContinueInstallationData;
typedef struct _Block78Data Block78Data;
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
#define __vala_GVirStoragePoolInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirStoragePoolInfo_free (var), NULL)))
typedef struct _BoxesVmCreatorGetStoragePoolData BoxesVmCreatorGetStoragePoolData;
typedef struct _BoxesVmCreatorCreateDomainConfigData BoxesVmCreatorCreateDomainConfigData;
#define __vala_GVirStorageVolInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirStorageVolInfo_free (var), NULL)))
typedef struct _Block79Data Block79Data;
typedef struct _Block80Data Block80Data;
typedef struct _BoxesVmCreatorUpdateInstallProgressData BoxesVmCreatorUpdateInstallProgressData;
typedef struct _BoxesVmCreatorCreateDomainNameAndTitleFromMediaData BoxesVmCreatorCreateDomainNameAndTitleFromMediaData;
typedef struct _BoxesVmCreatorCreateTargetVolumeData BoxesVmCreatorCreateTargetVolumeData;
typedef struct _BoxesParamSpecVMCreator BoxesParamSpecVMCreator;

struct _BoxesVMCreator {
	GTypeInstance parent_instance;
	volatile int ref_count;
	BoxesVMCreatorPrivate * priv;
};

struct _BoxesVMCreatorClass {
	GTypeClass parent_class;
	void (*finalize) (BoxesVMCreator *self);
	void (*launch_vm) (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GError** error);
	void (*continue_installation) (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*continue_installation_finish) (BoxesVMCreator* self, GAsyncResult* _res_);
	void (*update_machine_info) (BoxesVMCreator* self, BoxesLibvirtMachine* machine);
	void (*create_domain_config) (BoxesVMCreator* self, const gchar* name, const gchar* title, GVirStorageVol* volume, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GVirConfigDomain* (*create_domain_config_finish) (BoxesVMCreator* self, GAsyncResult* _res_, GError** error);
	void (*create_domain_base_name_and_title) (BoxesVMCreator* self, gchar** base_name, gchar** base_title);
};

struct _BoxesVMCreatorPrivate {
	BoxesInstallerMedia* _install_media;
	gulong state_changed_id;
	guint _num_reboots;
	gint prev_progress;
	gboolean updating_install_progress;
};

struct _Block74Data {
	int _ref_count_;
	BoxesVMCreator* self;
	gpointer _async_data_;
};

struct _Block75Data {
	int _ref_count_;
	Block74Data * _data74_;
	gulong handler;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesAppWindow {
	GtkApplicationWindow parent_instance;
	BoxesAppWindowPrivate * priv;
	BoxesCollectionItem* current_item;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesSelectionbar* selectionbar;
	BoxesSidebar* sidebar;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	GtkStack* below_bin;
	BoxesCollectionView* view;
	GSettings* settings;
};

struct _BoxesAppWindowClass {
	GtkApplicationWindowClass parent_class;
};

struct _BoxesInstallerMedia {
	GObject parent_instance;
	BoxesInstallerMediaPrivate * priv;
	OsinfoOs* os;
	OsinfoResources* resources;
	OsinfoMedia* os_media;
	gchar* label;
	gchar* device_file;
	gchar* mount_point;
	gboolean from_image;
};

struct _BoxesInstallerMediaClass {
	GObjectClass parent_class;
	void (*set_direct_boot_params) (BoxesInstallerMedia* self, GVirConfigDomainOs* os);
	void (*prepare) (BoxesInstallerMedia* self, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_);
	void (*prepare_for_installation) (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_for_installation_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_, GError** error);
	void (*prepare_to_continue_installation) (BoxesInstallerMedia* self, const gchar* vm_name);
	void (*clean_up) (BoxesInstallerMedia* self);
	void (*clean_up_preparation_cache) (BoxesInstallerMedia* self);
	void (*setup_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*setup_post_install_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*populate_setup_box) (BoxesInstallerMedia* self, GtkBox* setup_box);
	GList* (*get_vm_properties) (BoxesInstallerMedia* self);
	BoxesVMCreator* (*get_vm_creator) (BoxesInstallerMedia* self);
	OsinfoDeviceList* (*get_supported_devices) (BoxesInstallerMedia* self);
	guint64 (*get_installed_size) (BoxesInstallerMedia* self);
	gboolean (*get_need_user_input_for_vm_creation) (BoxesInstallerMedia* self);
	gboolean (*get_ready_to_create) (BoxesInstallerMedia* self);
	gboolean (*get_live) (BoxesInstallerMedia* self);
	gchar* (*get_architecture) (BoxesInstallerMedia* self);
};

struct _BoxesVmCreatorCreateVmData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesVMCreator* self;
	GCancellable* cancellable;
	BoxesLibvirtMachine* result;
	Block74Data* _data74_;
	GVirConnection* _tmp0_;
	GVirConnection* _tmp1_;
	GVirConnection* _tmp2_;
	gboolean _tmp3_;
	Block75Data* _data75_;
	BoxesApp* _tmp4_;
	gulong _tmp5_;
	gchar* title;
	gchar* name;
	gchar* _tmp6_;
	gchar* _tmp7_;
	BoxesInstallerMedia* _tmp8_;
	const gchar* _tmp9_;
	GCancellable* _tmp10_;
	GError* _error_;
	gchar* msg;
	const gchar* _tmp11_;
	gchar* _tmp12_;
	BoxesApp* _tmp13_;
	BoxesAppWindow* _tmp14_;
	BoxesAppWindow* _tmp15_;
	BoxesNotificationbar* _tmp16_;
	const gchar* _tmp17_;
	GdNotification* _tmp18_;
	GdNotification* _tmp19_;
	GError* _tmp20_;
	const gchar* _tmp21_;
	GVirStorageVol* volume;
	const gchar* _tmp22_;
	BoxesInstallerMedia* _tmp23_;
	OsinfoResources* _tmp24_;
	gint64 _tmp25_;
	gint64 _tmp26_;
	GVirStorageVol* _tmp27_;
	GVirConfigDomain* config;
	const gchar* _tmp28_;
	const gchar* _tmp29_;
	GVirStorageVol* _tmp30_;
	GCancellable* _tmp31_;
	GVirConfigDomain* _tmp32_;
	GVirDomain* domain;
	GVirConnection* _tmp33_;
	GVirConnection* _tmp34_;
	GVirConnection* _tmp35_;
	GVirConfigDomain* _tmp36_;
	GVirDomain* _tmp37_;
	GVirDomain* _tmp38_;
	BoxesLibvirtMachine* machine;
	BoxesLibvirtBroker* _tmp39_;
	BoxesLibvirtBroker* _tmp40_;
	BoxesApp* _tmp41_;
	BoxesCollectionSource* _tmp42_;
	BoxesCollectionSource* _tmp43_;
	BoxesApp* _tmp44_;
	GVirConnection* _tmp45_;
	GVirConnection* _tmp46_;
	GVirConnection* _tmp47_;
	GVirDomain* _tmp48_;
	BoxesLibvirtMachine* _tmp49_;
	BoxesLibvirtMachine* _tmp50_;
	BoxesLibvirtMachine* _tmp51_;
	GError * _inner_error_;
};

struct _Block76Data {
	int _ref_count_;
	BoxesVMCreator* self;
	BoxesLibvirtMachine* machine;
};

struct _BoxesUnattendedInstaller {
	BoxesInstallerMedia parent_instance;
	BoxesUnattendedInstallerPrivate * priv;
	BoxesUnattendedSetupBox* setup_box;
	GFile* disk_file;
	GFile* secondary_disk_file;
	GFile* kernel_file;
	GFile* initrd_file;
	OsinfoInstallConfig* config;
	OsinfoInstallScriptList* scripts;
};

struct _BoxesUnattendedInstallerClass {
	BoxesInstallerMediaClass parent_class;
};

struct _Block77Data {
	int _ref_count_;
	Block76Data * _data76_;
	gulong signal_id;
	BoxesAppWindow* window;
};

struct _BoxesCollectionItem {
	GObject parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	GObjectClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_LOGIN,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DISPLAY,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_SNAPSHOTS,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

typedef enum  {
	PROPERTY_CREATION_FLAG_NONE = 1 << 0,
	PROPERTY_CREATION_FLAG_NO_USB = 1 << 1
} PropertyCreationFlag;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
	gboolean suspend_at_exit;
	gboolean deleted;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*restart) (BoxesMachine* self);
	void (*disconnect_display) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
};

typedef enum  {
	BOXES_MACHINE_MACHINE_STATE_UNKNOWN,
	BOXES_MACHINE_MACHINE_STATE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_RUNNING,
	BOXES_MACHINE_MACHINE_STATE_PAUSED,
	BOXES_MACHINE_MACHINE_STATE_SAVED,
	BOXES_MACHINE_MACHINE_STATE_SLEEPING
} BoxesMachineMachineState;

struct _BoxesVmCreatorContinueInstallationData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesVMCreator* self;
	BoxesLibvirtMachine* machine;
	BoxesMediaManager* _tmp0_;
	BoxesMediaManager* _tmp1_;
	BoxesLibvirtMachine* _tmp2_;
	GVirConfigDomain* _tmp3_;
	GVirConfigDomain* _tmp4_;
	BoxesInstallerMedia* _tmp5_;
	BoxesInstallerMedia* _tmp6_;
	BoxesLibvirtMachine* _tmp7_;
	GVirConfigDomain* _tmp8_;
	GVirConfigDomain* _tmp9_;
	guint _tmp10_;
	gchar* name;
	BoxesLibvirtMachine* _tmp11_;
	GVirDomain* _tmp12_;
	GVirDomain* _tmp13_;
	const gchar* _tmp14_;
	gchar* _tmp15_;
	BoxesInstallerMedia* _tmp16_;
	BoxesLibvirtMachine* _tmp17_;
	BoxesInstallerMedia* _tmp18_;
	const gchar* _tmp19_;
	gboolean _tmp20_;
	BoxesInstallerMedia* _tmp21_;
	const gchar* _tmp22_;
	BoxesLibvirtMachine* _tmp23_;
	const gchar* _tmp24_;
	const gchar* _tmp25_;
	BoxesApp* _tmp26_;
	BoxesLibvirtMachine* _tmp27_;
	BoxesInstallerMedia* _tmp28_;
	const gchar* _tmp29_;
	BoxesLibvirtMachine* _tmp30_;
	gulong _tmp31_;
	BoxesLibvirtMachine* _tmp32_;
	BoxesLibvirtMachine* _tmp33_;
	BoxesLibvirtMachine* _tmp34_;
	gboolean _tmp35_;
	BoxesLibvirtMachine* _tmp36_;
	BoxesMachineMachineState _tmp37_;
	BoxesMachineMachineState _tmp38_;
	BoxesLibvirtMachine* _tmp39_;
	GVirConfigDomain* _tmp40_;
	GVirConfigDomain* _tmp41_;
	gboolean _tmp42_;
	BoxesLibvirtMachine* _tmp43_;
	GVirDomain* _tmp44_;
	GVirDomain* _tmp45_;
	GError* e;
	BoxesLibvirtMachine* _tmp46_;
	const gchar* _tmp47_;
	const gchar* _tmp48_;
	GError* _tmp49_;
	const gchar* _tmp50_;
	GError * _inner_error_;
};

struct _Block78Data {
	int _ref_count_;
	BoxesVMCreator* self;
	BoxesLibvirtMachine* machine;
};

typedef void (*BoxesAppUndoNotifyCallback) (void* user_data);
struct _BoxesVmCreatorGetStoragePoolData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesVMCreator* self;
	GVirStoragePool* result;
	GVirStoragePool* pool;
	GVirConnection* _tmp0_;
	GVirConnection* _tmp1_;
	GVirConnection* _tmp2_;
	GVirStoragePool* _tmp3_;
	GVirStoragePool* _tmp4_;
	GVirStoragePool* _tmp5_;
	GVirConfigStoragePool* config;
	GVirConfigStoragePool* _tmp6_;
	GVirStoragePool* _tmp7_;
	GVirConnection* _tmp8_;
	GVirConnection* _tmp9_;
	GVirConnection* _tmp10_;
	GVirConfigStoragePool* _tmp11_;
	GVirStoragePool* _tmp12_;
	GVirStoragePool* _tmp13_;
	GVirStoragePool* _tmp14_;
	GVirStoragePool* _tmp15_;
	GVirStoragePool* _tmp16_;
	GVirStoragePool* _tmp17_;
	GVirStoragePoolInfo* _tmp18_;
	GVirStoragePool* _tmp19_;
	GVirStoragePoolInfo* _tmp20_;
	GVirStoragePoolInfo* _tmp21_;
	GVirStoragePoolInfo* _tmp22_;
	GVirStoragePoolState _tmp23_;
	gboolean _tmp24_;
	gchar* _tmp25_;
	gchar* _tmp26_;
	gchar* _tmp27_;
	gchar* _tmp28_;
	GVirStoragePool* _tmp29_;
	GVirStoragePool* _tmp30_;
	GError * _inner_error_;
};

typedef enum  {
	BOXES_VM_CONFIGURATOR_ERROR_NO_GUEST_CAPS
} BoxesVMConfiguratorError;
#define BOXES_VM_CONFIGURATOR_ERROR boxes_vm_configurator_error_quark ()
struct _BoxesVmCreatorCreateDomainConfigData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesVMCreator* self;
	gchar* name;
	gchar* title;
	GVirStorageVol* volume;
	GCancellable* cancellable;
	GVirConfigDomain* result;
	GVirConfigCapabilities* caps;
	GVirConnection* _tmp0_;
	GVirConnection* _tmp1_;
	GVirConnection* _tmp2_;
	GCancellable* _tmp3_;
	GVirConfigCapabilities* _tmp4_;
	GVirConfigCapabilities* _tmp5_;
	const gchar* _tmp6_;
	GVirStorageVol* _tmp7_;
	const gchar* _tmp8_;
	GVirConfigDomain* config;
	BoxesInstallerMedia* _tmp9_;
	GVirConfigCapabilities* _tmp10_;
	GVirConfigDomain* _tmp11_;
	GVirConfigDomain* _tmp12_;
	const gchar* _tmp13_;
	GVirConfigDomain* _tmp14_;
	const gchar* _tmp15_;
	GError * _inner_error_;
};

struct _Block79Data {
	int _ref_count_;
	BoxesVMCreator* self;
	BoxesLibvirtMachine* machine;
};

struct _Block80Data {
	int _ref_count_;
	BoxesVMCreator* self;
	gint progress;
	BoxesLibvirtMachine* machine;
	gpointer _async_data_;
};

struct _BoxesVmCreatorUpdateInstallProgressData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesVMCreator* self;
	BoxesLibvirtMachine* machine;
	Block80Data* _data80_;
	BoxesLibvirtMachine* _tmp0_;
	GError* _error_;
	BoxesLibvirtMachine* _tmp1_;
	GVirStorageVol* _tmp2_;
	GVirStorageVol* _tmp3_;
	const gchar* _tmp4_;
	GError* _tmp5_;
	const gchar* _tmp6_;
	BoxesLibvirtMachine* _tmp7_;
	const gchar* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	GError * _inner_error_;
};

struct _BoxesVmCreatorCreateDomainNameAndTitleFromMediaData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesVMCreator* self;
	gchar* name;
	gchar* title;
	gchar* base_name;
	gchar* base_title;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	GVirStoragePool* pool;
	GVirStoragePool* _tmp4_;
	gint i;
	gboolean _tmp5_;
	gint _tmp6_;
	gboolean _tmp7_;
	gboolean _tmp8_;
	GVirConnection* _tmp9_;
	GVirConnection* _tmp10_;
	GVirConnection* _tmp11_;
	const gchar* _tmp12_;
	GVirDomain* _tmp13_;
	GVirDomain* _tmp14_;
	gboolean _tmp15_;
	GVirConnection* _tmp16_;
	GVirConnection* _tmp17_;
	GVirConnection* _tmp18_;
	const gchar* _tmp19_;
	GVirDomain* _tmp20_;
	GVirDomain* _tmp21_;
	const gchar* _tmp22_;
	GVirStorageVol* _tmp23_;
	GVirStorageVol* _tmp24_;
	gchar* _tmp25_;
	gchar* _tmp26_;
	gint _tmp27_;
	gchar* _tmp28_;
	gchar* _tmp29_;
	gchar* _tmp30_;
	gchar* _tmp31_;
	gchar* _tmp32_;
	gint _tmp33_;
	gchar* _tmp34_;
	gchar* _tmp35_;
	gchar* _tmp36_;
	GError * _inner_error_;
};

struct _BoxesVmCreatorCreateTargetVolumeData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesVMCreator* self;
	gchar* name;
	gint64 storage;
	GVirStorageVol* result;
	GVirStoragePool* pool;
	GVirStoragePool* _tmp0_;
	GVirConfigStorageVol* config;
	const gchar* _tmp1_;
	gint64 _tmp2_;
	GVirConfigStorageVol* _tmp3_;
	const gchar* _tmp4_;
	GVirStorageVol* volume;
	GVirStoragePool* _tmp5_;
	GVirConfigStorageVol* _tmp6_;
	GVirStorageVol* _tmp7_;
	const gchar* _tmp8_;
	GError * _inner_error_;
};

struct _BoxesParamSpecVMCreator {
	GParamSpec parent_instance;
};


static gpointer boxes_vm_creator_parent_class = NULL;
extern BoxesApp* boxes_app_app;

gpointer boxes_vm_creator_ref (gpointer instance);
void boxes_vm_creator_unref (gpointer instance);
GParamSpec* boxes_param_spec_vm_creator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_vm_creator (GValue* value, gpointer v_object);
void boxes_value_take_vm_creator (GValue* value, gpointer v_object);
gpointer boxes_value_get_vm_creator (const GValue* value);
GType boxes_vm_creator_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
GType boxes_installer_media_get_type (void) G_GNUC_CONST;
#define BOXES_VM_CREATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorPrivate))
enum  {
	BOXES_VM_CREATOR_DUMMY_PROPERTY
};
BoxesInstallerMedia* boxes_vm_creator_get_install_media (BoxesVMCreator* self);
void boxes_installer_media_clean_up (BoxesInstallerMedia* self);
#define BOXES_VM_CREATOR_INSTALL_COMPLETE_PERCENT 99
BoxesVMCreator* boxes_vm_creator_new (BoxesInstallerMedia* install_media);
BoxesVMCreator* boxes_vm_creator_construct (GType object_type, BoxesInstallerMedia* install_media);
void boxes_vm_creator_set_install_media (BoxesVMCreator* self, BoxesInstallerMedia* value);
BoxesVMCreator* boxes_vm_creator_new_for_install_completion (BoxesLibvirtMachine* machine);
BoxesVMCreator* boxes_vm_creator_construct_for_install_completion (GType object_type, BoxesLibvirtMachine* machine);
void boxes_vm_creator_continue_installation (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_vm_creator_continue_installation_finish (BoxesVMCreator* self, GAsyncResult* _res_);
static void boxes_vm_creator_create_vm_data_free (gpointer _data);
void boxes_vm_creator_create_vm (BoxesVMCreator* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesLibvirtMachine* boxes_vm_creator_create_vm_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error);
static gboolean boxes_vm_creator_create_vm_co (BoxesVmCreatorCreateVmData* _data_);
static Block74Data* block74_data_ref (Block74Data* _data74_);
static void block74_data_unref (void * _userdata_);
static GVirConnection* boxes_vm_creator_get_connection (BoxesVMCreator* self);
static Block75Data* block75_data_ref (Block75Data* _data75_);
static void block75_data_unref (void * _userdata_);
GType boxes_app_get_type (void) G_GNUC_CONST;
static void ___lambda95_ (Block75Data* _data75_);
static void ____lambda95__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_vm_creator_create_domain_name_and_title_from_media (BoxesVMCreator* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_vm_creator_create_domain_name_and_title_from_media_finish (BoxesVMCreator* self, GAsyncResult* _res_, gchar** name, gchar** title, GError** error);
static void boxes_vm_creator_create_vm_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
void boxes_installer_media_prepare_for_installation (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_installer_media_prepare_for_installation_finish (BoxesInstallerMedia* self, GAsyncResult* _res_, GError** error);
GType boxes_app_window_get_type (void) G_GNUC_CONST;
BoxesAppWindow* boxes_app_get_main_window (BoxesApp* self);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
GdNotification* boxes_notificationbar_display_error (BoxesNotificationbar* self, const gchar* message, gint timeout);
#define BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT 6
static void boxes_vm_creator_create_target_volume (BoxesVMCreator* self, const gchar* name, gint64 storage, GAsyncReadyCallback _callback_, gpointer _user_data_);
static GVirStorageVol* boxes_vm_creator_create_target_volume_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error);
void boxes_vm_creator_create_domain_config (BoxesVMCreator* self, const gchar* name, const gchar* title, GVirStorageVol* volume, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
GVirConfigDomain* boxes_vm_creator_create_domain_config_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error);
GType boxes_broker_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_broker_get_type (void) G_GNUC_CONST;
BoxesLibvirtBroker* boxes_libvirt_broker_get_default (void);
BoxesLibvirtMachine* boxes_libvirt_broker_add_domain (BoxesLibvirtBroker* self, BoxesCollectionSource* source, GVirConnection* connection, GVirDomain* domain, GError** error);
BoxesCollectionSource* boxes_app_get_default_source (BoxesApp* self);
GVirConnection* boxes_app_get_default_connection (BoxesApp* self);
void boxes_libvirt_machine_set_vm_creator (BoxesLibvirtMachine* self, BoxesVMCreator* value);
void boxes_vm_creator_launch_vm (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GError** error);
static void boxes_vm_creator_real_launch_vm (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GError** error);
static Block76Data* block76_data_ref (Block76Data* _data76_);
static void block76_data_unref (void * _userdata_);
GType boxes_unattended_installer_get_type (void) G_GNUC_CONST;
GType boxes_unattended_setup_box_get_type (void) G_GNUC_CONST;
gboolean boxes_unattended_setup_box_get_express_install (BoxesUnattendedSetupBox* self);
static Block77Data* block77_data_ref (Block77Data* _data77_);
static void block77_data_unref (void * _userdata_);
static void ___lambda96_ (Block77Data* _data77_);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
void boxes_app_window_select_item (BoxesAppWindow* self, BoxesCollectionItem* item);
static void ____lambda96__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
GVirDomain* boxes_libvirt_machine_get_domain (BoxesLibvirtMachine* self);
static void boxes_vm_creator_on_machine_state_changed (BoxesVMCreator* self, GObject* object, GParamSpec* pspec);
static void _boxes_vm_creator_on_machine_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType property_creation_flag_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
void boxes_vm_creator_update_machine_info (BoxesVMCreator* self, BoxesLibvirtMachine* machine);
static void boxes_vm_creator_real_continue_installation_data_free (gpointer _data);
static void boxes_vm_creator_real_continue_installation (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_vm_creator_real_continue_installation_co (BoxesVmCreatorContinueInstallationData* _data_);
GType boxes_media_manager_get_type (void) G_GNUC_CONST;
BoxesMediaManager* boxes_media_manager_get_instance (void);
void boxes_media_manager_create_installer_media_from_config (BoxesMediaManager* self, GVirConfigDomain* config, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesInstallerMedia* boxes_media_manager_create_installer_media_from_config_finish (BoxesMediaManager* self, GAsyncResult* _res_);
GVirConfigDomain* boxes_libvirt_machine_get_domain_config (BoxesLibvirtMachine* self);
static void boxes_vm_creator_continue_installation_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
guint boxes_vm_configurator_get_num_reboots (GVirConfigDomain* domain);
static void boxes_vm_creator_set_num_reboots (BoxesVMCreator* self, guint value);
void boxes_vm_creator_set_post_install_config (BoxesVMCreator* self, BoxesLibvirtMachine* machine);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
void boxes_app_delete_machine (BoxesApp* self, BoxesMachine* machine, gboolean by_user);
void boxes_installer_media_prepare_to_continue_installation (BoxesInstallerMedia* self, const gchar* vm_name);
GType boxes_machine_machine_state_get_type (void) G_GNUC_CONST;
BoxesMachineMachineState boxes_machine_get_state (BoxesMachine* self);
gboolean boxes_vm_configurator_is_install_config (GVirConfigDomain* domain);
static Block78Data* block78_data_ref (Block78Data* _data78_);
static void block78_data_unref (void * _userdata_);
gboolean boxes_machine_is_on (BoxesMachine* self);
static void boxes_vm_creator_increment_num_reboots (BoxesVMCreator* self, BoxesLibvirtMachine* machine);
static gboolean boxes_vm_creator_guest_installed_os (BoxesVMCreator* self, BoxesLibvirtMachine* machine);
gboolean boxes_vm_configurator_is_live_config (GVirConfigDomain* domain);
static gboolean boxes_vm_creator_install_trackable (BoxesVMCreator* self);
void boxes_machine_set_info (BoxesMachine* self, const gchar* value);
static void ____lambda83_ (Block78Data* _data78_);
static void _____lambda83__boxes_app_undo_notify_callback (gpointer self);
void boxes_app_delete_machines_undoable (BoxesApp* self, GList* items, const gchar* message, BoxesAppUndoNotifyCallback undo_notify_callback, void* undo_notify_callback_target, GDestroyNotify undo_notify_callback_target_destroy_notify);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
static void boxes_vm_creator_real_update_machine_info (BoxesVMCreator* self, BoxesLibvirtMachine* machine);
static void boxes_vm_creator_track_install_progress (BoxesVMCreator* self, BoxesLibvirtMachine* machine);
void boxes_vm_configurator_post_install_setup (GVirConfigDomain* domain, BoxesInstallerMedia* install_media);
static void boxes_vm_creator_get_storage_pool_data_free (gpointer _data);
void boxes_vm_creator_get_storage_pool (BoxesVMCreator* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
GVirStoragePool* boxes_vm_creator_get_storage_pool_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error);
static gboolean boxes_vm_creator_get_storage_pool_co (BoxesVmCreatorGetStoragePoolData* _data_);
GVirStoragePool* boxes_get_storage_pool (GVirConnection* connection);
GVirConfigStoragePool* boxes_vm_configurator_get_pool_config (GError** error);
static void boxes_vm_creator_get_storage_pool_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _vala_GVirStoragePoolInfo_free (GVirStoragePoolInfo* self);
static void boxes_vm_creator_real_create_domain_config_data_free (gpointer _data);
static void boxes_vm_creator_real_create_domain_config (BoxesVMCreator* self, const gchar* name, const gchar* title, GVirStorageVol* volume, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_vm_creator_real_create_domain_config_co (BoxesVmCreatorCreateDomainConfigData* _data_);
static void boxes_vm_creator_create_domain_config_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
GQuark boxes_vm_configurator_error_quark (void);
GVirConfigDomain* boxes_vm_configurator_create_domain_config (BoxesInstallerMedia* install_media, const gchar* target_path, GVirConfigCapabilities* caps, GError** error);
void boxes_vm_creator_create_domain_base_name_and_title (BoxesVMCreator* self, gchar** base_name, gchar** base_title);
static void boxes_vm_creator_real_create_domain_base_name_and_title (BoxesVMCreator* self, gchar** base_name, gchar** base_title);
static guint boxes_vm_creator_get_num_reboots (BoxesVMCreator* self);
void boxes_vm_configurator_set_num_reboots (GVirConfigDomain* domain, BoxesInstallerMedia* install_media, guint num_reboots);
GVirStorageVol* boxes_libvirt_machine_get_storage_volume (BoxesLibvirtMachine* self);
static gint boxes_vm_creator_get_progress (BoxesVMCreator* self, GVirStorageVol* volume, GError** error);
static void _vala_GVirStorageVolInfo_free (GVirStorageVolInfo* self);
static Block79Data* block79_data_ref (Block79Data* _data79_);
static void block79_data_unref (void * _userdata_);
static gboolean __lambda86_ (Block79Data* _data79_);
static void boxes_vm_creator_update_install_progress (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_vm_creator_update_install_progress_finish (BoxesVMCreator* self, GAsyncResult* _res_);
static gboolean ___lambda86__gsource_func (gpointer self);
static void boxes_vm_creator_update_install_progress_data_free (gpointer _data);
static gboolean boxes_vm_creator_update_install_progress_co (BoxesVmCreatorUpdateInstallProgressData* _data_);
static Block80Data* block80_data_ref (Block80Data* _data80_);
static void block80_data_unref (void * _userdata_);
static void ___lambda87_ (Block80Data* _data80_, GError** error);
static void ____lambda87__boxes_run_in_thread_func (gpointer self, GError** error);
static void boxes_vm_creator_update_install_progress_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
guint64 boxes_installer_media_get_installed_size (BoxesInstallerMedia* self);
static void boxes_vm_creator_create_domain_name_and_title_from_media_data_free (gpointer _data);
static gboolean boxes_vm_creator_create_domain_name_and_title_from_media_co (BoxesVmCreatorCreateDomainNameAndTitleFromMediaData* _data_);
static void boxes_vm_creator_create_domain_name_and_title_from_media_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_vm_creator_create_target_volume_data_free (gpointer _data);
static gboolean boxes_vm_creator_create_target_volume_co (BoxesVmCreatorCreateTargetVolumeData* _data_);
static void boxes_vm_creator_create_target_volume_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
GVirConfigStorageVol* boxes_vm_configurator_create_volume_config (const gchar* name, gint64 storage, GError** error);
static void boxes_vm_creator_finalize (BoxesVMCreator* obj);


BoxesVMCreator* boxes_vm_creator_construct (GType object_type, BoxesInstallerMedia* install_media) {
	BoxesVMCreator* self = NULL;
	BoxesInstallerMedia* _tmp0_ = NULL;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (install_media != NULL, NULL);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self = (BoxesVMCreator*) g_type_create_instance (object_type);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = install_media;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_set_install_media (self, _tmp0_);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return self;
#line 1043 "vm-creator.c"
}


BoxesVMCreator* boxes_vm_creator_new (BoxesInstallerMedia* install_media) {
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return boxes_vm_creator_construct (BOXES_TYPE_VM_CREATOR, install_media);
#line 1050 "vm-creator.c"
}


BoxesVMCreator* boxes_vm_creator_construct_for_install_completion (GType object_type, BoxesLibvirtMachine* machine) {
	BoxesVMCreator* self = NULL;
	BoxesLibvirtMachine* _tmp0_ = NULL;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (machine != NULL, NULL);
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self = (BoxesVMCreator*) g_type_create_instance (object_type);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = machine;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_continue_installation (self, _tmp0_, NULL, NULL);
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return self;
#line 1067 "vm-creator.c"
}


BoxesVMCreator* boxes_vm_creator_new_for_install_completion (BoxesLibvirtMachine* machine) {
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return boxes_vm_creator_construct_for_install_completion (BOXES_TYPE_VM_CREATOR, machine);
#line 1074 "vm-creator.c"
}


static void boxes_vm_creator_create_vm_data_free (gpointer _data) {
	BoxesVmCreatorCreateVmData* _data_;
	_data_ = _data;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->result);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_boxes_vm_creator_unref0 (_data_->self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_slice_free (BoxesVmCreatorCreateVmData, _data_);
#line 1089 "vm-creator.c"
}


static gpointer _boxes_vm_creator_ref0 (gpointer self) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return self ? boxes_vm_creator_ref (self) : NULL;
#line 1096 "vm-creator.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return self ? g_object_ref (self) : NULL;
#line 1103 "vm-creator.c"
}


void boxes_vm_creator_create_vm (BoxesVMCreator* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesVmCreatorCreateVmData* _data_;
	BoxesVMCreator* _tmp0_ = NULL;
	GCancellable* _tmp1_ = NULL;
	GCancellable* _tmp2_ = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_slice_new0 (BoxesVmCreatorCreateVmData);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_vm_creator_create_vm);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_vm_creator_create_vm_data_free);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _boxes_vm_creator_ref0 (self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = cancellable;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->cancellable = _tmp2_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_vm_co (_data_);
#line 1132 "vm-creator.c"
}


BoxesLibvirtMachine* boxes_vm_creator_create_vm_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error) {
	BoxesLibvirtMachine* result;
	BoxesVmCreatorCreateVmData* _data_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return NULL;
#line 1143 "vm-creator.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	result = _data_->result;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->result = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 1153 "vm-creator.c"
}


static Block74Data* block74_data_ref (Block74Data* _data74_) {
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_atomic_int_inc (&_data74_->_ref_count_);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return _data74_;
#line 1162 "vm-creator.c"
}


static void block74_data_unref (void * _userdata_) {
	Block74Data* _data74_;
	_data74_ = (Block74Data*) _userdata_;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_atomic_int_dec_and_test (&_data74_->_ref_count_)) {
#line 1171 "vm-creator.c"
		BoxesVMCreator* self;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		self = _data74_->self;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_boxes_vm_creator_unref0 (self);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_slice_free (Block74Data, _data74_);
#line 1179 "vm-creator.c"
	}
}


static Block75Data* block75_data_ref (Block75Data* _data75_) {
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_atomic_int_inc (&_data75_->_ref_count_);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return _data75_;
#line 1189 "vm-creator.c"
}


static void block75_data_unref (void * _userdata_) {
	Block75Data* _data75_;
	_data75_ = (Block75Data*) _userdata_;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_atomic_int_dec_and_test (&_data75_->_ref_count_)) {
#line 1198 "vm-creator.c"
		BoxesVMCreator* self;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		self = _data75_->_data74_->self;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block74_data_unref (_data75_->_data74_);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data75_->_data74_ = NULL;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_slice_free (Block75Data, _data75_);
#line 1208 "vm-creator.c"
	}
}


static void ___lambda95_ (Block75Data* _data75_) {
	Block74Data* _data74_;
	BoxesVMCreator* self;
	BoxesApp* _tmp0_ = NULL;
	gulong _tmp1_ = 0UL;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data74_ = _data75_->_data74_;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self = _data74_->self;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_vm_co (_data74_->_async_data_);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = boxes_app_app;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = _data75_->handler;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_signal_handler_disconnect ((GObject*) _tmp0_, _tmp1_);
#line 1230 "vm-creator.c"
}


static void ____lambda95__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	___lambda95_ (self);
#line 1237 "vm-creator.c"
}


static void boxes_vm_creator_create_vm_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesVmCreatorCreateVmData* _data_;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = _user_data_;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_source_object_ = source_object;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_res_ = _res_;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_vm_co (_data_);
#line 1251 "vm-creator.c"
}


static gboolean boxes_vm_creator_create_vm_co (BoxesVmCreatorCreateVmData* _data_) {
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	switch (_data_->_state_) {
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 0:
#line 1260 "vm-creator.c"
		goto _state_0;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 1:
#line 1264 "vm-creator.c"
		goto _state_1;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 2:
#line 1268 "vm-creator.c"
		goto _state_2;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 3:
#line 1272 "vm-creator.c"
		goto _state_3;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 4:
#line 1276 "vm-creator.c"
		goto _state_4;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 5:
#line 1280 "vm-creator.c"
		goto _state_5;
		default:
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_assert_not_reached ();
#line 1285 "vm-creator.c"
	}
	_state_0:
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data74_ = g_slice_new0 (Block74Data);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data74_->_ref_count_ = 1;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data74_->self = boxes_vm_creator_ref (_data_->self);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data74_->_async_data_ = _data_;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = NULL;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = boxes_vm_creator_get_connection (_data_->self);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = NULL;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = _data_->_tmp0_;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = NULL;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = _data_->_tmp1_;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = FALSE;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = _data_->_tmp2_ == NULL;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->_tmp2_);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_tmp3_) {
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data75_ = g_slice_new0 (Block75Data);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data75_->_ref_count_ = 1;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data75_->_data74_ = block74_data_ref (_data_->_data74_);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data75_->handler = (gulong) 0;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp4_ = NULL;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp4_ = boxes_app_app;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp5_ = 0UL;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp5_ = g_signal_connect_data ((GObject*) _data_->_tmp4_, "notify::default-connection", (GCallback) ____lambda95__g_object_notify, block75_data_ref (_data_->_data75_), (GClosureNotify) block75_data_unref, 0);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data75_->handler = _data_->_tmp5_;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_state_ = 1;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1338 "vm-creator.c"
		_state_1:
		;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block75_data_unref (_data_->_data75_);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data75_ = NULL;
#line 1345 "vm-creator.c"
	}
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp6_ = NULL;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp7_ = NULL;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_state_ = 2;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_domain_name_and_title_from_media (_data_->self, boxes_vm_creator_create_vm_ready, _data_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 1357 "vm-creator.c"
	_state_2:
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_domain_name_and_title_from_media_finish (_data_->self, _data_->_res_, &_data_->_tmp6_, &_data_->_tmp7_, &_data_->_inner_error_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->name = _data_->_tmp6_;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->title);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->title = _data_->_tmp7_;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block74_data_unref (_data_->_data74_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data74_ = NULL;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1387 "vm-creator.c"
		} else {
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1391 "vm-creator.c"
		}
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1397 "vm-creator.c"
	}
	{
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp8_ = NULL;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp8_ = _data_->self->priv->_install_media;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp9_ = NULL;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp9_ = _data_->name;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp10_ = NULL;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp10_ = _data_->cancellable;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_state_ = 3;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_installer_media_prepare_for_installation (_data_->_tmp8_, _data_->_tmp9_, _data_->_tmp10_, boxes_vm_creator_create_vm_ready, _data_);
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1418 "vm-creator.c"
		_state_3:
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_installer_media_prepare_for_installation_finish (_data_->_tmp8_, _data_->_res_, &_data_->_inner_error_);
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 1424 "vm-creator.c"
			goto __catch97_g_error;
		}
	}
	goto __finally97;
	__catch97_g_error:
	{
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_inner_error_ = NULL;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp11_ = NULL;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp11_ = _ ("An error occurred during installation preparation. Express Install dis" \
"abled.");
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp12_ = NULL;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp12_ = g_strdup (_data_->_tmp11_);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->msg = _data_->_tmp12_;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp13_ = NULL;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp13_ = boxes_app_app;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp14_ = NULL;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp14_ = boxes_app_get_main_window (_data_->_tmp13_);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp15_ = NULL;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp15_ = _data_->_tmp14_;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp16_ = NULL;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp16_ = _data_->_tmp15_->notificationbar;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp17_ = NULL;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp17_ = _data_->msg;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp18_ = NULL;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp18_ = boxes_notificationbar_display_error (_data_->_tmp16_, _data_->_tmp17_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp19_ = NULL;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp19_ = _data_->_tmp18_;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->_tmp19_);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp20_ = NULL;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp20_ = _data_->_error_;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp21_ = NULL;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp21_ = _data_->_tmp20_->message;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_debug ("vm-creator.vala:50: Disabling unattended installation: %s", _data_->_tmp21_);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->msg);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_error_free0 (_data_->_error_);
#line 1489 "vm-creator.c"
	}
	__finally97:
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block74_data_unref (_data_->_data74_);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data74_ = NULL;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1510 "vm-creator.c"
		} else {
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1514 "vm-creator.c"
		}
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1520 "vm-creator.c"
	}
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp22_ = NULL;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp22_ = _data_->name;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp23_ = NULL;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp23_ = _data_->self->priv->_install_media;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp24_ = NULL;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp24_ = _data_->_tmp23_->resources;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp25_ = 0LL;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp25_ = osinfo_resources_get_storage (_data_->_tmp24_);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp26_ = 0LL;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp26_ = _data_->_tmp25_;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_state_ = 4;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_target_volume (_data_->self, _data_->_tmp22_, _data_->_tmp26_, boxes_vm_creator_create_vm_ready, _data_);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 1548 "vm-creator.c"
	_state_4:
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp27_ = NULL;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp27_ = boxes_vm_creator_create_target_volume_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->volume = _data_->_tmp27_;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block74_data_unref (_data_->_data74_);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data74_ = NULL;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1574 "vm-creator.c"
		} else {
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1578 "vm-creator.c"
		}
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1584 "vm-creator.c"
	}
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp28_ = NULL;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp28_ = _data_->name;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp29_ = NULL;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp29_ = _data_->title;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp30_ = NULL;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp30_ = _data_->volume;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp31_ = NULL;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp31_ = _data_->cancellable;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_state_ = 5;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_domain_config (_data_->self, _data_->_tmp28_, _data_->_tmp29_, _data_->_tmp30_, _data_->_tmp31_, boxes_vm_creator_create_vm_ready, _data_);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 1608 "vm-creator.c"
	_state_5:
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp32_ = NULL;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp32_ = boxes_vm_creator_create_domain_config_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->config = _data_->_tmp32_;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->volume);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block74_data_unref (_data_->_data74_);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data74_ = NULL;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1636 "vm-creator.c"
		} else {
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1640 "vm-creator.c"
		}
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1646 "vm-creator.c"
	}
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp33_ = NULL;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp33_ = boxes_vm_creator_get_connection (_data_->self);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp34_ = NULL;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp34_ = _data_->_tmp33_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp35_ = NULL;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp35_ = _data_->_tmp34_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp36_ = NULL;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp36_ = _data_->config;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp37_ = NULL;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp37_ = gvir_connection_create_domain (_data_->_tmp35_, _data_->_tmp36_, &_data_->_inner_error_);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp38_ = NULL;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp38_ = _data_->_tmp37_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->_tmp35_);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->domain = _data_->_tmp38_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->config);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->volume);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block74_data_unref (_data_->_data74_);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data74_ = NULL;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1698 "vm-creator.c"
		} else {
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1702 "vm-creator.c"
		}
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1708 "vm-creator.c"
	}
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp39_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp39_ = boxes_libvirt_broker_get_default ();
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp40_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp40_ = _data_->_tmp39_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp41_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp41_ = boxes_app_app;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp42_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp42_ = boxes_app_get_default_source (_data_->_tmp41_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp43_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp43_ = _data_->_tmp42_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp44_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp44_ = boxes_app_app;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp45_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp45_ = boxes_app_get_default_connection (_data_->_tmp44_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp46_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp46_ = _data_->_tmp45_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp47_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp47_ = _data_->_tmp46_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp48_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp48_ = _data_->domain;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp49_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp49_ = boxes_libvirt_broker_add_domain (_data_->_tmp40_, _data_->_tmp43_, _data_->_tmp47_, _data_->_tmp48_, &_data_->_inner_error_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp50_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp50_ = _data_->_tmp49_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->_tmp47_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->_tmp40_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->machine = _data_->_tmp50_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->domain);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->config);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->volume);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block74_data_unref (_data_->_data74_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data74_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1788 "vm-creator.c"
		} else {
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1792 "vm-creator.c"
		}
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1798 "vm-creator.c"
	}
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp51_ = NULL;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp51_ = _data_->machine;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_libvirt_machine_set_vm_creator (_data_->_tmp51_, _data_->self);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->result = _data_->machine;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->domain);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->config);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->volume);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->title);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	block74_data_unref (_data_->_data74_);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data74_ = NULL;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1826 "vm-creator.c"
	} else {
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1830 "vm-creator.c"
	}
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->machine);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->domain);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->config);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->volume);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->title);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	block74_data_unref (_data_->_data74_);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data74_ = NULL;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1856 "vm-creator.c"
	} else {
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1860 "vm-creator.c"
	}
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 1866 "vm-creator.c"
}


static Block76Data* block76_data_ref (Block76Data* _data76_) {
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_atomic_int_inc (&_data76_->_ref_count_);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return _data76_;
#line 1875 "vm-creator.c"
}


static void block76_data_unref (void * _userdata_) {
	Block76Data* _data76_;
	_data76_ = (Block76Data*) _userdata_;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_atomic_int_dec_and_test (&_data76_->_ref_count_)) {
#line 1884 "vm-creator.c"
		BoxesVMCreator* self;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		self = _data76_->self;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data76_->machine);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_boxes_vm_creator_unref0 (self);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_slice_free (Block76Data, _data76_);
#line 1894 "vm-creator.c"
	}
}


static Block77Data* block77_data_ref (Block77Data* _data77_) {
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_atomic_int_inc (&_data77_->_ref_count_);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return _data77_;
#line 1904 "vm-creator.c"
}


static void block77_data_unref (void * _userdata_) {
	Block77Data* _data77_;
	_data77_ = (Block77Data*) _userdata_;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_atomic_int_dec_and_test (&_data77_->_ref_count_)) {
#line 1913 "vm-creator.c"
		BoxesVMCreator* self;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		self = _data77_->_data76_->self;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data77_->window);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block76_data_unref (_data77_->_data76_);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data77_->_data76_ = NULL;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_slice_free (Block77Data, _data77_);
#line 1925 "vm-creator.c"
	}
}


static void ___lambda96_ (Block77Data* _data77_) {
	Block76Data* _data76_;
	BoxesVMCreator* self;
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesUIState _tmp1_ = 0;
	BoxesUIState _tmp2_ = 0;
	BoxesAppWindow* _tmp3_ = NULL;
	BoxesLibvirtMachine* _tmp4_ = NULL;
	BoxesAppWindow* _tmp5_ = NULL;
	gulong _tmp6_ = 0UL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data76_ = _data77_->_data76_;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self = _data76_->self;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _data77_->window;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp0_);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _tmp1_;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp2_ != BOXES_UI_STATE_COLLECTION) {
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return;
#line 1954 "vm-creator.c"
	}
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = _data77_->window;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp4_ = _data76_->machine;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_app_window_select_item (_tmp3_, (BoxesCollectionItem*) _tmp4_);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp5_ = _data77_->window;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp6_ = _data77_->signal_id;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_signal_handler_disconnect ((GObject*) _tmp5_, _tmp6_);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return;
#line 1970 "vm-creator.c"
}


static void ____lambda96__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	___lambda96_ (self);
#line 1977 "vm-creator.c"
}


static void _boxes_vm_creator_on_machine_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_on_machine_state_changed ((BoxesVMCreator*) self, _sender, pspec);
#line 1984 "vm-creator.c"
}


static void boxes_vm_creator_real_launch_vm (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GError** error) {
	Block76Data* _data76_;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	BoxesLibvirtMachine* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	BoxesInstallerMedia* _tmp3_ = NULL;
	BoxesLibvirtMachine* _tmp17_ = NULL;
	gulong _tmp18_ = 0UL;
	BoxesLibvirtMachine* _tmp19_ = NULL;
	BoxesBoxConfig* _tmp20_ = NULL;
	gint64 _tmp21_ = 0LL;
	BoxesLibvirtMachine* _tmp22_ = NULL;
	GError * _inner_error_ = NULL;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (machine != NULL);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data76_ = g_slice_new0 (Block76Data);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data76_->_ref_count_ = 1;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data76_->self = boxes_vm_creator_ref (self);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = machine;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data76_->machine);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data76_->machine = _tmp1_;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = self->priv->_install_media;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, BOXES_TYPE_UNATTENDED_INSTALLER)) {
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp2_ = TRUE;
#line 2023 "vm-creator.c"
	} else {
		BoxesInstallerMedia* _tmp4_ = NULL;
		BoxesUnattendedSetupBox* _tmp5_ = NULL;
		gboolean _tmp6_ = FALSE;
		gboolean _tmp7_ = FALSE;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp4_ = self->priv->_install_media;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp5_ = (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, BOXES_TYPE_UNATTENDED_INSTALLER) ? ((BoxesUnattendedInstaller*) _tmp4_) : NULL)->setup_box;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp6_ = boxes_unattended_setup_box_get_express_install (_tmp5_);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp7_ = _tmp6_;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp2_ = !_tmp7_;
#line 2039 "vm-creator.c"
	}
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp2_) {
#line 2043 "vm-creator.c"
		Block77Data* _data77_;
		BoxesApp* _tmp8_ = NULL;
		BoxesAppWindow* _tmp9_ = NULL;
		BoxesAppWindow* _tmp10_ = NULL;
		BoxesAppWindow* _tmp11_ = NULL;
		BoxesAppWindow* _tmp12_ = NULL;
		gulong _tmp13_ = 0UL;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data77_ = g_slice_new0 (Block77Data);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data77_->_ref_count_ = 1;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data77_->_data76_ = block76_data_ref (_data76_);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data77_->signal_id = (gulong) 0;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp8_ = boxes_app_app;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp9_ = boxes_app_get_main_window (_tmp8_);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp10_ = _tmp9_;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp11_ = _g_object_ref0 (_tmp10_);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data77_->window = _tmp11_;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp12_ = _data77_->window;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp13_ = g_signal_connect_data ((GObject*) _tmp12_, "notify::ui-state", (GCallback) ____lambda96__g_object_notify, block77_data_ref (_data77_), (GClosureNotify) block77_data_unref, 0);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data77_->signal_id = _tmp13_;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block77_data_unref (_data77_);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data77_ = NULL;
#line 2079 "vm-creator.c"
	} else {
		BoxesLibvirtMachine* _tmp14_ = NULL;
		GVirDomain* _tmp15_ = NULL;
		GVirDomain* _tmp16_ = NULL;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp14_ = _data76_->machine;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp15_ = boxes_libvirt_machine_get_domain (_tmp14_);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp16_ = _tmp15_;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		gvir_domain_start (_tmp16_, (guint) 0, &_inner_error_);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_propagate_error (error, _inner_error_);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			block76_data_unref (_data76_);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data76_ = NULL;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return;
#line 2102 "vm-creator.c"
		}
	}
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp17_ = _data76_->machine;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp18_ = g_signal_connect ((GObject*) _tmp17_, "notify::state", (GCallback) _boxes_vm_creator_on_machine_state_changed_g_object_notify, self);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self->priv->state_changed_id = _tmp18_;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp19_ = _data76_->machine;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp20_ = ((BoxesMachine*) _tmp19_)->config;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp21_ = g_get_real_time ();
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_box_config_set_access_last_time (_tmp20_, _tmp21_);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp22_ = _data76_->machine;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_update_machine_info (self, _tmp22_);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	block76_data_unref (_data76_);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data76_ = NULL;
#line 2127 "vm-creator.c"
}


void boxes_vm_creator_launch_vm (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GError** error) {
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	BOXES_VM_CREATOR_GET_CLASS (self)->launch_vm (self, machine, error);
#line 2136 "vm-creator.c"
}


static void boxes_vm_creator_real_continue_installation_data_free (gpointer _data) {
	BoxesVmCreatorContinueInstallationData* _data_;
	_data_ = _data;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->machine);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_boxes_vm_creator_unref0 (_data_->self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_slice_free (BoxesVmCreatorContinueInstallationData, _data_);
#line 2149 "vm-creator.c"
}


static void boxes_vm_creator_real_continue_installation (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesVmCreatorContinueInstallationData* _data_;
	BoxesVMCreator* _tmp0_ = NULL;
	BoxesLibvirtMachine* _tmp1_ = NULL;
	BoxesLibvirtMachine* _tmp2_ = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_slice_new0 (BoxesVmCreatorContinueInstallationData);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_vm_creator_real_continue_installation);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_vm_creator_real_continue_installation_data_free);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _boxes_vm_creator_ref0 (self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = machine;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->machine);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->machine = _tmp2_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_real_continue_installation_co (_data_);
#line 2178 "vm-creator.c"
}


static void boxes_vm_creator_real_continue_installation_finish (BoxesVMCreator* self, GAsyncResult* _res_) {
	BoxesVmCreatorContinueInstallationData* _data_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 2186 "vm-creator.c"
}


static void boxes_vm_creator_continue_installation_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesVmCreatorContinueInstallationData* _data_;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = _user_data_;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_source_object_ = source_object;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_res_ = _res_;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_real_continue_installation_co (_data_);
#line 2200 "vm-creator.c"
}


static gboolean boxes_vm_creator_real_continue_installation_co (BoxesVmCreatorContinueInstallationData* _data_) {
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	switch (_data_->_state_) {
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 0:
#line 2209 "vm-creator.c"
		goto _state_0;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 1:
#line 2213 "vm-creator.c"
		goto _state_1;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 2:
#line 2217 "vm-creator.c"
		goto _state_2;
		default:
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_assert_not_reached ();
#line 2222 "vm-creator.c"
	}
	_state_0:
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = NULL;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = boxes_media_manager_get_instance ();
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = NULL;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = _data_->_tmp0_;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = NULL;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = _data_->machine;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = NULL;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = boxes_libvirt_machine_get_domain_config (_data_->_tmp2_);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp4_ = NULL;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp4_ = _data_->_tmp3_;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_state_ = 1;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_media_manager_create_installer_media_from_config (_data_->_tmp1_, _data_->_tmp4_, boxes_vm_creator_continue_installation_ready, _data_);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 2251 "vm-creator.c"
	_state_1:
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp5_ = NULL;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp5_ = boxes_media_manager_create_installer_media_from_config_finish (_data_->_tmp1_, _data_->_res_);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp6_ = NULL;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp6_ = _data_->_tmp5_;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_set_install_media (_data_->self, _data_->_tmp6_);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->_tmp6_);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->_tmp1_);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp7_ = NULL;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp7_ = _data_->machine;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp8_ = NULL;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp8_ = boxes_libvirt_machine_get_domain_config (_data_->_tmp7_);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp9_ = NULL;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp9_ = _data_->_tmp8_;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp10_ = 0U;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp10_ = boxes_vm_configurator_get_num_reboots (_data_->_tmp9_);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_set_num_reboots (_data_->self, _data_->_tmp10_);
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp11_ = NULL;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp11_ = _data_->machine;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp12_ = NULL;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp12_ = boxes_libvirt_machine_get_domain (_data_->_tmp11_);
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp13_ = NULL;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp13_ = _data_->_tmp12_;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp14_ = NULL;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp14_ = gvir_domain_get_name (_data_->_tmp13_);
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp15_ = NULL;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp15_ = g_strdup (_data_->_tmp14_);
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->name = _data_->_tmp15_;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp16_ = NULL;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp16_ = _data_->self->priv->_install_media;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_tmp16_ == NULL) {
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_debug ("vm-creator.vala:96: Could not find needed install media to continue in" \
"stallation, give up on automatic installation");
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp17_ = NULL;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp17_ = _data_->machine;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_creator_set_post_install_config (_data_->self, _data_->_tmp17_);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2327 "vm-creator.c"
		} else {
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2331 "vm-creator.c"
		}
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 2337 "vm-creator.c"
	}
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp18_ = NULL;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp18_ = _data_->self->priv->_install_media;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp19_ = NULL;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp19_ = _data_->_tmp18_->device_file;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp20_ = FALSE;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp20_ = g_file_test (_data_->_tmp19_, G_FILE_TEST_EXISTS);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (!_data_->_tmp20_) {
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp21_ = NULL;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp21_ = _data_->self->priv->_install_media;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp22_ = NULL;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp22_ = _data_->_tmp21_->device_file;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp23_ = NULL;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp23_ = _data_->machine;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp24_ = NULL;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp24_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->_tmp23_);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp25_ = NULL;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp25_ = _data_->_tmp24_;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_warning ("vm-creator.vala:102: Source installer media '%s' no longer exists. Del" \
"eting machine '%s'..", _data_->_tmp22_, _data_->_tmp25_);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp26_ = NULL;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp26_ = boxes_app_app;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp27_ = NULL;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp27_ = _data_->machine;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_app_delete_machine (_data_->_tmp26_, (BoxesMachine*) _data_->_tmp27_, TRUE);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2391 "vm-creator.c"
		} else {
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2395 "vm-creator.c"
		}
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 2401 "vm-creator.c"
	}
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp28_ = NULL;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp28_ = _data_->self->priv->_install_media;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp29_ = NULL;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp29_ = _data_->name;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_installer_media_prepare_to_continue_installation (_data_->_tmp28_, _data_->_tmp29_);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp30_ = NULL;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp30_ = _data_->machine;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp31_ = 0UL;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp31_ = g_signal_connect ((GObject*) _data_->_tmp30_, "notify::state", (GCallback) _boxes_vm_creator_on_machine_state_changed_g_object_notify, _data_->self);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self->priv->state_changed_id = _data_->_tmp31_;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp32_ = NULL;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp32_ = _data_->machine;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_libvirt_machine_set_vm_creator (_data_->_tmp32_, _data_->self);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp33_ = NULL;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp33_ = _data_->machine;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_update_machine_info (_data_->self, _data_->_tmp33_);
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp34_ = NULL;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp34_ = _data_->machine;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_on_machine_state_changed (_data_->self, (GObject*) _data_->_tmp34_, NULL);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp36_ = NULL;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp36_ = _data_->machine;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp37_ = 0;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp37_ = boxes_machine_get_state ((BoxesMachine*) _data_->_tmp36_);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp38_ = 0;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp38_ = _data_->_tmp37_;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_tmp38_ == BOXES_MACHINE_MACHINE_STATE_SAVED) {
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp39_ = NULL;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp39_ = _data_->machine;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp40_ = NULL;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp40_ = boxes_libvirt_machine_get_domain_config (_data_->_tmp39_);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp41_ = NULL;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp41_ = _data_->_tmp40_;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp42_ = FALSE;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp42_ = boxes_vm_configurator_is_install_config (_data_->_tmp41_);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp35_ = _data_->_tmp42_;
#line 2473 "vm-creator.c"
	} else {
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp35_ = FALSE;
#line 2477 "vm-creator.c"
	}
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_tmp35_) {
#line 2481 "vm-creator.c"
		{
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp43_ = NULL;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp43_ = _data_->machine;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp44_ = NULL;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp44_ = boxes_libvirt_machine_get_domain (_data_->_tmp43_);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp45_ = NULL;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp45_ = _data_->_tmp44_;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_state_ = 2;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			gvir_domain_start_async (_data_->_tmp45_, (guint) 0, NULL, boxes_vm_creator_continue_installation_ready, _data_);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return FALSE;
#line 2501 "vm-creator.c"
			_state_2:
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			gvir_domain_start_finish (_data_->_tmp45_, _data_->_res_, &_data_->_inner_error_);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 2507 "vm-creator.c"
				goto __catch98_g_error;
			}
		}
		goto __finally98;
		__catch98_g_error:
		{
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->e = _data_->_inner_error_;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_inner_error_ = NULL;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp46_ = NULL;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp46_ = _data_->machine;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp47_ = NULL;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp47_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->_tmp46_);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp48_ = NULL;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp48_ = _data_->_tmp47_;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp49_ = NULL;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp49_ = _data_->e;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp50_ = NULL;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp50_ = _data_->_tmp49_->message;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_warning ("vm-creator.vala:121: Failed to start '%s': %s", _data_->_tmp48_, _data_->_tmp50_);
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_error_free0 (_data_->e);
#line 2542 "vm-creator.c"
		}
		__finally98:
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_free0 (_data_->name);
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_clear_error (&_data_->_inner_error_);
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return FALSE;
#line 2555 "vm-creator.c"
		}
	}
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2564 "vm-creator.c"
	} else {
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2568 "vm-creator.c"
	}
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 2574 "vm-creator.c"
}


void boxes_vm_creator_continue_installation (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GAsyncReadyCallback _callback_, gpointer _user_data_) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	BOXES_VM_CREATOR_GET_CLASS (self)->continue_installation (self, machine, _callback_, _user_data_);
#line 2581 "vm-creator.c"
}


void boxes_vm_creator_continue_installation_finish (BoxesVMCreator* self, GAsyncResult* _res_) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	BOXES_VM_CREATOR_GET_CLASS (self)->continue_installation_finish (self, _res_);
#line 2588 "vm-creator.c"
}


static Block78Data* block78_data_ref (Block78Data* _data78_) {
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_atomic_int_inc (&_data78_->_ref_count_);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return _data78_;
#line 2597 "vm-creator.c"
}


static void block78_data_unref (void * _userdata_) {
	Block78Data* _data78_;
	_data78_ = (Block78Data*) _userdata_;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_atomic_int_dec_and_test (&_data78_->_ref_count_)) {
#line 2606 "vm-creator.c"
		BoxesVMCreator* self;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		self = _data78_->self;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data78_->machine);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_boxes_vm_creator_unref0 (self);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_slice_free (Block78Data, _data78_);
#line 2616 "vm-creator.c"
	}
}


static void ____lambda83_ (Block78Data* _data78_) {
	BoxesVMCreator* self;
	BoxesLibvirtMachine* _tmp0_ = NULL;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self = _data78_->self;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_debug ("vm-creator.vala:171: Live box deletion cancelled. Invoking post instal" \
"lation setup...");
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _data78_->machine;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_set_post_install_config (self, _tmp0_);
#line 2632 "vm-creator.c"
}


static void _____lambda83__boxes_app_undo_notify_callback (gpointer self) {
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	____lambda83_ (self);
#line 2639 "vm-creator.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 2646 "vm-creator.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_list_free (self);
#line 2655 "vm-creator.c"
}


static void boxes_vm_creator_on_machine_state_changed (BoxesVMCreator* self, GObject* object, GParamSpec* pspec) {
	Block78Data* _data78_;
	GObject* _tmp0_ = NULL;
	BoxesLibvirtMachine* _tmp1_ = NULL;
	BoxesLibvirtMachine* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	GVirDomain* domain = NULL;
	BoxesLibvirtMachine* _tmp4_ = NULL;
	GVirDomain* _tmp5_ = NULL;
	GVirDomain* _tmp6_ = NULL;
	GVirDomain* _tmp7_ = NULL;
	BoxesLibvirtMachine* _tmp8_ = NULL;
	gboolean _tmp9_ = FALSE;
	BoxesLibvirtMachine* _tmp15_ = NULL;
	BoxesMachineMachineState _tmp16_ = 0;
	BoxesMachineMachineState _tmp17_ = 0;
	BoxesLibvirtMachine* _tmp21_ = NULL;
	BoxesLibvirtMachine* _tmp22_ = NULL;
	gboolean _tmp23_ = FALSE;
	GError * _inner_error_ = NULL;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (object != NULL);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data78_ = g_slice_new0 (Block78Data);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data78_->_ref_count_ = 1;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data78_->self = boxes_vm_creator_ref (self);
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = object;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, BOXES_TYPE_LIBVIRT_MACHINE) ? ((BoxesLibvirtMachine*) _tmp0_) : NULL);
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data78_->machine = _tmp1_;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _data78_->machine;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = boxes_machine_is_on ((BoxesMachine*) _tmp2_);
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp3_) {
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block78_data_unref (_data78_);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data78_ = NULL;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return;
#line 2707 "vm-creator.c"
	}
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp4_ = _data78_->machine;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp5_ = boxes_libvirt_machine_get_domain (_tmp4_);
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp6_ = _tmp5_;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp7_ = _g_object_ref0 (_tmp6_);
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	domain = _tmp7_;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp8_ = _data78_->machine;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp9_ = ((BoxesMachine*) _tmp8_)->deleted;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp9_) {
#line 2725 "vm-creator.c"
		BoxesLibvirtMachine* _tmp10_ = NULL;
		gulong _tmp11_ = 0UL;
		BoxesLibvirtMachine* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp10_ = _data78_->machine;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp11_ = self->priv->state_changed_id;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_signal_handler_disconnect ((GObject*) _tmp10_, _tmp11_);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp12_ = _data78_->machine;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp13_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp12_);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp14_ = _tmp13_;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_debug ("vm-creator.vala:135: '%s' was deleted, no need for post-installation s" \
"etup on it", _tmp14_);
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (domain);
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block78_data_unref (_data78_);
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data78_ = NULL;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return;
#line 2753 "vm-creator.c"
	}
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp15_ = _data78_->machine;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp16_ = boxes_machine_get_state ((BoxesMachine*) _tmp15_);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp17_ = _tmp16_;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp17_ == BOXES_MACHINE_MACHINE_STATE_SAVED) {
#line 2763 "vm-creator.c"
		BoxesLibvirtMachine* _tmp18_ = NULL;
		const gchar* _tmp19_ = NULL;
		const gchar* _tmp20_ = NULL;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp18_ = _data78_->machine;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp19_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp18_);
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp20_ = _tmp19_;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_debug ("vm-creator.vala:142: '%s' has saved state, no need for post-installati" \
"on setup on it", _tmp20_);
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (domain);
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block78_data_unref (_data78_);
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data78_ = NULL;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return;
#line 2783 "vm-creator.c"
	}
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp21_ = _data78_->machine;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_increment_num_reboots (self, _tmp21_);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp22_ = _data78_->machine;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp23_ = boxes_vm_creator_guest_installed_os (self, _tmp22_);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp23_) {
#line 2795 "vm-creator.c"
		BoxesLibvirtMachine* _tmp24_ = NULL;
		BoxesInstallerMedia* _tmp25_ = NULL;
		BoxesLibvirtMachine* _tmp31_ = NULL;
		gulong _tmp32_ = 0UL;
		gboolean _tmp33_ = FALSE;
		BoxesLibvirtMachine* _tmp34_ = NULL;
		GVirConfigDomain* _tmp35_ = NULL;
		GVirConfigDomain* _tmp36_ = NULL;
		gboolean _tmp37_ = FALSE;
		BoxesLibvirtMachine* _tmp40_ = NULL;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp24_ = _data78_->machine;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_creator_set_post_install_config (self, _tmp24_);
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp25_ = self->priv->_install_media;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_installer_media_clean_up (_tmp25_);
#line 2814 "vm-creator.c"
		{
			GVirDomain* _tmp26_ = NULL;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp26_ = domain;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			gvir_domain_start (_tmp26_, (guint) 0, &_inner_error_);
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2823 "vm-creator.c"
				goto __catch99_g_error;
			}
		}
		goto __finally99;
		__catch99_g_error:
		{
			GError* _error_ = NULL;
			GVirDomain* _tmp27_ = NULL;
			const gchar* _tmp28_ = NULL;
			GError* _tmp29_ = NULL;
			const gchar* _tmp30_ = NULL;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_error_ = _inner_error_;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_inner_error_ = NULL;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp27_ = domain;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp28_ = gvir_domain_get_name (_tmp27_);
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp29_ = _error_;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp30_ = _tmp29_->message;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_warning ("vm-creator.vala:155: Failed to start domain '%s': %s", _tmp28_, _tmp30_);
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_error_free0 (_error_);
#line 2851 "vm-creator.c"
		}
		__finally99:
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (domain);
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			block78_data_unref (_data78_);
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data78_ = NULL;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_clear_error (&_inner_error_);
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return;
#line 2868 "vm-creator.c"
		}
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp31_ = _data78_->machine;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp32_ = self->priv->state_changed_id;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_signal_handler_disconnect ((GObject*) _tmp31_, _tmp32_);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp34_ = _data78_->machine;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp35_ = boxes_libvirt_machine_get_domain_config (_tmp34_);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp36_ = _tmp35_;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp37_ = boxes_vm_configurator_is_live_config (_tmp36_);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_tmp37_) {
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp33_ = TRUE;
#line 2888 "vm-creator.c"
		} else {
			gboolean _tmp38_ = FALSE;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp38_ = boxes_vm_creator_install_trackable (self);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp33_ = !_tmp38_;
#line 2895 "vm-creator.c"
		}
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_tmp33_) {
#line 2899 "vm-creator.c"
			BoxesLibvirtMachine* _tmp39_ = NULL;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp39_ = _data78_->machine;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			boxes_machine_set_info ((BoxesMachine*) _tmp39_, NULL);
#line 2905 "vm-creator.c"
		}
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp40_ = _data78_->machine;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_libvirt_machine_set_vm_creator (_tmp40_, NULL);
#line 2911 "vm-creator.c"
	} else {
		gboolean _tmp41_ = FALSE;
		BoxesLibvirtMachine* _tmp42_ = NULL;
		GVirConfigDomain* _tmp43_ = NULL;
		GVirConfigDomain* _tmp44_ = NULL;
		gboolean _tmp45_ = FALSE;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp42_ = _data78_->machine;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp43_ = boxes_libvirt_machine_get_domain_config (_tmp42_);
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp44_ = _tmp43_;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp45_ = boxes_vm_configurator_is_live_config (_tmp44_);
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_tmp45_) {
#line 2928 "vm-creator.c"
			BoxesLibvirtMachine* _tmp46_ = NULL;
			BoxesMachineMachineState _tmp47_ = 0;
			BoxesMachineMachineState _tmp48_ = 0;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp46_ = _data78_->machine;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp47_ = boxes_machine_get_state ((BoxesMachine*) _tmp46_);
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp48_ = _tmp47_;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp41_ = _tmp48_ != BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED;
#line 2940 "vm-creator.c"
		} else {
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp41_ = FALSE;
#line 2944 "vm-creator.c"
		}
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_tmp41_) {
#line 2948 "vm-creator.c"
			BoxesLibvirtMachine* _tmp49_ = NULL;
			gulong _tmp50_ = 0UL;
			BoxesInstallerMedia* _tmp51_ = NULL;
			GList* items = NULL;
			BoxesLibvirtMachine* _tmp52_ = NULL;
			BoxesCollectionItem* _tmp53_ = NULL;
			BoxesAppUndoNotifyCallback undo_notify_callback = NULL;
			void* undo_notify_callback_target = NULL;
			GDestroyNotify undo_notify_callback_target_destroy_notify = NULL;
			gchar* msg = NULL;
			const gchar* _tmp54_ = NULL;
			BoxesLibvirtMachine* _tmp55_ = NULL;
			const gchar* _tmp56_ = NULL;
			const gchar* _tmp57_ = NULL;
			gchar* _tmp58_ = NULL;
			BoxesApp* _tmp59_ = NULL;
			GList* _tmp60_ = NULL;
			const gchar* _tmp61_ = NULL;
			BoxesAppUndoNotifyCallback _tmp62_ = NULL;
			void* _tmp62__target = NULL;
			GDestroyNotify _tmp62__target_destroy_notify = NULL;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp49_ = _data78_->machine;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp50_ = self->priv->state_changed_id;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_signal_handler_disconnect ((GObject*) _tmp49_, _tmp50_);
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp51_ = self->priv->_install_media;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			boxes_installer_media_clean_up (_tmp51_);
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			items = NULL;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp52_ = _data78_->machine;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp53_ = _g_object_ref0 ((BoxesCollectionItem*) _tmp52_);
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			items = g_list_append (items, _tmp53_);
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			undo_notify_callback = _____lambda83__boxes_app_undo_notify_callback;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			undo_notify_callback_target = block78_data_ref (_data78_);
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			undo_notify_callback_target_destroy_notify = block78_data_unref;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp54_ = _ ("Live box '%s' has been deleted automatically.");
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp55_ = _data78_->machine;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp56_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp55_);
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp57_ = _tmp56_;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp58_ = g_strdup_printf (_tmp54_, _tmp57_);
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			msg = _tmp58_;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp59_ = boxes_app_app;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp60_ = items;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			items = NULL;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp61_ = msg;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp62_ = undo_notify_callback;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp62__target = undo_notify_callback_target;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp62__target_destroy_notify = undo_notify_callback_target_destroy_notify;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			undo_notify_callback_target_destroy_notify = NULL;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			boxes_app_delete_machines_undoable (_tmp59_, _tmp60_, _tmp61_, _tmp62_, _tmp62__target, _tmp62__target_destroy_notify);
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_free0 (msg);
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			(undo_notify_callback_target_destroy_notify == NULL) ? NULL : (undo_notify_callback_target_destroy_notify (undo_notify_callback_target), NULL);
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			undo_notify_callback = NULL;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			undo_notify_callback_target = NULL;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			undo_notify_callback_target_destroy_notify = NULL;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			__g_list_free__g_object_unref0_0 (items);
#line 3036 "vm-creator.c"
		} else {
			{
				GVirDomain* _tmp63_ = NULL;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp63_ = domain;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				gvir_domain_start (_tmp63_, (guint) 0, &_inner_error_);
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3046 "vm-creator.c"
					goto __catch100_g_error;
				}
			}
			goto __finally100;
			__catch100_g_error:
			{
				GError* _error_ = NULL;
				GVirDomain* _tmp64_ = NULL;
				const gchar* _tmp65_ = NULL;
				GError* _tmp66_ = NULL;
				const gchar* _tmp67_ = NULL;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_error_ = _inner_error_;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_inner_error_ = NULL;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp64_ = domain;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp65_ = gvir_domain_get_name (_tmp64_);
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp66_ = _error_;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp67_ = _tmp66_->message;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_warning ("vm-creator.vala:181: Failed to start domain '%s': %s", _tmp65_, _tmp67_);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_error_free0 (_error_);
#line 3074 "vm-creator.c"
			}
			__finally100:
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_object_unref0 (domain);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				block78_data_unref (_data78_);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data78_ = NULL;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_clear_error (&_inner_error_);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				return;
#line 3091 "vm-creator.c"
			}
		}
	}
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (domain);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	block78_data_unref (_data78_);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data78_ = NULL;
#line 3101 "vm-creator.c"
}


static void boxes_vm_creator_real_update_machine_info (BoxesVMCreator* self, BoxesLibvirtMachine* machine) {
	BoxesLibvirtMachine* _tmp0_ = NULL;
	GVirConfigDomain* _tmp1_ = NULL;
	GVirConfigDomain* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (machine != NULL);
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = machine;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = boxes_libvirt_machine_get_domain_config (_tmp0_);
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _tmp1_;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = boxes_vm_configurator_is_install_config (_tmp2_);
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp3_) {
#line 3122 "vm-creator.c"
		BoxesLibvirtMachine* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		BoxesLibvirtMachine* _tmp6_ = NULL;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp4_ = machine;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp5_ = _ ("Installing…");
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_machine_set_info ((BoxesMachine*) _tmp4_, _tmp5_);
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp6_ = machine;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_creator_track_install_progress (self, _tmp6_);
#line 3136 "vm-creator.c"
	} else {
		BoxesLibvirtMachine* _tmp7_ = NULL;
		const gchar* _tmp8_ = NULL;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp7_ = machine;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp8_ = _ ("Live");
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_machine_set_info ((BoxesMachine*) _tmp7_, _tmp8_);
#line 3146 "vm-creator.c"
	}
}


void boxes_vm_creator_update_machine_info (BoxesVMCreator* self, BoxesLibvirtMachine* machine) {
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	BOXES_VM_CREATOR_GET_CLASS (self)->update_machine_info (self, machine);
#line 3156 "vm-creator.c"
}


void boxes_vm_creator_set_post_install_config (BoxesVMCreator* self, BoxesLibvirtMachine* machine) {
	BoxesLibvirtMachine* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	GError * _inner_error_ = NULL;
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (machine != NULL);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = machine;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp0_);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _tmp1_;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_debug ("vm-creator.vala:196: Setting post-installation configuration on '%s'", _tmp2_);
#line 3177 "vm-creator.c"
	{
		GVirConfigDomain* config = NULL;
		BoxesLibvirtMachine* _tmp3_ = NULL;
		GVirDomain* _tmp4_ = NULL;
		GVirDomain* _tmp5_ = NULL;
		GVirConfigDomain* _tmp6_ = NULL;
		GVirConfigDomain* _tmp7_ = NULL;
		BoxesInstallerMedia* _tmp8_ = NULL;
		BoxesLibvirtMachine* _tmp9_ = NULL;
		GVirDomain* _tmp10_ = NULL;
		GVirDomain* _tmp11_ = NULL;
		GVirConfigDomain* _tmp12_ = NULL;
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp3_ = machine;
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp4_ = boxes_libvirt_machine_get_domain (_tmp3_);
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp5_ = _tmp4_;
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp6_ = gvir_domain_get_config (_tmp5_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		config = _tmp6_;
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3202 "vm-creator.c"
			goto __catch101_g_error;
		}
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp7_ = config;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp8_ = self->priv->_install_media;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_configurator_post_install_setup (_tmp7_, _tmp8_);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp9_ = machine;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp10_ = boxes_libvirt_machine_get_domain (_tmp9_);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp11_ = _tmp10_;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp12_ = config;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		gvir_domain_set_config (_tmp11_, _tmp12_, &_inner_error_);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (config);
#line 3225 "vm-creator.c"
			goto __catch101_g_error;
		}
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (config);
#line 3230 "vm-creator.c"
	}
	goto __finally101;
	__catch101_g_error:
	{
		GError* _error_ = NULL;
		BoxesLibvirtMachine* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
		const gchar* _tmp15_ = NULL;
		GError* _tmp16_ = NULL;
		const gchar* _tmp17_ = NULL;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_error_ = _inner_error_;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_inner_error_ = NULL;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp13_ = machine;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp14_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp13_);
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp15_ = _tmp14_;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp16_ = _error_;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp17_ = _tmp16_->message;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_warning ("vm-creator.vala:202: Failed to set post-install configuration on '%s':" \
" %s", _tmp15_, _tmp17_);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_error_free0 (_error_);
#line 3259 "vm-creator.c"
	}
	__finally101:
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_clear_error (&_inner_error_);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return;
#line 3270 "vm-creator.c"
	}
}


static void boxes_vm_creator_get_storage_pool_data_free (gpointer _data) {
	BoxesVmCreatorGetStoragePoolData* _data_;
	_data_ = _data;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->result);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_boxes_vm_creator_unref0 (_data_->self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_slice_free (BoxesVmCreatorGetStoragePoolData, _data_);
#line 3284 "vm-creator.c"
}


void boxes_vm_creator_get_storage_pool (BoxesVMCreator* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesVmCreatorGetStoragePoolData* _data_;
	BoxesVMCreator* _tmp0_ = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_slice_new0 (BoxesVmCreatorGetStoragePoolData);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_vm_creator_get_storage_pool);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_vm_creator_get_storage_pool_data_free);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _boxes_vm_creator_ref0 (self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_get_storage_pool_co (_data_);
#line 3303 "vm-creator.c"
}


GVirStoragePool* boxes_vm_creator_get_storage_pool_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error) {
	GVirStoragePool* result;
	BoxesVmCreatorGetStoragePoolData* _data_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return NULL;
#line 3314 "vm-creator.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	result = _data_->result;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->result = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 3324 "vm-creator.c"
}


static void boxes_vm_creator_get_storage_pool_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesVmCreatorGetStoragePoolData* _data_;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = _user_data_;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_source_object_ = source_object;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_res_ = _res_;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_get_storage_pool_co (_data_);
#line 3338 "vm-creator.c"
}


static void _vala_GVirStoragePoolInfo_free (GVirStoragePoolInfo* self) {
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_boxed_free (gvir_storage_pool_info_get_type (), self);
#line 3345 "vm-creator.c"
}


static gboolean boxes_vm_creator_get_storage_pool_co (BoxesVmCreatorGetStoragePoolData* _data_) {
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	switch (_data_->_state_) {
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 0:
#line 3354 "vm-creator.c"
		goto _state_0;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 1:
#line 3358 "vm-creator.c"
		goto _state_1;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 2:
#line 3362 "vm-creator.c"
		goto _state_2;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 3:
#line 3366 "vm-creator.c"
		goto _state_3;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 4:
#line 3370 "vm-creator.c"
		goto _state_4;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 5:
#line 3374 "vm-creator.c"
		goto _state_5;
		default:
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_assert_not_reached ();
#line 3379 "vm-creator.c"
	}
	_state_0:
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = NULL;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = boxes_vm_creator_get_connection (_data_->self);
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = NULL;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = _data_->_tmp0_;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = NULL;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = _data_->_tmp1_;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = NULL;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = boxes_get_storage_pool (_data_->_tmp2_);
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp4_ = NULL;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp4_ = _data_->_tmp3_;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->_tmp2_);
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->pool = _data_->_tmp4_;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp5_ = NULL;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp5_ = _data_->pool;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_tmp5_ == NULL) {
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_debug ("vm-creator.vala:209: Creating storage pool..");
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp6_ = NULL;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp6_ = boxes_vm_configurator_get_pool_config (&_data_->_inner_error_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->config = _data_->_tmp6_;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_error_free (_data_->_inner_error_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->pool);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (_data_->_state_ == 0) {
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3432 "vm-creator.c"
			} else {
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 3436 "vm-creator.c"
			}
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_object_unref (_data_->_async_result);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return FALSE;
#line 3442 "vm-creator.c"
		}
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp8_ = NULL;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp8_ = boxes_vm_creator_get_connection (_data_->self);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp9_ = NULL;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp9_ = _data_->_tmp8_;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp10_ = NULL;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp10_ = _data_->_tmp9_;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp11_ = NULL;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp11_ = _data_->config;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp12_ = NULL;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp12_ = gvir_connection_create_storage_pool (_data_->_tmp10_, _data_->_tmp11_, (guint) 0, &_data_->_inner_error_);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp13_ = NULL;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp13_ = _data_->_tmp12_;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->_tmp10_);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp7_ = _data_->_tmp13_;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_error_free (_data_->_inner_error_);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->config);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->pool);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (_data_->_state_ == 0) {
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3486 "vm-creator.c"
			} else {
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 3490 "vm-creator.c"
			}
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_object_unref (_data_->_async_result);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return FALSE;
#line 3496 "vm-creator.c"
		}
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp14_ = NULL;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp14_ = _data_->_tmp7_;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp7_ = NULL;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->pool);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->pool = _data_->_tmp14_;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp15_ = NULL;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp15_ = _data_->pool;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_state_ = 1;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		gvir_storage_pool_build_async (_data_->_tmp15_, (guint) 0, NULL, boxes_vm_creator_get_storage_pool_ready, _data_);
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 3518 "vm-creator.c"
		_state_1:
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		gvir_storage_pool_build_finish (_data_->_tmp15_, _data_->_res_, &_data_->_inner_error_);
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_error_free (_data_->_inner_error_);
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->_tmp7_);
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->config);
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->pool);
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (_data_->_state_ == 0) {
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3538 "vm-creator.c"
			} else {
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 3542 "vm-creator.c"
			}
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_object_unref (_data_->_async_result);
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return FALSE;
#line 3548 "vm-creator.c"
		}
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp16_ = NULL;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp16_ = _data_->pool;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_state_ = 2;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		gvir_storage_pool_start_async (_data_->_tmp16_, (guint) 0, NULL, boxes_vm_creator_get_storage_pool_ready, _data_);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 3560 "vm-creator.c"
		_state_2:
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		gvir_storage_pool_start_finish (_data_->_tmp16_, _data_->_res_, &_data_->_inner_error_);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_error_free (_data_->_inner_error_);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->_tmp7_);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->config);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->pool);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (_data_->_state_ == 0) {
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3580 "vm-creator.c"
			} else {
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 3584 "vm-creator.c"
			}
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_object_unref (_data_->_async_result);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return FALSE;
#line 3590 "vm-creator.c"
		}
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp17_ = NULL;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp17_ = _data_->pool;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_state_ = 3;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		gvir_storage_pool_refresh_async (_data_->_tmp17_, NULL, boxes_vm_creator_get_storage_pool_ready, _data_);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 3602 "vm-creator.c"
		_state_3:
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		gvir_storage_pool_refresh_finish (_data_->_tmp17_, _data_->_res_, &_data_->_inner_error_);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_error_free (_data_->_inner_error_);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->_tmp7_);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->config);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->pool);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (_data_->_state_ == 0) {
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3622 "vm-creator.c"
			} else {
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 3626 "vm-creator.c"
			}
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_object_unref (_data_->_async_result);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return FALSE;
#line 3632 "vm-creator.c"
		}
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_debug ("vm-creator.vala:215: Created storage pool.");
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->_tmp7_);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->config);
#line 3640 "vm-creator.c"
	} else {
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp19_ = NULL;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp19_ = _data_->pool;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp20_ = NULL;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp20_ = gvir_storage_pool_get_info (_data_->_tmp19_, &_data_->_inner_error_);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp18_ = _data_->_tmp20_;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_error_free (_data_->_inner_error_);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->pool);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (_data_->_state_ == 0) {
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3664 "vm-creator.c"
			} else {
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 3668 "vm-creator.c"
			}
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_object_unref (_data_->_async_result);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return FALSE;
#line 3674 "vm-creator.c"
		}
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp21_ = NULL;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp21_ = _data_->_tmp18_;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp18_ = NULL;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp22_ = NULL;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp22_ = _data_->_tmp21_;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp23_ = 0;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp23_ = _data_->_tmp22_->state;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp24_ = FALSE;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp24_ = _data_->_tmp23_ == GVIR_STORAGE_POOL_STATE_INACTIVE;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		__vala_GVirStoragePoolInfo_free0 (_data_->_tmp22_);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_tmp24_) {
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp25_ = NULL;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp25_ = boxes_get_user_pkgdata (NULL);
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp26_ = NULL;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp26_ = _data_->_tmp25_;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp27_ = NULL;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp27_ = g_build_filename (_data_->_tmp26_, "images", NULL, NULL);
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp28_ = NULL;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp28_ = _data_->_tmp27_;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_mkdir_with_parents (_data_->_tmp28_, 0775);
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_free0 (_data_->_tmp28_);
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_free0 (_data_->_tmp26_);
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp29_ = NULL;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp29_ = _data_->pool;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_state_ = 4;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			gvir_storage_pool_start_async (_data_->_tmp29_, (guint) 0, NULL, boxes_vm_creator_get_storage_pool_ready, _data_);
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return FALSE;
#line 3730 "vm-creator.c"
			_state_4:
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			gvir_storage_pool_start_finish (_data_->_tmp29_, _data_->_res_, &_data_->_inner_error_);
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_error_free (_data_->_inner_error_);
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				__vala_GVirStoragePoolInfo_free0 (_data_->_tmp18_);
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_object_unref0 (_data_->pool);
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				if (_data_->_state_ == 0) {
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3748 "vm-creator.c"
				} else {
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					g_simple_async_result_complete (_data_->_async_result);
#line 3752 "vm-creator.c"
				}
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_object_unref (_data_->_async_result);
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				return FALSE;
#line 3758 "vm-creator.c"
			}
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp30_ = NULL;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp30_ = _data_->pool;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_state_ = 5;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			gvir_storage_pool_refresh_async (_data_->_tmp30_, NULL, boxes_vm_creator_get_storage_pool_ready, _data_);
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return FALSE;
#line 3770 "vm-creator.c"
			_state_5:
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			gvir_storage_pool_refresh_finish (_data_->_tmp30_, _data_->_res_, &_data_->_inner_error_);
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_error_free (_data_->_inner_error_);
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				__vala_GVirStoragePoolInfo_free0 (_data_->_tmp18_);
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_object_unref0 (_data_->pool);
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				if (_data_->_state_ == 0) {
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3788 "vm-creator.c"
				} else {
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					g_simple_async_result_complete (_data_->_async_result);
#line 3792 "vm-creator.c"
				}
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_object_unref (_data_->_async_result);
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				return FALSE;
#line 3798 "vm-creator.c"
			}
		}
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		__vala_GVirStoragePoolInfo_free0 (_data_->_tmp18_);
#line 3803 "vm-creator.c"
	}
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->result = _data_->pool;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3811 "vm-creator.c"
	} else {
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3815 "vm-creator.c"
	}
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->pool);
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3827 "vm-creator.c"
	} else {
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3831 "vm-creator.c"
	}
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 3837 "vm-creator.c"
}


static void boxes_vm_creator_real_create_domain_config_data_free (gpointer _data) {
	BoxesVmCreatorCreateDomainConfigData* _data_;
	_data_ = _data;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->title);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->volume);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->result);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_boxes_vm_creator_unref0 (_data_->self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_slice_free (BoxesVmCreatorCreateDomainConfigData, _data_);
#line 3858 "vm-creator.c"
}


static void boxes_vm_creator_real_create_domain_config (BoxesVMCreator* self, const gchar* name, const gchar* title, GVirStorageVol* volume, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesVmCreatorCreateDomainConfigData* _data_;
	BoxesVMCreator* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	GVirStorageVol* _tmp5_ = NULL;
	GVirStorageVol* _tmp6_ = NULL;
	GCancellable* _tmp7_ = NULL;
	GCancellable* _tmp8_ = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_slice_new0 (BoxesVmCreatorCreateDomainConfigData);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_vm_creator_real_create_domain_config);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_vm_creator_real_create_domain_config_data_free);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _boxes_vm_creator_ref0 (self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = name;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->name = _tmp2_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = title;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp4_ = g_strdup (_tmp3_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->title);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->title = _tmp4_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp5_ = volume;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp6_ = _g_object_ref0 (_tmp5_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->volume);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->volume = _tmp6_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp7_ = cancellable;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp8_ = _g_object_ref0 (_tmp7_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->cancellable = _tmp8_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_real_create_domain_config_co (_data_);
#line 3917 "vm-creator.c"
}


static GVirConfigDomain* boxes_vm_creator_real_create_domain_config_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error) {
	GVirConfigDomain* result;
	BoxesVmCreatorCreateDomainConfigData* _data_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return NULL;
#line 3928 "vm-creator.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	result = _data_->result;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->result = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 3938 "vm-creator.c"
}


static void boxes_vm_creator_create_domain_config_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesVmCreatorCreateDomainConfigData* _data_;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = _user_data_;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_source_object_ = source_object;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_res_ = _res_;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_real_create_domain_config_co (_data_);
#line 3952 "vm-creator.c"
}


static gboolean boxes_vm_creator_real_create_domain_config_co (BoxesVmCreatorCreateDomainConfigData* _data_) {
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	switch (_data_->_state_) {
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 0:
#line 3961 "vm-creator.c"
		goto _state_0;
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 1:
#line 3965 "vm-creator.c"
		goto _state_1;
		default:
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_assert_not_reached ();
#line 3970 "vm-creator.c"
	}
	_state_0:
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = NULL;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = boxes_vm_creator_get_connection (_data_->self);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = NULL;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = _data_->_tmp0_;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = NULL;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = _data_->_tmp1_;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = NULL;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = _data_->cancellable;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_state_ = 1;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	gvir_connection_get_capabilities_async (_data_->_tmp2_, _data_->_tmp3_, boxes_vm_creator_create_domain_config_ready, _data_);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 3995 "vm-creator.c"
	_state_1:
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp4_ = NULL;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp4_ = gvir_connection_get_capabilities_finish (_data_->_tmp2_, _data_->_res_, &_data_->_inner_error_);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp5_ = NULL;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp5_ = _data_->_tmp4_;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->_tmp2_);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->caps = _data_->_tmp5_;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4019 "vm-creator.c"
		} else {
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4023 "vm-creator.c"
		}
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 4029 "vm-creator.c"
	}
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp7_ = NULL;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp7_ = _data_->volume;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp8_ = NULL;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp8_ = gvir_storage_vol_get_path (_data_->_tmp7_, &_data_->_inner_error_);
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp6_ = _data_->_tmp8_;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->caps);
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4053 "vm-creator.c"
		} else {
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4057 "vm-creator.c"
		}
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 4063 "vm-creator.c"
	}
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp9_ = NULL;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp9_ = _data_->self->priv->_install_media;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp10_ = NULL;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp10_ = _data_->caps;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp11_ = NULL;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp11_ = boxes_vm_configurator_create_domain_config (_data_->_tmp9_, _data_->_tmp6_, _data_->_tmp10_, &_data_->_inner_error_);
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->config = _data_->_tmp11_;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->caps);
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4091 "vm-creator.c"
		} else {
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4095 "vm-creator.c"
		}
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 4101 "vm-creator.c"
	}
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp12_ = NULL;
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp12_ = _data_->config;
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp13_ = NULL;
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp13_ = _data_->name;
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	gvir_config_domain_set_name (_data_->_tmp12_, _data_->_tmp13_);
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp14_ = NULL;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp14_ = _data_->config;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp15_ = NULL;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp15_ = _data_->title;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	gvir_config_domain_set_title (_data_->_tmp14_, _data_->_tmp15_);
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->result = _data_->config;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->caps);
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4131 "vm-creator.c"
	} else {
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4135 "vm-creator.c"
	}
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->config);
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->caps);
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4149 "vm-creator.c"
	} else {
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4153 "vm-creator.c"
	}
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 4159 "vm-creator.c"
}


void boxes_vm_creator_create_domain_config (BoxesVMCreator* self, const gchar* name, const gchar* title, GVirStorageVol* volume, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	BOXES_VM_CREATOR_GET_CLASS (self)->create_domain_config (self, name, title, volume, cancellable, _callback_, _user_data_);
#line 4166 "vm-creator.c"
}


GVirConfigDomain* boxes_vm_creator_create_domain_config_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return BOXES_VM_CREATOR_GET_CLASS (self)->create_domain_config_finish (self, _res_, error);
#line 4173 "vm-creator.c"
}


static gchar* string_slice (const gchar* self, glong start, glong end) {
	gchar* result = NULL;
	glong string_length = 0L;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	glong _tmp2_ = 0L;
	glong _tmp5_ = 0L;
	gboolean _tmp8_ = FALSE;
	glong _tmp9_ = 0L;
	gboolean _tmp12_ = FALSE;
	glong _tmp13_ = 0L;
	glong _tmp16_ = 0L;
	glong _tmp17_ = 0L;
	glong _tmp18_ = 0L;
	glong _tmp19_ = 0L;
	glong _tmp20_ = 0L;
	gchar* _tmp21_ = NULL;
#line 1230 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1231 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp0_ = strlen (self);
#line 1231 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp1_ = _tmp0_;
#line 1231 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	string_length = (glong) _tmp1_;
#line 1232 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp2_ = start;
#line 1232 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	if (_tmp2_ < ((glong) 0)) {
#line 4206 "vm-creator.c"
		glong _tmp3_ = 0L;
		glong _tmp4_ = 0L;
#line 1233 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp3_ = string_length;
#line 1233 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp4_ = start;
#line 1233 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		start = _tmp3_ + _tmp4_;
#line 4215 "vm-creator.c"
	}
#line 1235 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp5_ = end;
#line 1235 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	if (_tmp5_ < ((glong) 0)) {
#line 4221 "vm-creator.c"
		glong _tmp6_ = 0L;
		glong _tmp7_ = 0L;
#line 1236 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp6_ = string_length;
#line 1236 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp7_ = end;
#line 1236 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		end = _tmp6_ + _tmp7_;
#line 4230 "vm-creator.c"
	}
#line 1238 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp9_ = start;
#line 1238 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	if (_tmp9_ >= ((glong) 0)) {
#line 4236 "vm-creator.c"
		glong _tmp10_ = 0L;
		glong _tmp11_ = 0L;
#line 1238 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp10_ = start;
#line 1238 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp11_ = string_length;
#line 1238 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp8_ = _tmp10_ <= _tmp11_;
#line 4245 "vm-creator.c"
	} else {
#line 1238 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp8_ = FALSE;
#line 4249 "vm-creator.c"
	}
#line 1238 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	g_return_val_if_fail (_tmp8_, NULL);
#line 1239 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp13_ = end;
#line 1239 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	if (_tmp13_ >= ((glong) 0)) {
#line 4257 "vm-creator.c"
		glong _tmp14_ = 0L;
		glong _tmp15_ = 0L;
#line 1239 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp14_ = end;
#line 1239 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp15_ = string_length;
#line 1239 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp12_ = _tmp14_ <= _tmp15_;
#line 4266 "vm-creator.c"
	} else {
#line 1239 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp12_ = FALSE;
#line 4270 "vm-creator.c"
	}
#line 1239 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	g_return_val_if_fail (_tmp12_, NULL);
#line 1240 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp16_ = start;
#line 1240 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp17_ = end;
#line 1240 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	g_return_val_if_fail (_tmp16_ <= _tmp17_, NULL);
#line 1241 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp18_ = start;
#line 1241 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp19_ = end;
#line 1241 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp20_ = start;
#line 1241 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp21_ = g_strndup (((gchar*) self) + _tmp18_, (gsize) (_tmp19_ - _tmp20_));
#line 1241 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	result = _tmp21_;
#line 1241 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	return result;
#line 4292 "vm-creator.c"
}


static void boxes_vm_creator_real_create_domain_base_name_and_title (BoxesVMCreator* self, gchar** base_name, gchar** base_title) {
	gchar* _vala_base_name = NULL;
	gchar* _vala_base_title = NULL;
	BoxesInstallerMedia* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	BoxesInstallerMedia* _tmp3_ = NULL;
	OsinfoOs* _tmp4_ = NULL;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = self->priv->_install_media;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = _tmp0_->label;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_vala_base_title);
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_vala_base_title = _tmp2_;
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = self->priv->_install_media;
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp4_ = _tmp3_->os;
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp4_ != NULL) {
#line 4320 "vm-creator.c"
		BoxesInstallerMedia* _tmp5_ = NULL;
		OsinfoOs* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		const gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		BoxesInstallerMedia* _tmp10_ = NULL;
		OsinfoMedia* _tmp11_ = NULL;
		const gchar* _tmp26_ = NULL;
		gint _tmp27_ = 0;
		gint _tmp28_ = 0;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp5_ = self->priv->_install_media;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp6_ = _tmp5_->os;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp7_ = osinfo_product_get_short_id ((OsinfoProduct*) _tmp6_);
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp8_ = _tmp7_;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp9_ = g_strdup (_tmp8_);
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_vala_base_name);
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_vala_base_name = _tmp9_;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp10_ = self->priv->_install_media;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp11_ = _tmp10_->os_media;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_tmp11_ != NULL) {
#line 4351 "vm-creator.c"
			OsinfoOsVariantList* variants = NULL;
			BoxesInstallerMedia* _tmp12_ = NULL;
			OsinfoMedia* _tmp13_ = NULL;
			OsinfoOsVariantList* _tmp14_ = NULL;
			OsinfoOsVariantList* _tmp15_ = NULL;
			gint _tmp16_ = 0;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp12_ = self->priv->_install_media;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp13_ = _tmp12_->os_media;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp14_ = osinfo_media_get_os_variants (_tmp13_);
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			variants = _tmp14_;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp15_ = variants;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp16_ = osinfo_list_get_length ((OsinfoList*) _tmp15_);
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (_tmp16_ > 0) {
#line 4372 "vm-creator.c"
				const gchar* _tmp17_ = NULL;
				OsinfoOsVariantList* _tmp18_ = NULL;
				OsinfoEntity* _tmp19_ = NULL;
				gchar* _tmp20_ = NULL;
				gchar* _tmp21_ = NULL;
				gchar* _tmp22_ = NULL;
				gchar* _tmp23_ = NULL;
				gchar* _tmp24_ = NULL;
				gchar* _tmp25_ = NULL;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp17_ = _vala_base_name;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp18_ = variants;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp19_ = osinfo_list_get_nth ((OsinfoList*) _tmp18_, 0);
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_object_get (_tmp19_, "id", &_tmp20_, NULL);
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp21_ = _tmp20_;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp22_ = _tmp21_;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp23_ = g_strconcat ("-", _tmp22_, NULL);
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp24_ = _tmp23_;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp25_ = g_strconcat (_tmp17_, _tmp24_, NULL);
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_vala_base_name);
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_vala_base_name = _tmp25_;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_tmp24_);
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_tmp22_);
#line 4408 "vm-creator.c"
			}
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (variants);
#line 4412 "vm-creator.c"
		}
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp26_ = _vala_base_name;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp27_ = strlen (_tmp26_);
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp28_ = _tmp27_;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_tmp28_ > 12) {
#line 4422 "vm-creator.c"
			const gchar* _tmp29_ = NULL;
			gchar* _tmp30_ = NULL;
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp29_ = _vala_base_name;
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp30_ = string_slice (_tmp29_, (glong) 0, (glong) 12);
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_free0 (_vala_base_name);
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_vala_base_name = _tmp30_;
#line 4433 "vm-creator.c"
		}
	} else {
		gchar* _tmp31_ = NULL;
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp31_ = g_strdup ("boxes-unknown");
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_vala_base_name);
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_vala_base_name = _tmp31_;
#line 4443 "vm-creator.c"
	}
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (base_name) {
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		*base_name = _vala_base_name;
#line 4449 "vm-creator.c"
	} else {
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_vala_base_name);
#line 4453 "vm-creator.c"
	}
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (base_title) {
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		*base_title = _vala_base_title;
#line 4459 "vm-creator.c"
	} else {
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_vala_base_title);
#line 4463 "vm-creator.c"
	}
}


void boxes_vm_creator_create_domain_base_name_and_title (BoxesVMCreator* self, gchar** base_name, gchar** base_title) {
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	BOXES_VM_CREATOR_GET_CLASS (self)->create_domain_base_name_and_title (self, base_name, base_title);
#line 4473 "vm-creator.c"
}


static void boxes_vm_creator_increment_num_reboots (BoxesVMCreator* self, BoxesLibvirtMachine* machine) {
	guint _tmp0_ = 0U;
	GError * _inner_error_ = NULL;
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (machine != NULL);
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = self->priv->_num_reboots;
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_set_num_reboots (self, _tmp0_ + 1);
#line 4488 "vm-creator.c"
	{
		GVirConfigDomain* config = NULL;
		BoxesLibvirtMachine* _tmp1_ = NULL;
		GVirDomain* _tmp2_ = NULL;
		GVirDomain* _tmp3_ = NULL;
		GVirConfigDomain* _tmp4_ = NULL;
		GVirConfigDomain* _tmp5_ = NULL;
		BoxesInstallerMedia* _tmp6_ = NULL;
		guint _tmp7_ = 0U;
		BoxesLibvirtMachine* _tmp8_ = NULL;
		GVirDomain* _tmp9_ = NULL;
		GVirDomain* _tmp10_ = NULL;
		GVirConfigDomain* _tmp11_ = NULL;
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp1_ = machine;
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp2_ = boxes_libvirt_machine_get_domain (_tmp1_);
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp3_ = _tmp2_;
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp4_ = gvir_domain_get_config (_tmp3_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		config = _tmp4_;
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4514 "vm-creator.c"
			goto __catch102_g_error;
		}
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp5_ = config;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp6_ = self->priv->_install_media;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp7_ = self->priv->_num_reboots;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_configurator_set_num_reboots (_tmp5_, _tmp6_, _tmp7_);
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp8_ = machine;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp9_ = boxes_libvirt_machine_get_domain (_tmp8_);
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp10_ = _tmp9_;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp11_ = config;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		gvir_domain_set_config (_tmp10_, _tmp11_, &_inner_error_);
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (config);
#line 4539 "vm-creator.c"
			goto __catch102_g_error;
		}
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (config);
#line 4544 "vm-creator.c"
	}
	goto __finally102;
	__catch102_g_error:
	{
		GError* _error_ = NULL;
		BoxesLibvirtMachine* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
		GError* _tmp15_ = NULL;
		const gchar* _tmp16_ = NULL;
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_error_ = _inner_error_;
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_inner_error_ = NULL;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp12_ = machine;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp13_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp12_);
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp14_ = _tmp13_;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp15_ = _error_;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp16_ = _tmp15_->message;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_warning ("vm-creator.vala:267: Failed to update configuration on '%s': %s", _tmp14_, _tmp16_);
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_error_free0 (_error_);
#line 4573 "vm-creator.c"
	}
	__finally102:
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_clear_error (&_inner_error_);
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return;
#line 4584 "vm-creator.c"
	}
}


static void _vala_GVirStorageVolInfo_free (GVirStorageVolInfo* self) {
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_boxed_free (gvir_storage_vol_info_get_type (), self);
#line 4592 "vm-creator.c"
}


static gboolean boxes_vm_creator_guest_installed_os (BoxesVMCreator* self, BoxesLibvirtMachine* machine) {
	gboolean result = FALSE;
	GVirStorageVol* volume = NULL;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	GVirStorageVol* _tmp1_ = NULL;
	GVirStorageVol* _tmp2_ = NULL;
	GVirStorageVol* _tmp3_ = NULL;
	GError * _inner_error_ = NULL;
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (machine != NULL, FALSE);
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = machine;
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = boxes_libvirt_machine_get_storage_volume (_tmp0_);
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _tmp1_;
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	volume = _tmp3_;
#line 4618 "vm-creator.c"
	{
		gboolean _tmp4_ = FALSE;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp4_ = boxes_vm_creator_install_trackable (self);
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_tmp4_) {
#line 4625 "vm-creator.c"
			gint _tmp5_ = 0;
			GVirStorageVol* _tmp6_ = NULL;
			gint _tmp7_ = 0;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp6_ = volume;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp7_ = boxes_vm_creator_get_progress (self, _tmp6_, &_inner_error_);
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp5_ = _tmp7_;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4637 "vm-creator.c"
				goto __catch103_g_error;
			}
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			result = _tmp5_ == BOXES_VM_CREATOR_INSTALL_COMPLETE_PERCENT;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (volume);
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return result;
#line 4646 "vm-creator.c"
		} else {
			gboolean _tmp8_ = FALSE;
			BoxesInstallerMedia* _tmp9_ = NULL;
			OsinfoMedia* _tmp10_ = NULL;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp9_ = self->priv->_install_media;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp10_ = _tmp9_->os_media;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (_tmp10_ != NULL) {
#line 4657 "vm-creator.c"
				BoxesLibvirtMachine* _tmp11_ = NULL;
				GVirConfigDomain* _tmp12_ = NULL;
				GVirConfigDomain* _tmp13_ = NULL;
				gboolean _tmp14_ = FALSE;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp11_ = machine;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp12_ = boxes_libvirt_machine_get_domain_config (_tmp11_);
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp13_ = _tmp12_;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp14_ = boxes_vm_configurator_is_install_config (_tmp13_);
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp8_ = _tmp14_;
#line 4672 "vm-creator.c"
			} else {
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp8_ = FALSE;
#line 4676 "vm-creator.c"
			}
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (_tmp8_) {
#line 4680 "vm-creator.c"
				guint _tmp15_ = 0U;
				BoxesInstallerMedia* _tmp16_ = NULL;
				OsinfoMedia* _tmp17_ = NULL;
				gint _tmp18_ = 0;
				gint _tmp19_ = 0;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp15_ = self->priv->_num_reboots;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp16_ = self->priv->_install_media;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp17_ = _tmp16_->os_media;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_object_get (_tmp17_, "installer-reboots", &_tmp18_, NULL);
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp19_ = _tmp18_;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				result = _tmp15_ == ((guint) _tmp19_);
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_object_unref0 (volume);
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				return result;
#line 4702 "vm-creator.c"
			} else {
				GVirStorageVolInfo* info = NULL;
				GVirStorageVol* _tmp20_ = NULL;
				GVirStorageVolInfo* _tmp21_ = NULL;
				GVirStorageVolInfo* _tmp22_ = NULL;
				guint64 _tmp23_ = 0ULL;
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp20_ = volume;
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp21_ = gvir_storage_vol_get_info (_tmp20_, &_inner_error_);
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				info = _tmp21_;
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4717 "vm-creator.c"
					goto __catch103_g_error;
				}
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp22_ = info;
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp23_ = _tmp22_->allocation;
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				result = _tmp23_ >= ((guint64) OSINFO_MEBIBYTES);
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				__vala_GVirStorageVolInfo_free0 (info);
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_object_unref0 (volume);
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				return result;
#line 4732 "vm-creator.c"
			}
		}
	}
	goto __finally103;
	__catch103_g_error:
	{
		GError* _error_ = NULL;
		GVirStorageVol* _tmp24_ = NULL;
		const gchar* _tmp25_ = NULL;
		GError* _tmp26_ = NULL;
		const gchar* _tmp27_ = NULL;
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_error_ = _inner_error_;
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_inner_error_ = NULL;
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp24_ = volume;
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp25_ = gvir_storage_vol_get_name (_tmp24_);
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp26_ = _error_;
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp27_ = _tmp26_->message;
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_warning ("vm-creator.vala:287: Failed to get information from volume '%s': %s", _tmp25_, _tmp27_);
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		result = FALSE;
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_error_free0 (_error_);
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (volume);
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return result;
#line 4766 "vm-creator.c"
	}
	__finally103:
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (volume);
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_clear_error (&_inner_error_);
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 4777 "vm-creator.c"
}


static Block79Data* block79_data_ref (Block79Data* _data79_) {
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_atomic_int_inc (&_data79_->_ref_count_);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return _data79_;
#line 4786 "vm-creator.c"
}


static void block79_data_unref (void * _userdata_) {
	Block79Data* _data79_;
	_data79_ = (Block79Data*) _userdata_;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_atomic_int_dec_and_test (&_data79_->_ref_count_)) {
#line 4795 "vm-creator.c"
		BoxesVMCreator* self;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		self = _data79_->self;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data79_->machine);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_boxes_vm_creator_unref0 (self);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_slice_free (Block79Data, _data79_);
#line 4805 "vm-creator.c"
	}
}


static gboolean __lambda86_ (Block79Data* _data79_) {
	BoxesVMCreator* self;
	gboolean result = FALSE;
	gint _tmp0_ = 0;
	gboolean _tmp2_ = FALSE;
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self = _data79_->self;
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = self->priv->prev_progress;
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp0_ == 100) {
#line 4821 "vm-creator.c"
		BoxesLibvirtMachine* _tmp1_ = NULL;
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp1_ = _data79_->machine;
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_machine_set_info ((BoxesMachine*) _tmp1_, NULL);
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		result = FALSE;
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return result;
#line 4831 "vm-creator.c"
	}
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = self->priv->updating_install_progress;
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (!_tmp2_) {
#line 4837 "vm-creator.c"
		BoxesLibvirtMachine* _tmp3_ = NULL;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp3_ = _data79_->machine;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_creator_update_install_progress (self, _tmp3_, NULL, NULL);
#line 4843 "vm-creator.c"
	}
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	result = TRUE;
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 4849 "vm-creator.c"
}


static gboolean ___lambda86__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda86_ (self);
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 4858 "vm-creator.c"
}


static void boxes_vm_creator_track_install_progress (BoxesVMCreator* self, BoxesLibvirtMachine* machine) {
	Block79Data* _data79_;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	BoxesLibvirtMachine* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	BoxesLibvirtMachine* _tmp3_ = NULL;
	GVirStorageVol* _tmp4_ = NULL;
	GVirStorageVol* _tmp5_ = NULL;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (machine != NULL);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data79_ = g_slice_new0 (Block79Data);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data79_->_ref_count_ = 1;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data79_->self = boxes_vm_creator_ref (self);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = machine;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data79_->machine);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data79_->machine = _tmp1_;
#line 295 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = boxes_vm_creator_install_trackable (self);
#line 295 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (!_tmp2_) {
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block79_data_unref (_data79_);
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data79_ = NULL;
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return;
#line 4898 "vm-creator.c"
	}
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = _data79_->machine;
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp4_ = boxes_libvirt_machine_get_storage_volume (_tmp3_);
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp5_ = _tmp4_;
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (_tmp5_ != NULL);
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) 6, ___lambda86__gsource_func, block79_data_ref (_data79_), block79_data_unref);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	block79_data_unref (_data79_);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data79_ = NULL;
#line 4914 "vm-creator.c"
}


static void boxes_vm_creator_update_install_progress_data_free (gpointer _data) {
	BoxesVmCreatorUpdateInstallProgressData* _data_;
	_data_ = _data;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_boxes_vm_creator_unref0 (_data_->self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_slice_free (BoxesVmCreatorUpdateInstallProgressData, _data_);
#line 4925 "vm-creator.c"
}


static void boxes_vm_creator_update_install_progress (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesVmCreatorUpdateInstallProgressData* _data_;
	BoxesVMCreator* _tmp0_ = NULL;
	BoxesLibvirtMachine* _tmp1_ = NULL;
	BoxesLibvirtMachine* _tmp2_ = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_slice_new0 (BoxesVmCreatorUpdateInstallProgressData);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_vm_creator_update_install_progress);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_vm_creator_update_install_progress_data_free);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _boxes_vm_creator_ref0 (self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = machine;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->machine);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->machine = _tmp2_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_update_install_progress_co (_data_);
#line 4954 "vm-creator.c"
}


static void boxes_vm_creator_update_install_progress_finish (BoxesVMCreator* self, GAsyncResult* _res_) {
	BoxesVmCreatorUpdateInstallProgressData* _data_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 4962 "vm-creator.c"
}


static Block80Data* block80_data_ref (Block80Data* _data80_) {
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_atomic_int_inc (&_data80_->_ref_count_);
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return _data80_;
#line 4971 "vm-creator.c"
}


static void block80_data_unref (void * _userdata_) {
	Block80Data* _data80_;
	_data80_ = (Block80Data*) _userdata_;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_atomic_int_dec_and_test (&_data80_->_ref_count_)) {
#line 4980 "vm-creator.c"
		BoxesVMCreator* self;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		self = _data80_->self;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data80_->machine);
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_boxes_vm_creator_unref0 (self);
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_slice_free (Block80Data, _data80_);
#line 4990 "vm-creator.c"
	}
}


static void ___lambda87_ (Block80Data* _data80_, GError** error) {
	BoxesVMCreator* self;
	gint _tmp0_ = 0;
	BoxesLibvirtMachine* _tmp1_ = NULL;
	GVirStorageVol* _tmp2_ = NULL;
	GVirStorageVol* _tmp3_ = NULL;
	gint _tmp4_ = 0;
	GError * _inner_error_ = NULL;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self = _data80_->self;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = _data80_->machine;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = boxes_libvirt_machine_get_storage_volume (_tmp1_);
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = _tmp2_;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp4_ = boxes_vm_creator_get_progress (self, _tmp3_, &_inner_error_);
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _tmp4_;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_propagate_error (error, _inner_error_);
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return;
#line 5021 "vm-creator.c"
	}
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data80_->progress = _tmp0_;
#line 5025 "vm-creator.c"
}


static void ____lambda87__boxes_run_in_thread_func (gpointer self, GError** error) {
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	___lambda87_ (self, error);
#line 5032 "vm-creator.c"
}


static void boxes_vm_creator_update_install_progress_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesVmCreatorUpdateInstallProgressData* _data_;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = _user_data_;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_source_object_ = source_object;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_res_ = _res_;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_update_install_progress_co (_data_);
#line 5046 "vm-creator.c"
}


static gboolean boxes_vm_creator_update_install_progress_co (BoxesVmCreatorUpdateInstallProgressData* _data_) {
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	switch (_data_->_state_) {
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 0:
#line 5055 "vm-creator.c"
		goto _state_0;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 1:
#line 5059 "vm-creator.c"
		goto _state_1;
		default:
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_assert_not_reached ();
#line 5064 "vm-creator.c"
	}
	_state_0:
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data80_ = g_slice_new0 (Block80Data);
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data80_->_ref_count_ = 1;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data80_->self = boxes_vm_creator_ref (_data_->self);
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = NULL;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = _data_->machine;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->_data80_->machine);
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data80_->machine = _data_->_tmp0_;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data80_->_async_data_ = _data_;
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self->priv->updating_install_progress = TRUE;
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data80_->progress = 0;
#line 5087 "vm-creator.c"
	{
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_state_ = 1;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_run_in_thread (____lambda87__boxes_run_in_thread_func, block80_data_ref (_data_->_data80_), block80_data_unref, boxes_vm_creator_update_install_progress_ready, _data_);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 5095 "vm-creator.c"
		_state_1:
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_run_in_thread_finish (_data_->_res_, &_data_->_inner_error_);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 5101 "vm-creator.c"
			goto __catch104_g_error;
		}
	}
	goto __finally104;
	__catch104_g_error:
	{
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_inner_error_ = NULL;
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp1_ = NULL;
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp1_ = _data_->_data80_->machine;
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp2_ = NULL;
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp2_ = boxes_libvirt_machine_get_storage_volume (_data_->_tmp1_);
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp3_ = NULL;
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp3_ = _data_->_tmp2_;
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp4_ = NULL;
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp4_ = gvir_storage_vol_get_name (_data_->_tmp3_);
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp5_ = NULL;
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp5_ = _data_->_error_;
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp6_ = NULL;
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp6_ = _data_->_tmp5_->message;
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_warning ("vm-creator.vala:323: Failed to get information from volume '%s': %s", _data_->_tmp4_, _data_->_tmp6_);
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_error_free0 (_data_->_error_);
#line 5140 "vm-creator.c"
	}
	__finally104:
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block80_data_unref (_data_->_data80_);
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data80_ = NULL;
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_clear_error (&_data_->_inner_error_);
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 5155 "vm-creator.c"
	}
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_data80_->progress < 0) {
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block80_data_unref (_data_->_data80_);
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data80_ = NULL;
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5167 "vm-creator.c"
		} else {
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 5171 "vm-creator.c"
		}
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 5177 "vm-creator.c"
	}
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp7_ = NULL;
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp7_ = _data_->_data80_->machine;
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp8_ = NULL;
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp8_ = ngettext ("%d%% Installed", "%d%% Installed", (gulong) _data_->_data80_->progress);
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp9_ = NULL;
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp9_ = g_strdup_printf (_data_->_tmp8_, _data_->_data80_->progress);
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp10_ = NULL;
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp10_ = _data_->_tmp9_;
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_machine_set_info ((BoxesMachine*) _data_->_tmp7_, _data_->_tmp10_);
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->_tmp10_);
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self->priv->prev_progress = _data_->_data80_->progress;
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self->priv->updating_install_progress = FALSE;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	block80_data_unref (_data_->_data80_);
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data80_ = NULL;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5211 "vm-creator.c"
	} else {
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 5215 "vm-creator.c"
	}
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 5221 "vm-creator.c"
}


static gboolean boxes_vm_creator_install_trackable (BoxesVMCreator* self) {
	gboolean result = FALSE;
	BoxesInstallerMedia* _tmp0_ = NULL;
	guint64 _tmp1_ = 0ULL;
	guint64 _tmp2_ = 0ULL;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = self->priv->_install_media;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = boxes_installer_media_get_installed_size (_tmp0_);
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _tmp1_;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	result = _tmp2_ > ((guint64) 0);
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 5242 "vm-creator.c"
}


static gint boxes_vm_creator_get_progress (BoxesVMCreator* self, GVirStorageVol* volume, GError** error) {
	gint result = 0;
	GVirStorageVolInfo* volume_info = NULL;
	GVirStorageVol* _tmp0_ = NULL;
	GVirStorageVolInfo* _tmp1_ = NULL;
	gint percent = 0;
	guint64 _tmp2_ = 0ULL;
	BoxesInstallerMedia* _tmp3_ = NULL;
	guint64 _tmp4_ = 0ULL;
	guint64 _tmp5_ = 0ULL;
	gint _tmp6_ = 0;
	gint _tmp7_ = 0;
	gint _tmp8_ = 0;
	GError * _inner_error_ = NULL;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (volume != NULL, 0);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = volume;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = gvir_storage_vol_get_info (_tmp0_, &_inner_error_);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	volume_info = _tmp1_;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_propagate_error (error, _inner_error_);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return 0;
#line 5276 "vm-creator.c"
	}
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = volume_info->allocation;
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = self->priv->_install_media;
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp4_ = boxes_installer_media_get_installed_size (_tmp3_);
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp5_ = _tmp4_;
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	percent = (gint) ((_tmp2_ * 100) / _tmp5_);
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp6_ = percent;
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp7_ = CLAMP (_tmp6_, 0, BOXES_VM_CREATOR_INSTALL_COMPLETE_PERCENT);
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	percent = _tmp7_;
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp8_ = percent;
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp8_ == BOXES_VM_CREATOR_INSTALL_COMPLETE_PERCENT) {
#line 350 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		percent = 100;
#line 5300 "vm-creator.c"
	}
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	result = percent;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	__vala_GVirStorageVolInfo_free0 (volume_info);
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 5308 "vm-creator.c"
}


static void boxes_vm_creator_create_domain_name_and_title_from_media_data_free (gpointer _data) {
	BoxesVmCreatorCreateDomainNameAndTitleFromMediaData* _data_;
	_data_ = _data;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_boxes_vm_creator_unref0 (_data_->self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_slice_free (BoxesVmCreatorCreateDomainNameAndTitleFromMediaData, _data_);
#line 5319 "vm-creator.c"
}


static void boxes_vm_creator_create_domain_name_and_title_from_media (BoxesVMCreator* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesVmCreatorCreateDomainNameAndTitleFromMediaData* _data_;
	BoxesVMCreator* _tmp0_ = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_slice_new0 (BoxesVmCreatorCreateDomainNameAndTitleFromMediaData);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_vm_creator_create_domain_name_and_title_from_media);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_vm_creator_create_domain_name_and_title_from_media_data_free);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _boxes_vm_creator_ref0 (self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_domain_name_and_title_from_media_co (_data_);
#line 5338 "vm-creator.c"
}


static void boxes_vm_creator_create_domain_name_and_title_from_media_finish (BoxesVMCreator* self, GAsyncResult* _res_, gchar** name, gchar** title, GError** error) {
	BoxesVmCreatorCreateDomainNameAndTitleFromMediaData* _data_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return;
#line 5348 "vm-creator.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (name) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		*name = _data_->name;
#line 5356 "vm-creator.c"
	} else {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 5360 "vm-creator.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->name = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (title) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		*title = _data_->title;
#line 5368 "vm-creator.c"
	} else {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 5372 "vm-creator.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->title = NULL;
#line 5376 "vm-creator.c"
}


static void boxes_vm_creator_create_domain_name_and_title_from_media_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesVmCreatorCreateDomainNameAndTitleFromMediaData* _data_;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = _user_data_;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_source_object_ = source_object;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_res_ = _res_;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_domain_name_and_title_from_media_co (_data_);
#line 5390 "vm-creator.c"
}


static gboolean boxes_vm_creator_create_domain_name_and_title_from_media_co (BoxesVmCreatorCreateDomainNameAndTitleFromMediaData* _data_) {
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	switch (_data_->_state_) {
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 0:
#line 5399 "vm-creator.c"
		goto _state_0;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 1:
#line 5403 "vm-creator.c"
		goto _state_1;
		default:
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_assert_not_reached ();
#line 5408 "vm-creator.c"
	}
	_state_0:
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = NULL;
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = NULL;
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_domain_base_name_and_title (_data_->self, &_data_->_tmp0_, &_data_->_tmp1_);
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->base_name);
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->base_name = _data_->_tmp0_;
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->base_title);
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->base_title = _data_->_tmp1_;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = NULL;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = g_strdup (_data_->base_name);
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->name = _data_->_tmp2_;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = NULL;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = g_strdup (_data_->base_title);
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->title);
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->title = _data_->_tmp3_;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_state_ = 1;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_get_storage_pool (_data_->self, boxes_vm_creator_create_domain_name_and_title_from_media_ready, _data_);
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 5447 "vm-creator.c"
	_state_1:
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp4_ = NULL;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp4_ = boxes_vm_creator_get_storage_pool_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->pool = _data_->_tmp4_;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->base_title);
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->base_name);
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5469 "vm-creator.c"
		} else {
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 5473 "vm-creator.c"
		}
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 5479 "vm-creator.c"
	}
	{
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->i = 2;
#line 5484 "vm-creator.c"
		{
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp5_ = TRUE;
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			while (TRUE) {
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				if (!_data_->_tmp5_) {
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp6_ = 0;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp6_ = _data_->i;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->i = _data_->_tmp6_ + 1;
#line 5498 "vm-creator.c"
				}
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp5_ = FALSE;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp9_ = NULL;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp9_ = boxes_vm_creator_get_connection (_data_->self);
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp10_ = NULL;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp10_ = _data_->_tmp9_;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp11_ = NULL;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp11_ = _data_->_tmp10_;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp12_ = NULL;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp12_ = _data_->name;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp13_ = NULL;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp13_ = gvir_connection_find_domain_by_name (_data_->_tmp11_, _data_->_tmp12_);
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp14_ = NULL;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp14_ = _data_->_tmp13_;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp15_ = FALSE;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp15_ = _data_->_tmp14_ != NULL;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_object_unref0 (_data_->_tmp14_);
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_object_unref0 (_data_->_tmp11_);
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				if (_data_->_tmp15_) {
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp8_ = TRUE;
#line 5538 "vm-creator.c"
				} else {
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp16_ = NULL;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp16_ = boxes_vm_creator_get_connection (_data_->self);
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp17_ = NULL;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp17_ = _data_->_tmp16_;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp18_ = NULL;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp18_ = _data_->_tmp17_;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp19_ = NULL;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp19_ = _data_->title;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp20_ = NULL;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp20_ = gvir_connection_find_domain_by_name (_data_->_tmp18_, _data_->_tmp19_);
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp21_ = NULL;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp21_ = _data_->_tmp20_;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp8_ = _data_->_tmp21_ != NULL;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_g_object_unref0 (_data_->_tmp21_);
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_g_object_unref0 (_data_->_tmp18_);
#line 5570 "vm-creator.c"
				}
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				if (_data_->_tmp8_) {
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp7_ = TRUE;
#line 5576 "vm-creator.c"
				} else {
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp22_ = NULL;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp22_ = _data_->name;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp23_ = NULL;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp23_ = gvir_storage_pool_get_volume (_data_->pool, _data_->_tmp22_);
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp24_ = NULL;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp24_ = _data_->_tmp23_;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp7_ = _data_->_tmp24_ != NULL;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_g_object_unref0 (_data_->_tmp24_);
#line 5594 "vm-creator.c"
				}
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				if (!_data_->_tmp7_) {
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					break;
#line 5600 "vm-creator.c"
				}
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp25_ = NULL;
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp25_ = g_strconcat (_data_->base_name, "-", NULL);
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp26_ = NULL;
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp26_ = _data_->_tmp25_;
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp27_ = 0;
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp27_ = _data_->i;
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp28_ = NULL;
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp28_ = g_strdup_printf ("%i", _data_->_tmp27_);
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp29_ = NULL;
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp29_ = _data_->_tmp28_;
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp30_ = NULL;
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp30_ = g_strconcat (_data_->_tmp26_, _data_->_tmp29_, NULL);
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_data_->name);
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->name = _data_->_tmp30_;
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_data_->_tmp29_);
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_data_->_tmp26_);
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp31_ = NULL;
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp31_ = g_strconcat (_data_->base_title, " ", NULL);
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp32_ = NULL;
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp32_ = _data_->_tmp31_;
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp33_ = 0;
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp33_ = _data_->i;
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp34_ = NULL;
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp34_ = g_strdup_printf ("%i", _data_->_tmp33_);
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp35_ = NULL;
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp35_ = _data_->_tmp34_;
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp36_ = NULL;
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp36_ = g_strconcat (_data_->_tmp32_, _data_->_tmp35_, NULL);
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_data_->title);
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->title = _data_->_tmp36_;
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_data_->_tmp35_);
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_data_->_tmp32_);
#line 5666 "vm-creator.c"
			}
		}
	}
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->pool);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->base_title);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->base_name);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5680 "vm-creator.c"
	} else {
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 5684 "vm-creator.c"
	}
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 5690 "vm-creator.c"
}


static void boxes_vm_creator_create_target_volume_data_free (gpointer _data) {
	BoxesVmCreatorCreateTargetVolumeData* _data_;
	_data_ = _data;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->result);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_boxes_vm_creator_unref0 (_data_->self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_slice_free (BoxesVmCreatorCreateTargetVolumeData, _data_);
#line 5705 "vm-creator.c"
}


static void boxes_vm_creator_create_target_volume (BoxesVMCreator* self, const gchar* name, gint64 storage, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesVmCreatorCreateTargetVolumeData* _data_;
	BoxesVMCreator* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gint64 _tmp3_ = 0LL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_slice_new0 (BoxesVmCreatorCreateTargetVolumeData);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_vm_creator_create_target_volume);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_vm_creator_create_target_volume_data_free);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _boxes_vm_creator_ref0 (self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = name;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->name = _tmp2_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = storage;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->storage = _tmp3_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_target_volume_co (_data_);
#line 5739 "vm-creator.c"
}


static GVirStorageVol* boxes_vm_creator_create_target_volume_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error) {
	GVirStorageVol* result;
	BoxesVmCreatorCreateTargetVolumeData* _data_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return NULL;
#line 5750 "vm-creator.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	result = _data_->result;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->result = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 5760 "vm-creator.c"
}


static void boxes_vm_creator_create_target_volume_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesVmCreatorCreateTargetVolumeData* _data_;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = _user_data_;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_source_object_ = source_object;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_res_ = _res_;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_target_volume_co (_data_);
#line 5774 "vm-creator.c"
}


static gboolean boxes_vm_creator_create_target_volume_co (BoxesVmCreatorCreateTargetVolumeData* _data_) {
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	switch (_data_->_state_) {
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 0:
#line 5783 "vm-creator.c"
		goto _state_0;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 1:
#line 5787 "vm-creator.c"
		goto _state_1;
		default:
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_assert_not_reached ();
#line 5792 "vm-creator.c"
	}
	_state_0:
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_state_ = 1;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_get_storage_pool (_data_->self, boxes_vm_creator_create_target_volume_ready, _data_);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 5801 "vm-creator.c"
	_state_1:
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = NULL;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = boxes_vm_creator_get_storage_pool_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->pool = _data_->_tmp0_;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5819 "vm-creator.c"
		} else {
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 5823 "vm-creator.c"
		}
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 5829 "vm-creator.c"
	}
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = NULL;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = _data_->name;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = 0LL;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = _data_->storage;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = NULL;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = boxes_vm_configurator_create_volume_config (_data_->_tmp1_, _data_->_tmp2_, &_data_->_inner_error_);
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->config = _data_->_tmp3_;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->pool);
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5857 "vm-creator.c"
		} else {
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 5861 "vm-creator.c"
		}
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 5867 "vm-creator.c"
	}
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp4_ = NULL;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp4_ = _data_->name;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_debug ("vm-creator.vala:377: Creating volume '%s'..", _data_->_tmp4_);
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp5_ = NULL;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp5_ = _data_->pool;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp6_ = NULL;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp6_ = _data_->config;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp7_ = NULL;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp7_ = gvir_storage_pool_create_volume (_data_->_tmp5_, _data_->_tmp6_, &_data_->_inner_error_);
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->volume = _data_->_tmp7_;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->config);
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->pool);
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5903 "vm-creator.c"
		} else {
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 5907 "vm-creator.c"
		}
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 5913 "vm-creator.c"
	}
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp8_ = NULL;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp8_ = _data_->name;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_debug ("vm-creator.vala:379: Created volume '%s'.", _data_->_tmp8_);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->result = _data_->volume;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->config);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->pool);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5931 "vm-creator.c"
	} else {
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 5935 "vm-creator.c"
	}
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->volume);
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->config);
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->pool);
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5951 "vm-creator.c"
	} else {
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 5955 "vm-creator.c"
	}
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 5961 "vm-creator.c"
}


BoxesInstallerMedia* boxes_vm_creator_get_install_media (BoxesVMCreator* self) {
	BoxesInstallerMedia* result;
	BoxesInstallerMedia* _tmp0_ = NULL;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = self->priv->_install_media;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	result = _tmp0_;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 5976 "vm-creator.c"
}


void boxes_vm_creator_set_install_media (BoxesVMCreator* self, BoxesInstallerMedia* value) {
	BoxesInstallerMedia* _tmp0_ = NULL;
	BoxesInstallerMedia* _tmp1_ = NULL;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = value;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (self->priv->_install_media);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self->priv->_install_media = _tmp1_;
#line 5993 "vm-creator.c"
}


static GVirConnection* boxes_vm_creator_get_connection (BoxesVMCreator* self) {
	GVirConnection* result;
	BoxesApp* _tmp0_ = NULL;
	GVirConnection* _tmp1_ = NULL;
	GVirConnection* _tmp2_ = NULL;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = boxes_app_app;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = boxes_app_get_default_connection (_tmp0_);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _tmp1_;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	result = _tmp2_;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 6014 "vm-creator.c"
}


static guint boxes_vm_creator_get_num_reboots (BoxesVMCreator* self) {
	guint result;
	guint _tmp0_ = 0U;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (self != NULL, 0U);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = self->priv->_num_reboots;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	result = _tmp0_;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 6029 "vm-creator.c"
}


static void boxes_vm_creator_set_num_reboots (BoxesVMCreator* self, guint value) {
	guint _tmp0_ = 0U;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = value;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self->priv->_num_reboots = _tmp0_;
#line 6041 "vm-creator.c"
}


static void boxes_value_vm_creator_init (GValue* value) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	value->data[0].v_pointer = NULL;
#line 6048 "vm-creator.c"
}


static void boxes_value_vm_creator_free_value (GValue* value) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (value->data[0].v_pointer) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_creator_unref (value->data[0].v_pointer);
#line 6057 "vm-creator.c"
	}
}


static void boxes_value_vm_creator_copy_value (const GValue* src_value, GValue* dest_value) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (src_value->data[0].v_pointer) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		dest_value->data[0].v_pointer = boxes_vm_creator_ref (src_value->data[0].v_pointer);
#line 6067 "vm-creator.c"
	} else {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		dest_value->data[0].v_pointer = NULL;
#line 6071 "vm-creator.c"
	}
}


static gpointer boxes_value_vm_creator_peek_pointer (const GValue* value) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return value->data[0].v_pointer;
#line 6079 "vm-creator.c"
}


static gchar* boxes_value_vm_creator_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (collect_values[0].v_pointer) {
#line 6086 "vm-creator.c"
		BoxesVMCreator* object;
		object = collect_values[0].v_pointer;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (object->parent_instance.g_class == NULL) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 6093 "vm-creator.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 6097 "vm-creator.c"
		}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		value->data[0].v_pointer = boxes_vm_creator_ref (object);
#line 6101 "vm-creator.c"
	} else {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		value->data[0].v_pointer = NULL;
#line 6105 "vm-creator.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return NULL;
#line 6109 "vm-creator.c"
}


static gchar* boxes_value_vm_creator_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	BoxesVMCreator** object_p;
	object_p = collect_values[0].v_pointer;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (!object_p) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 6120 "vm-creator.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (!value->data[0].v_pointer) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		*object_p = NULL;
#line 6126 "vm-creator.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		*object_p = value->data[0].v_pointer;
#line 6130 "vm-creator.c"
	} else {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		*object_p = boxes_vm_creator_ref (value->data[0].v_pointer);
#line 6134 "vm-creator.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return NULL;
#line 6138 "vm-creator.c"
}


GParamSpec* boxes_param_spec_vm_creator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	BoxesParamSpecVMCreator* spec;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (g_type_is_a (object_type, BOXES_TYPE_VM_CREATOR), NULL);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return G_PARAM_SPEC (spec);
#line 6152 "vm-creator.c"
}


gpointer boxes_value_get_vm_creator (const GValue* value) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, BOXES_TYPE_VM_CREATOR), NULL);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return value->data[0].v_pointer;
#line 6161 "vm-creator.c"
}


void boxes_value_set_vm_creator (GValue* value, gpointer v_object) {
	BoxesVMCreator* old;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, BOXES_TYPE_VM_CREATOR));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	old = value->data[0].v_pointer;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (v_object) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, BOXES_TYPE_VM_CREATOR));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		value->data[0].v_pointer = v_object;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_creator_ref (value->data[0].v_pointer);
#line 6181 "vm-creator.c"
	} else {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		value->data[0].v_pointer = NULL;
#line 6185 "vm-creator.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (old) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_creator_unref (old);
#line 6191 "vm-creator.c"
	}
}


void boxes_value_take_vm_creator (GValue* value, gpointer v_object) {
	BoxesVMCreator* old;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, BOXES_TYPE_VM_CREATOR));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	old = value->data[0].v_pointer;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (v_object) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, BOXES_TYPE_VM_CREATOR));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		value->data[0].v_pointer = v_object;
#line 6210 "vm-creator.c"
	} else {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		value->data[0].v_pointer = NULL;
#line 6214 "vm-creator.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (old) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_creator_unref (old);
#line 6220 "vm-creator.c"
	}
}


static void boxes_vm_creator_class_init (BoxesVMCreatorClass * klass) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_parent_class = g_type_class_peek_parent (klass);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	((BoxesVMCreatorClass *) klass)->finalize = boxes_vm_creator_finalize;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_type_class_add_private (klass, sizeof (BoxesVMCreatorPrivate));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	((BoxesVMCreatorClass *) klass)->launch_vm = boxes_vm_creator_real_launch_vm;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	((BoxesVMCreatorClass *) klass)->continue_installation = boxes_vm_creator_real_continue_installation;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	((BoxesVMCreatorClass *) klass)->continue_installation_finish = boxes_vm_creator_real_continue_installation_finish;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	((BoxesVMCreatorClass *) klass)->update_machine_info = boxes_vm_creator_real_update_machine_info;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	((BoxesVMCreatorClass *) klass)->create_domain_config = boxes_vm_creator_real_create_domain_config;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	((BoxesVMCreatorClass *) klass)->create_domain_config_finish = boxes_vm_creator_real_create_domain_config_finish;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	((BoxesVMCreatorClass *) klass)->create_domain_base_name_and_title = boxes_vm_creator_real_create_domain_base_name_and_title;
#line 6246 "vm-creator.c"
}


static void boxes_vm_creator_instance_init (BoxesVMCreator * self) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self->priv = BOXES_VM_CREATOR_GET_PRIVATE (self);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self->priv->prev_progress = 0;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self->ref_count = 1;
#line 6257 "vm-creator.c"
}


static void boxes_vm_creator_finalize (BoxesVMCreator* obj) {
	BoxesVMCreator * self;
	BoxesInstallerMedia* _tmp0_ = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_VM_CREATOR, BoxesVMCreator);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_signal_handlers_destroy (self);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = self->priv->_install_media;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp0_ != NULL) {
#line 6272 "vm-creator.c"
		BoxesInstallerMedia* _tmp1_ = NULL;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp1_ = self->priv->_install_media;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_installer_media_clean_up (_tmp1_);
#line 6278 "vm-creator.c"
	}
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (self->priv->_install_media);
#line 6282 "vm-creator.c"
}


GType boxes_vm_creator_get_type (void) {
	static volatile gsize boxes_vm_creator_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_vm_creator_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { boxes_value_vm_creator_init, boxes_value_vm_creator_free_value, boxes_value_vm_creator_copy_value, boxes_value_vm_creator_peek_pointer, "p", boxes_value_vm_creator_collect_value, "p", boxes_value_vm_creator_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (BoxesVMCreatorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_vm_creator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesVMCreator), 0, (GInstanceInitFunc) boxes_vm_creator_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType boxes_vm_creator_type_id;
		boxes_vm_creator_type_id = g_type_register_fundamental (g_type_fundamental_next (), "BoxesVMCreator", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&boxes_vm_creator_type_id__volatile, boxes_vm_creator_type_id);
	}
	return boxes_vm_creator_type_id__volatile;
}


gpointer boxes_vm_creator_ref (gpointer instance) {
	BoxesVMCreator* self;
	self = instance;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_atomic_int_inc (&self->ref_count);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return instance;
#line 6307 "vm-creator.c"
}


void boxes_vm_creator_unref (gpointer instance) {
	BoxesVMCreator* self;
	self = instance;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		BOXES_VM_CREATOR_GET_CLASS (self)->finalize (self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 6320 "vm-creator.c"
	}
}



