/* wizard.c generated by valac 0.25.2.7-aa52, the Vala compiler
 * generated from wizard.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <libcommon.h>
#include <gio/gio.h>
#include <float.h>
#include <math.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include <libxml/uri.h>
#include <libgd/gd.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <osinfo/osinfo.h>
#include <libvirt-gobject/libvirt-gobject.h>
#include <pango/pango.h>


#define BOXES_TYPE_WIZARD_PAGE (boxes_wizard_page_get_type ())

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;
typedef struct _BoxesWizardPrivate BoxesWizardPrivate;

#define BOXES_TYPE_WIZARD_SOURCE (boxes_wizard_source_get_type ())
#define BOXES_WIZARD_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSource))
#define BOXES_WIZARD_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSourceClass))
#define BOXES_IS_WIZARD_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_SOURCE))
#define BOXES_IS_WIZARD_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_SOURCE))
#define BOXES_WIZARD_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSourceClass))

typedef struct _BoxesWizardSource BoxesWizardSource;
typedef struct _BoxesWizardSourceClass BoxesWizardSourceClass;

#define BOXES_TYPE_WIZARD_SUMMARY (boxes_wizard_summary_get_type ())
#define BOXES_WIZARD_SUMMARY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_SUMMARY, BoxesWizardSummary))
#define BOXES_WIZARD_SUMMARY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_SUMMARY, BoxesWizardSummaryClass))
#define BOXES_IS_WIZARD_SUMMARY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_SUMMARY))
#define BOXES_IS_WIZARD_SUMMARY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_SUMMARY))
#define BOXES_WIZARD_SUMMARY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_SUMMARY, BoxesWizardSummaryClass))

typedef struct _BoxesWizardSummary BoxesWizardSummary;
typedef struct _BoxesWizardSummaryClass BoxesWizardSummaryClass;

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;

#define BOXES_TYPE_MEDIA_MANAGER (boxes_media_manager_get_type ())
#define BOXES_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManager))
#define BOXES_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))
#define BOXES_IS_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_IS_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_MEDIA_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))

typedef struct _BoxesMediaManager BoxesMediaManager;
typedef struct _BoxesMediaManagerClass BoxesMediaManagerClass;

#define BOXES_TYPE_VM_CREATOR (boxes_vm_creator_get_type ())
#define BOXES_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreator))
#define BOXES_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))
#define BOXES_IS_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VM_CREATOR))
#define BOXES_IS_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VM_CREATOR))
#define BOXES_VM_CREATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))

typedef struct _BoxesVMCreator BoxesVMCreator;
typedef struct _BoxesVMCreatorClass BoxesVMCreatorClass;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _boxes_vm_creator_unref0(var) ((var == NULL) ? NULL : (var = (boxes_vm_creator_unref (var), NULL)))
typedef struct _Block84Data Block84Data;

#define BOXES_TYPE_SOURCE_PAGE (boxes_source_page_get_type ())

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _Block85Data Block85Data;

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;

#define BOXES_TYPE_INSTALLER_MEDIA (boxes_installer_media_get_type ())
#define BOXES_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia))
#define BOXES_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))
#define BOXES_IS_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_IS_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_INSTALLER_MEDIA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))

typedef struct _BoxesInstallerMedia BoxesInstallerMedia;
typedef struct _BoxesInstallerMediaClass BoxesInstallerMediaClass;
typedef struct _BoxesWizardSourcePrivate BoxesWizardSourcePrivate;

#define BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER (boxes_libvirt_system_importer_get_type ())
#define BOXES_LIBVIRT_SYSTEM_IMPORTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER, BoxesLibvirtSystemImporter))
#define BOXES_LIBVIRT_SYSTEM_IMPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER, BoxesLibvirtSystemImporterClass))
#define BOXES_IS_LIBVIRT_SYSTEM_IMPORTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER))
#define BOXES_IS_LIBVIRT_SYSTEM_IMPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER))
#define BOXES_LIBVIRT_SYSTEM_IMPORTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER, BoxesLibvirtSystemImporterClass))

typedef struct _BoxesLibvirtSystemImporter BoxesLibvirtSystemImporter;
typedef struct _BoxesLibvirtSystemImporterClass BoxesLibvirtSystemImporterClass;
typedef struct _BoxesWizardCreateData BoxesWizardCreateData;
#define _xmlFreeURI0(var) ((var == NULL) ? NULL : (var = (xmlFreeURI (var), NULL)))
typedef struct _Block86Data Block86Data;
typedef struct _BoxesAppWindowPrivate BoxesAppWindowPrivate;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;
typedef struct _BoxesInstallerMediaPrivate BoxesInstallerMediaPrivate;
typedef struct _BoxesWizardPrepareMediaData BoxesWizardPrepareMediaData;
typedef struct _BoxesWizardReviewData BoxesWizardReviewData;

#define BOXES_TYPE_REMOTE_MACHINE (boxes_remote_machine_get_type ())
#define BOXES_REMOTE_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REMOTE_MACHINE, BoxesRemoteMachine))
#define BOXES_REMOTE_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REMOTE_MACHINE, BoxesRemoteMachineClass))
#define BOXES_IS_REMOTE_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REMOTE_MACHINE))
#define BOXES_IS_REMOTE_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REMOTE_MACHINE))
#define BOXES_REMOTE_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REMOTE_MACHINE, BoxesRemoteMachineClass))

typedef struct _BoxesRemoteMachine BoxesRemoteMachine;
typedef struct _BoxesRemoteMachineClass BoxesRemoteMachineClass;
#define _boxes_pair_unref0(var) ((var == NULL) ? NULL : (var = (boxes_pair_unref (var), NULL)))
#define __g_list_free__boxes_pair_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__boxes_pair_unref0_ (var), NULL)))
typedef struct _Block87Data Block87Data;
#define __vala_GVirStorageVolInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirStorageVolInfo_free (var), NULL)))
typedef struct _BoxesWizardDoReviewCancellableData BoxesWizardDoReviewCancellableData;
typedef struct _BoxesWizardDownloadMediaData BoxesWizardDownloadMediaData;
typedef struct _Block88Data Block88Data;
typedef struct _BoxesTopbarPrivate BoxesTopbarPrivate;

#define BOXES_TYPE_PROPERTIES_TOOLBAR (boxes_properties_toolbar_get_type ())
#define BOXES_PROPERTIES_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES_TOOLBAR, BoxesPropertiesToolbar))
#define BOXES_PROPERTIES_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES_TOOLBAR, BoxesPropertiesToolbarClass))
#define BOXES_IS_PROPERTIES_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES_TOOLBAR))
#define BOXES_IS_PROPERTIES_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES_TOOLBAR))
#define BOXES_PROPERTIES_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES_TOOLBAR, BoxesPropertiesToolbarClass))

typedef struct _BoxesPropertiesToolbar BoxesPropertiesToolbar;
typedef struct _BoxesPropertiesToolbarClass BoxesPropertiesToolbarClass;

#define BOXES_TYPE_WIZARD_TOOLBAR (boxes_wizard_toolbar_get_type ())
#define BOXES_WIZARD_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_TOOLBAR, BoxesWizardToolbar))
#define BOXES_WIZARD_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_TOOLBAR, BoxesWizardToolbarClass))
#define BOXES_IS_WIZARD_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_TOOLBAR))
#define BOXES_IS_WIZARD_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_TOOLBAR))
#define BOXES_WIZARD_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_TOOLBAR, BoxesWizardToolbarClass))

typedef struct _BoxesWizardToolbar BoxesWizardToolbar;
typedef struct _BoxesWizardToolbarClass BoxesWizardToolbarClass;
typedef struct _BoxesWizardToolbarPrivate BoxesWizardToolbarPrivate;
typedef struct _BoxesSidebarPrivate BoxesSidebarPrivate;

#define BOXES_TYPE_WIZARD_SIDEBAR (boxes_wizard_sidebar_get_type ())
#define BOXES_WIZARD_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_SIDEBAR, BoxesWizardSidebar))
#define BOXES_WIZARD_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_SIDEBAR, BoxesWizardSidebarClass))
#define BOXES_IS_WIZARD_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_SIDEBAR))
#define BOXES_IS_WIZARD_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_SIDEBAR))
#define BOXES_WIZARD_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_SIDEBAR, BoxesWizardSidebarClass))

typedef struct _BoxesWizardSidebar BoxesWizardSidebar;
typedef struct _BoxesWizardSidebarClass BoxesWizardSidebarClass;

#define BOXES_TYPE_PROPERTIES_SIDEBAR (boxes_properties_sidebar_get_type ())
#define BOXES_PROPERTIES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES_SIDEBAR, BoxesPropertiesSidebar))
#define BOXES_PROPERTIES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES_SIDEBAR, BoxesPropertiesSidebarClass))
#define BOXES_IS_PROPERTIES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES_SIDEBAR))
#define BOXES_IS_PROPERTIES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES_SIDEBAR))
#define BOXES_PROPERTIES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES_SIDEBAR, BoxesPropertiesSidebarClass))

typedef struct _BoxesPropertiesSidebar BoxesPropertiesSidebar;
typedef struct _BoxesPropertiesSidebarClass BoxesPropertiesSidebarClass;
typedef struct _BoxesWizardSummaryPrivate BoxesWizardSummaryPrivate;
typedef struct _Block89Data Block89Data;
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))

typedef enum  {
	BOXES_WIZARD_PAGE_INTRODUCTION,
	BOXES_WIZARD_PAGE_SOURCE,
	BOXES_WIZARD_PAGE_PREPARATION,
	BOXES_WIZARD_PAGE_SETUP,
	BOXES_WIZARD_PAGE_REVIEW,
	BOXES_WIZARD_PAGE_LAST
} BoxesWizardPage;

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesWizard {
	GtkStack parent_instance;
	BoxesWizardPrivate * priv;
};

struct _BoxesWizardClass {
	GtkStackClass parent_class;
};

struct _BoxesWizardPrivate {
	BoxesUIState _previous_ui_state;
	BoxesUIState _ui_state;
	GtkButton* cancel_button;
	GtkButton* back_button;
	GtkButton* next_button;
	GtkButton* continue_button;
	GtkButton* create_button;
	BoxesCollectionSource* source;
	BoxesWizardSource* wizard_source;
	BoxesWizardSummary* summary;
	GtkProgressBar* prep_progress;
	GtkLabel* prep_media_label;
	GtkLabel* prep_status_label;
	GtkBox* setup_box;
	GtkLabel* review_label;
	GtkInfoBar* nokvm_infobar;
	GtkImage* installer_image;
	BoxesAppWindow* window;
	BoxesMediaManager* media_manager;
	BoxesVMCreator* vm_creator;
	BoxesMachine* _machine;
	GCancellable* prepare_cancellable;
	GCancellable* review_cancellable;
	gboolean skip_review_for_live;
	BoxesWizardPage _page;
};

struct _Block84Data {
	int _ref_count_;
	BoxesWizard* self;
	BoxesActivityProgress* progress;
};

typedef enum  {
	BOXES_SOURCE_PAGE_MAIN,
	BOXES_SOURCE_PAGE_URL,
	BOXES_SOURCE_PAGE_LAST
} BoxesSourcePage;

struct _Block85Data {
	int _ref_count_;
	BoxesWizard* self;
	gpointer _async_data_;
};

struct _BoxesWizardSource {
	GtkStack parent_instance;
	BoxesWizardSourcePrivate * priv;
	gboolean libvirt_sys_import;
	GtkEntry* url_entry;
	BoxesMediaManager* media_manager;
};

struct _BoxesWizardSourceClass {
	GtkStackClass parent_class;
};

struct _BoxesWizardCreateData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesWizard* self;
	gboolean result;
	Block85Data* _data85_;
	BoxesVMCreator* _tmp0_;
	BoxesLibvirtMachine* _tmp1_;
	BoxesLibvirtMachine* _tmp2_;
	GCancellable* _tmp3_;
	gulong wait;
	gulong _tmp4_;
	gulong _tmp5_;
	BoxesLibvirtMachine* _tmp6_;
	BoxesLibvirtMachine* _tmp7_;
	GtkButton* _tmp8_;
	BoxesVMCreator* _tmp9_;
	BoxesLibvirtMachine* _tmp10_;
	BoxesLibvirtMachine* _tmp11_;
	GError* _error_;
	GError* _tmp12_;
	const gchar* _tmp13_;
	BoxesVMCreator* _tmp14_;
	BoxesInstallerMedia* _tmp15_;
	BoxesInstallerMedia* _tmp16_;
	BoxesWizardSource* _tmp17_;
	BoxesWizardSource* _tmp18_;
	BoxesCollectionSource* _tmp19_;
	BoxesCollectionSource* _tmp20_;
	BoxesApp* _tmp21_;
	BoxesCollectionSource* _tmp22_;
	BoxesWizardSource* _tmp23_;
	gboolean _tmp24_;
	BoxesWizardSource* _tmp25_;
	BoxesLibvirtSystemImporter* _tmp26_;
	BoxesLibvirtSystemImporter* _tmp27_;
	GError * _inner_error_;
};

struct _Block86Data {
	int _ref_count_;
	BoxesWizard* self;
	BoxesActivityProgress* progress;
};

struct _BoxesAppWindow {
	GtkApplicationWindow parent_instance;
	BoxesAppWindowPrivate * priv;
	BoxesCollectionItem* current_item;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesSelectionbar* selectionbar;
	BoxesSidebar* sidebar;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	GtkStack* below_bin;
	BoxesCollectionView* view;
	GSettings* settings;
};

struct _BoxesAppWindowClass {
	GtkApplicationWindowClass parent_class;
};

struct _BoxesInstallerMedia {
	GObject parent_instance;
	BoxesInstallerMediaPrivate * priv;
	OsinfoOs* os;
	OsinfoResources* resources;
	OsinfoMedia* os_media;
	gchar* label;
	gchar* device_file;
	gchar* mount_point;
	gboolean from_image;
};

struct _BoxesInstallerMediaClass {
	GObjectClass parent_class;
	void (*set_direct_boot_params) (BoxesInstallerMedia* self, GVirConfigDomainOs* os);
	void (*prepare) (BoxesInstallerMedia* self, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_);
	void (*prepare_for_installation) (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_for_installation_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_, GError** error);
	void (*prepare_to_continue_installation) (BoxesInstallerMedia* self, const gchar* vm_name);
	void (*clean_up) (BoxesInstallerMedia* self);
	void (*clean_up_preparation_cache) (BoxesInstallerMedia* self);
	void (*setup_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*setup_post_install_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*populate_setup_box) (BoxesInstallerMedia* self, GtkBox* setup_box);
	GList* (*get_vm_properties) (BoxesInstallerMedia* self);
	BoxesVMCreator* (*get_vm_creator) (BoxesInstallerMedia* self);
	OsinfoDeviceList* (*get_supported_devices) (BoxesInstallerMedia* self);
	guint64 (*get_installed_size) (BoxesInstallerMedia* self);
	gboolean (*get_need_user_input_for_vm_creation) (BoxesInstallerMedia* self);
	gboolean (*get_ready_to_create) (BoxesInstallerMedia* self);
	gboolean (*get_live) (BoxesInstallerMedia* self);
	gchar* (*get_architecture) (BoxesInstallerMedia* self);
};

struct _BoxesWizardPrepareMediaData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesWizard* self;
	BoxesInstallerMedia* install_media;
	BoxesActivityProgress* progress;
	BoxesInstallerMedia* _tmp0_;
	OsinfoOs* _tmp1_;
	GtkLabel* _tmp2_;
	BoxesInstallerMedia* _tmp3_;
	OsinfoOs* _tmp4_;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	GtkImage* _tmp7_;
	BoxesInstallerMedia* _tmp8_;
	OsinfoOs* _tmp9_;
	BoxesActivityProgress* prepare_media_progress;
	BoxesWizardSource* _tmp10_;
	gboolean _tmp11_;
	gboolean _tmp12_;
	BoxesActivityProgress* _tmp13_;
	BoxesActivityProgress* _tmp14_;
	BoxesActivityProgress* _tmp15_;
	BoxesActivityProgress* _tmp16_;
	BoxesActivityProgress* _tmp17_;
	GtkLabel* _tmp18_;
	BoxesInstallerMedia* _tmp19_;
	BoxesActivityProgress* _tmp20_;
	GCancellable* _tmp21_;
	BoxesInstallerMedia* _tmp22_;
	BoxesVMCreator* _tmp23_;
	GtkProgressBar* _tmp24_;
};

struct _BoxesWizardReviewData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesWizard* self;
	gboolean result;
	GCancellable* _tmp0_;
	GCancellable* _tmp1_;
	gboolean _result_;
	gboolean _tmp2_;
};

struct _Block87Data {
	int _ref_count_;
	BoxesWizard* self;
	GVirConfigDomain* config;
};

typedef void (*BoxesWizardSummaryCustomizeFunc) (void* user_data);
struct _BoxesWizardDoReviewCancellableData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesWizard* self;
	gboolean result;
	GCancellable* _tmp0_;
	GtkInfoBar* _tmp1_;
	BoxesWizardSummary* _tmp2_;
	BoxesCollectionSource* _tmp3_;
	BoxesRemoteMachine* _tmp4_;
	BoxesCollectionSource* _tmp5_;
	BoxesRemoteMachine* _tmp6_;
	GError* _error_;
	GError* _tmp7_;
	const gchar* _tmp8_;
	gboolean _tmp9_;
	BoxesVMCreator* _tmp10_;
	BoxesLibvirtMachine* _tmp11_;
	BoxesLibvirtMachine* _tmp12_;
	BoxesLibvirtMachine* _tmp13_;
	BoxesVMCreator* _tmp14_;
	GCancellable* _tmp15_;
	BoxesLibvirtMachine* _tmp16_;
	GError* cancel_error;
	GError* _vala1__error_;
	BoxesAppWindow* _tmp17_;
	BoxesNotificationbar* _tmp18_;
	const gchar* _tmp19_;
	GdNotification* _tmp20_;
	GdNotification* _tmp21_;
	GError* _tmp22_;
	const gchar* _tmp23_;
	BoxesLibvirtMachine* _tmp24_;
	BoxesLibvirtMachine* _tmp25_;
	GCancellable* _tmp26_;
	gboolean _tmp27_;
	GtkLabel* _tmp28_;
	const gchar* _tmp29_;
	BoxesCollectionSource* _tmp30_;
	xmlURI* uri;
	BoxesCollectionSource* _tmp31_;
	gchar* _tmp32_;
	gchar* _tmp33_;
	gchar* _tmp34_;
	xmlURI* _tmp35_;
	xmlURI* _tmp36_;
	BoxesWizardSummary* _tmp37_;
	const gchar* _tmp38_;
	BoxesCollectionSource* _tmp39_;
	gchar* _tmp40_;
	gchar* _tmp41_;
	gchar* _tmp42_;
	gboolean _tmp43_;
	xmlURI* _tmp44_;
	xmlURI* _tmp45_;
	const gchar* _tmp46_;
	BoxesWizardSummary* _tmp47_;
	const gchar* _tmp48_;
	xmlURI* _tmp49_;
	const gchar* _tmp50_;
	gchar* _tmp51_;
	gchar* _tmp52_;
	BoxesWizardSummary* _tmp53_;
	const gchar* _tmp54_;
	BoxesCollectionSource* _tmp55_;
	gchar* _tmp56_;
	gchar* _tmp57_;
	gchar* _tmp58_;
	gchar* _tmp59_;
	gchar* _tmp60_;
	xmlURI* _tmp61_;
	const gchar* _tmp62_;
	const gchar* _tmp63_;
	GQuark _tmp65_;
	gint port;
	gint tls_port;
	BoxesCollectionSource* _tmp66_;
	gchar* _tmp67_;
	gchar* _tmp68_;
	gchar* _tmp69_;
	gint* _tmp70_;
	gint* _tmp71_;
	gint* _tmp72_;
	gint* _tmp73_;
	gint _tmp74_;
	BoxesWizardSummary* _tmp75_;
	const gchar* _tmp76_;
	gint _tmp77_;
	gchar* _tmp78_;
	gchar* _tmp79_;
	gint _tmp80_;
	BoxesWizardSummary* _tmp81_;
	const gchar* _tmp82_;
	gint _tmp83_;
	gchar* _tmp84_;
	gchar* _tmp85_;
	GError* _vala2__error_;
	GError* _tmp86_;
	const gchar* _tmp87_;
	xmlURI* _tmp88_;
	gint _tmp89_;
	BoxesWizardSummary* _tmp90_;
	const gchar* _tmp91_;
	xmlURI* _tmp92_;
	gint _tmp93_;
	gchar* _tmp94_;
	gchar* _tmp95_;
	BoxesApp* _tmp96_;
	BoxesCollectionSource* _tmp97_;
	gchar* _tmp98_;
	gchar* _tmp99_;
	gchar* _tmp100_;
	gboolean _tmp101_;
	gboolean _tmp102_;
	GtkLabel* _tmp103_;
	const gchar* _tmp104_;
	BoxesLibvirtMachine* _tmp105_;
	BoxesLibvirtMachine* _tmp106_;
	BoxesVMCreator* _tmp107_;
	BoxesInstallerMedia* _tmp108_;
	BoxesInstallerMedia* _tmp109_;
	GList* _tmp110_;
	GList* property_collection;
	GList* property_it;
	BoxesPair* _tmp111_;
	BoxesPair* property;
	BoxesWizardSummary* _tmp112_;
	BoxesPair* _tmp113_;
	gconstpointer _tmp114_;
	BoxesPair* _tmp115_;
	gconstpointer _tmp116_;
	Block87Data* _data87_;
	gpointer _tmp117_;
	GVirConfigDomain* _tmp118_;
	gchar* memory;
	GVirConfigDomain* _tmp119_;
	guint64 _tmp120_;
	guint64 _tmp121_;
	gchar* _tmp122_;
	BoxesWizardSummary* _tmp123_;
	const gchar* _tmp124_;
	const gchar* _tmp125_;
	GError* _vala3__error_;
	BoxesLibvirtMachine* _tmp126_;
	BoxesLibvirtMachine* _tmp127_;
	const gchar* _tmp128_;
	const gchar* _tmp129_;
	GError* _tmp130_;
	const gchar* _tmp131_;
	gboolean _tmp132_;
	BoxesLibvirtMachine* _tmp133_;
	BoxesLibvirtMachine* _tmp134_;
	gboolean _tmp135_;
	gboolean _tmp136_;
	BoxesLibvirtMachine* _tmp137_;
	BoxesLibvirtMachine* _tmp138_;
	GVirStorageVol* _tmp139_;
	GVirStorageVol* _tmp140_;
	GVirStorageVolInfo* volume_info;
	BoxesLibvirtMachine* _tmp141_;
	BoxesLibvirtMachine* _tmp142_;
	GVirStorageVol* _tmp143_;
	GVirStorageVol* _tmp144_;
	GVirStorageVolInfo* _tmp145_;
	gchar* capacity;
	GVirStorageVolInfo* _tmp146_;
	guint64 _tmp147_;
	gchar* _tmp148_;
	BoxesWizardSummary* _tmp149_;
	const gchar* _tmp150_;
	const gchar* _tmp151_;
	gchar* _tmp152_;
	gchar* _tmp153_;
	const gchar* _tmp154_;
	GError* _vala4__error_;
	BoxesLibvirtMachine* _tmp155_;
	BoxesLibvirtMachine* _tmp156_;
	GVirStorageVol* _tmp157_;
	GVirStorageVol* _tmp158_;
	const gchar* _tmp159_;
	GError* _tmp160_;
	const gchar* _tmp161_;
	GtkInfoBar* _tmp162_;
	BoxesLibvirtMachine* _tmp163_;
	BoxesLibvirtMachine* _tmp164_;
	GVirConfigDomain* _tmp165_;
	GVirConfigDomain* _tmp166_;
	GVirConfigDomainVirtType _tmp167_;
	BoxesWizardSource* _tmp168_;
	gboolean _tmp169_;
	GtkLabel* _tmp170_;
	BoxesWizardSource* _tmp171_;
	BoxesLibvirtSystemImporter* _tmp172_;
	BoxesLibvirtSystemImporter* _tmp173_;
	gchar* _tmp174_;
	gchar* _tmp175_;
	gchar* _tmp176_;
	BoxesMachine* _tmp177_;
	BoxesWizardSummary* _tmp178_;
	GError * _inner_error_;
};

struct _BoxesWizardDownloadMediaData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesWizard* self;
	gchar* uri;
	BoxesActivityProgress* progress;
	BoxesActivityProgress* download_progress;
	BoxesActivityProgress* _tmp0_;
	BoxesActivityProgress* _tmp1_;
	GtkLabel* _tmp2_;
	const gchar* _tmp3_;
	gchar* cache_path;
	const gchar* _tmp4_;
	BoxesActivityProgress* _tmp5_;
	GCancellable* _tmp6_;
	gchar* _tmp7_;
	const gchar* _tmp8_;
	BoxesActivityProgress* _tmp9_;
	GError* e;
	const gchar* _tmp10_;
	GError* _vala1_e;
	const gchar* _tmp11_;
	GError* _tmp12_;
	const gchar* _tmp13_;
	BoxesAppWindow* _tmp14_;
	BoxesNotificationbar* _tmp15_;
	const gchar* _tmp16_;
	GdNotification* _tmp17_;
	GdNotification* _tmp18_;
	GError * _inner_error_;
};

struct _Block88Data {
	int _ref_count_;
	BoxesWizard* self;
	BoxesAppWindow* window;
};

struct _BoxesTopbar {
	GtkStack parent_instance;
	BoxesTopbarPrivate * priv;
	BoxesPropertiesToolbar* props_toolbar;
	BoxesWizardToolbar* wizard_toolbar;
	gchar* _status;
};

struct _BoxesTopbarClass {
	GtkStackClass parent_class;
};

struct _BoxesWizardToolbar {
	GtkHeaderBar parent_instance;
	BoxesWizardToolbarPrivate * priv;
	GtkButton* cancel_btn;
	GtkButton* back_btn;
	GtkButton* continue_btn;
	GtkButton* create_btn;
};

struct _BoxesWizardToolbarClass {
	GtkHeaderBarClass parent_class;
};

struct _BoxesSidebar {
	GtkRevealer parent_instance;
	BoxesSidebarPrivate * priv;
	BoxesWizardSidebar* wizard_sidebar;
	BoxesPropertiesSidebar* props_sidebar;
};

struct _BoxesSidebarClass {
	GtkRevealerClass parent_class;
};

struct _BoxesWizardSummary {
	GtkGrid parent_instance;
	BoxesWizardSummaryPrivate * priv;
};

struct _BoxesWizardSummaryClass {
	GtkGridClass parent_class;
};

struct _BoxesWizardSummaryPrivate {
	gint current_row;
};

struct _Block89Data {
	int _ref_count_;
	BoxesWizardSummary* self;
	BoxesWizardSummaryCustomizeFunc customize_func;
	gpointer customize_func_target;
};


static gpointer boxes_wizard_parent_class = NULL;
extern BoxesApp* boxes_app_app;
static BoxesUIIface* boxes_wizard_boxes_ui_parent_iface = NULL;
static gpointer boxes_wizard_summary_parent_class = NULL;

GType boxes_wizard_page_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_wizard_source_get_type (void) G_GNUC_CONST;
GType boxes_wizard_summary_get_type (void) G_GNUC_CONST;
GType boxes_app_window_get_type (void) G_GNUC_CONST;
GType boxes_media_manager_get_type (void) G_GNUC_CONST;
gpointer boxes_vm_creator_ref (gpointer instance);
void boxes_vm_creator_unref (gpointer instance);
GParamSpec* boxes_param_spec_vm_creator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_vm_creator (GValue* value, gpointer v_object);
void boxes_value_take_vm_creator (GValue* value, gpointer v_object);
gpointer boxes_value_get_vm_creator (const GValue* value);
GType boxes_vm_creator_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
#define BOXES_WIZARD_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_WIZARD, BoxesWizardPrivate))
enum  {
	BOXES_WIZARD_DUMMY_PROPERTY,
	BOXES_WIZARD_PREVIOUS_UI_STATE,
	BOXES_WIZARD_UI_STATE,
	BOXES_WIZARD_MACHINE,
	BOXES_WIZARD_PAGE
};
#define BOXES_WIZARD_DOWNLOAD_PROGRESS_SCALE 0.95
#define BOXES_WIZARD_PREPARE_PROGRESS_SCALE 0.05
static BoxesActivityProgress* boxes_wizard_create_preparation_progress (BoxesWizard* self);
static Block84Data* block84_data_ref (Block84Data* _data84_);
static void block84_data_unref (void * _userdata_);
static void __lambda168_ (Block84Data* _data84_);
static void ___lambda168__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_wizard_wizard_source_update_next (BoxesWizard* self);
BoxesWizardPage boxes_wizard_get_page (BoxesWizard* self);
GType boxes_source_page_get_type (void) G_GNUC_CONST;
BoxesSourcePage boxes_wizard_source_get_page (BoxesWizardSource* self);
GtkWidget* boxes_wizard_source_get_selected (BoxesWizardSource* self);
const gchar* boxes_wizard_source_get_uri (BoxesWizardSource* self);
static void boxes_wizard_prepare_for_location (BoxesWizard* self, const gchar* location, gboolean probing, BoxesActivityProgress* progress, GError** error);
GType boxes_app_get_type (void) G_GNUC_CONST;
gboolean boxes_app_has_broker_for_source_type (BoxesApp* self, const gchar* type);
void boxes_wizard_source_update_url_page (BoxesWizardSource* self, const gchar* title, const gchar* text, const gchar* icon_name);
void boxes_wizard_cleanup (BoxesWizard* self);
static void boxes_wizard_destroy_machine (BoxesWizard* self);
void boxes_wizard_source_cleanup (BoxesWizardSource* self);
static void boxes_wizard_create_data_free (gpointer _data);
static void boxes_wizard_create (BoxesWizard* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_wizard_create_finish (BoxesWizard* self, GAsyncResult* _res_);
static gboolean boxes_wizard_create_co (BoxesWizardCreateData* _data_);
static Block85Data* block85_data_ref (Block85Data* _data85_);
static void block85_data_unref (void * _userdata_);
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
static BoxesLibvirtMachine* boxes_wizard_get_libvirt_machine (BoxesWizard* self);
static void ____lambda177_ (Block85Data* _data85_);
static void _____lambda177__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
void boxes_vm_creator_launch_vm (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GError** error);
GType boxes_installer_media_get_type (void) G_GNUC_CONST;
BoxesInstallerMedia* boxes_vm_creator_get_install_media (BoxesVMCreator* self);
void boxes_installer_media_clean_up_preparation_cache (BoxesInstallerMedia* self);
void boxes_wizard_source_set_uri (BoxesWizardSource* self, const gchar* value);
void boxes_app_add_collection_source (BoxesApp* self, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_app_add_collection_source_finish (BoxesApp* self, GAsyncResult* _res_);
GType boxes_libvirt_system_importer_get_type (void) G_GNUC_CONST;
BoxesLibvirtSystemImporter* boxes_wizard_source_get_libvirt_sys_importer (BoxesWizardSource* self);
void boxes_libvirt_system_importer_import (BoxesLibvirtSystemImporter* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_libvirt_system_importer_import_finish (BoxesLibvirtSystemImporter* self, GAsyncResult* _res_);
void boxes_wizard_set_machine (BoxesWizard* self, BoxesMachine* value);
static void boxes_wizard_prepare_for_installer (BoxesWizard* self, const gchar* path, BoxesActivityProgress* progress, GError** error);
static void boxes_wizard_prepare_for_uri (BoxesWizard* self, const gchar* uri_as_text, GError** error);
gboolean boxes_wizard_source_get_download_required (BoxesWizardSource* self);
void spice_validate_uri (const gchar* uri_as_text, gint** port, gint** tls_port, GError** error);
static Block86Data* block86_data_ref (Block86Data* _data86_);
static void block86_data_unref (void * _userdata_);
void boxes_media_manager_create_installer_media_for_path (BoxesMediaManager* self, const gchar* path, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesInstallerMedia* boxes_media_manager_create_installer_media_for_path_finish (BoxesMediaManager* self, GAsyncResult* _res_, GError** error);
static void __lambda169_ (Block86Data* _data86_, GObject* obj, GAsyncResult* res);
static void boxes_wizard_on_installer_media_instantiated (BoxesWizard* self, GAsyncResult* _result_, BoxesActivityProgress* progress);
static void ___lambda169__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void boxes_wizard_prepare_media (BoxesWizard* self, BoxesInstallerMedia* install_media, BoxesActivityProgress* progress, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_wizard_prepare_media_finish (BoxesWizard* self, GAsyncResult* _res_);
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
GdNotification* boxes_notificationbar_display_error (BoxesNotificationbar* self, const gchar* message, gint timeout);
#define BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT 6
static void boxes_wizard_set_page (BoxesWizard* self, BoxesWizardPage value);
static void boxes_wizard_prepare_media_data_free (gpointer _data);
static gboolean boxes_wizard_prepare_media_co (BoxesWizardPrepareMediaData* _data_);
void boxes_downloader_fetch_os_logo (GtkImage* image, OsinfoOs* os, gint size, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_downloader_fetch_os_logo_finish (GAsyncResult* _res_);
void boxes_installer_media_prepare (BoxesInstallerMedia* self, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_installer_media_prepare_finish (BoxesInstallerMedia* self, GAsyncResult* _res_);
static void boxes_wizard_prepare_media_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
BoxesVMCreator* boxes_installer_media_get_vm_creator (BoxesInstallerMedia* self);
static gboolean boxes_wizard_prepare (BoxesWizard* self, BoxesActivityProgress* progress);
static void boxes_wizard_download_media (BoxesWizard* self, const gchar* uri, BoxesActivityProgress* progress, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_wizard_download_media_finish (BoxesWizard* self, GAsyncResult* _res_);
BoxesInstallerMedia* boxes_wizard_source_get_install_media (BoxesWizardSource* self);
static gboolean boxes_wizard_setup (BoxesWizard* self);
void boxes_installer_media_populate_setup_box (BoxesInstallerMedia* self, GtkBox* setup_box);
static void __lambda170_ (BoxesWizard* self);
gboolean boxes_installer_media_get_ready_to_create (BoxesInstallerMedia* self);
static void ___lambda170__boxes_installer_media_user_wants_to_create (BoxesInstallerMedia* _sender, gpointer self);
static void boxes_wizard_review_data_free (gpointer _data);
static void boxes_wizard_review (BoxesWizard* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_wizard_review_finish (BoxesWizard* self, GAsyncResult* _res_);
static gboolean boxes_wizard_review_co (BoxesWizardReviewData* _data_);
static void boxes_wizard_do_review_cancellable (BoxesWizard* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_wizard_do_review_cancellable_finish (BoxesWizard* self, GAsyncResult* _res_);
static void boxes_wizard_review_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_wizard_do_review_cancellable_data_free (gpointer _data);
static gboolean boxes_wizard_do_review_cancellable_co (BoxesWizardDoReviewCancellableData* _data_);
void boxes_wizard_summary_clear (BoxesWizardSummary* self);
GType boxes_remote_machine_get_type (void) G_GNUC_CONST;
BoxesRemoteMachine* boxes_remote_machine_new (BoxesCollectionSource* source, GError** error);
BoxesRemoteMachine* boxes_remote_machine_construct (GType object_type, BoxesCollectionSource* source, GError** error);
void boxes_vm_creator_create_vm (BoxesVMCreator* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesLibvirtMachine* boxes_vm_creator_create_vm_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error);
static void boxes_wizard_do_review_cancellable_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
void boxes_wizard_summary_add_property (BoxesWizardSummary* self, const gchar* name, const gchar* value);
GList* boxes_installer_media_get_vm_properties (BoxesInstallerMedia* self);
static void _boxes_pair_unref0_ (gpointer var);
static void _g_list_free__boxes_pair_unref0_ (GList* self);
static Block87Data* block87_data_ref (Block87Data* _data87_);
static void block87_data_unref (void * _userdata_);
static void _____lambda174_ (Block87Data* _data87_, GError** error);
GVirDomain* boxes_libvirt_machine_get_domain (BoxesLibvirtMachine* self);
static void ______lambda174__boxes_run_in_thread_func (gpointer self, GError** error);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
gboolean boxes_libvirt_machine_get_importing (BoxesLibvirtMachine* self);
GVirStorageVol* boxes_libvirt_machine_get_storage_volume (BoxesLibvirtMachine* self);
static void _vala_GVirStorageVolInfo_free (GVirStorageVolInfo* self);
GVirConfigDomain* boxes_libvirt_machine_get_domain_config (BoxesLibvirtMachine* self);
gchar* boxes_libvirt_system_importer_get_wizard_review_label (BoxesLibvirtSystemImporter* self);
BoxesMachine* boxes_wizard_get_machine (BoxesWizard* self);
void boxes_wizard_summary_append_customize_button (BoxesWizardSummary* self, BoxesWizardSummaryCustomizeFunc customize_func, void* customize_func_target);
static void ___lambda175_ (BoxesWizard* self);
void boxes_app_window_select_item (BoxesAppWindow* self, BoxesCollectionItem* item);
static void ____lambda175__boxes_wizard_summary_customize_func (gpointer self);
static gboolean boxes_wizard_skip_page (BoxesWizard* self, BoxesWizardPage page);
gboolean boxes_installer_media_get_need_user_input_for_vm_creation (BoxesInstallerMedia* self);
gboolean boxes_installer_media_get_live (BoxesInstallerMedia* self);
static void boxes_wizard_download_media_data_free (gpointer _data);
static gboolean boxes_wizard_download_media_co (BoxesWizardDownloadMediaData* _data_);
void boxes_downloader_fetch_media (const gchar* uri, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
gchar* boxes_downloader_fetch_media_finish (GAsyncResult* _res_, GError** error);
static void boxes_wizard_download_media_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_wizard_prepare_downloaded_media (BoxesWizard* self, const gchar* cache_path, BoxesActivityProgress* progress);
void boxes_wizard_setup_ui (BoxesWizard* self, BoxesAppWindow* window);
static Block88Data* block88_data_ref (Block88Data* _data88_);
static void block88_data_unref (void * _userdata_);
GType boxes_properties_toolbar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_toolbar_get_type (void) G_GNUC_CONST;
static void __lambda179_ (Block88Data* _data88_);
void boxes_wizard_source_set_page (BoxesWizardSource* self, BoxesSourcePage value);
void boxes_ui_set_state (BoxesUI* self, BoxesUIState new_state);
static void ___lambda179__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda180_ (BoxesWizard* self);
static void ___lambda180__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda181_ (BoxesWizard* self);
static void ___lambda181__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda182_ (BoxesWizard* self);
static void ___lambda182__gtk_button_clicked (GtkButton* _sender, gpointer self);
void boxes_wizard_source_setup_ui (BoxesWizardSource* self, BoxesAppWindow* window);
void boxes_wizard_open_with_uri (BoxesWizard* self, const gchar* uri, gboolean skip_review_for_live);
static void boxes_wizard_ui_state_changed (BoxesWizard* self);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
BoxesUIState boxes_ui_get_previous_ui_state (BoxesUI* self);
void boxes_app_delete_machine (BoxesApp* self, BoxesMachine* machine, gboolean by_user);
BoxesWizard* boxes_wizard_new (void);
BoxesWizard* boxes_wizard_construct (GType object_type);
static void _boxes_wizard_page_____lambda176_ (BoxesWizard* self, GObject* obj, GAsyncResult* _result_);
static void __boxes_wizard_page_____lambda176__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void _boxes_wizard_page_____lambda178_ (BoxesWizard* self, GObject* obj, GAsyncResult* _result_);
static void __boxes_wizard_page_____lambda178__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
GType boxes_wizard_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_properties_sidebar_get_type (void) G_GNUC_CONST;
void boxes_wizard_sidebar_set_page (BoxesWizardSidebar* self, BoxesWizardPage wizard_page);
static GObject * boxes_wizard_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
BoxesMediaManager* boxes_media_manager_get_instance (void);
static void _boxes_wizard_wizard_source_update_next_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _boxes_wizard_wizard_source_update_next_gtk_editable_changed (GtkEditable* _sender, gpointer self);
static void _boxes_wizard_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _boxes_wizard___lambda183_ (BoxesWizard* self);
static void __boxes_wizard___lambda183__boxes_wizard_source_activated (BoxesWizardSource* _sender, gpointer self);
static void boxes_wizard_finalize (GObject* obj);
static void _vala_boxes_wizard_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
void boxes_ui_set_previous_ui_state (BoxesUI* self, BoxesUIState value);
void boxes_ui_set_ui_state (BoxesUI* self, BoxesUIState value);
static void _vala_boxes_wizard_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
#define BOXES_WIZARD_SUMMARY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_WIZARD_SUMMARY, BoxesWizardSummaryPrivate))
enum  {
	BOXES_WIZARD_SUMMARY_DUMMY_PROPERTY
};
static Block89Data* block89_data_ref (Block89Data* _data89_);
static void block89_data_unref (void * _userdata_);
static void __lambda167_ (Block89Data* _data89_);
static void ___lambda167__gtk_button_clicked (GtkButton* _sender, gpointer self);
BoxesWizardSummary* boxes_wizard_summary_new (void);
BoxesWizardSummary* boxes_wizard_summary_construct (GType object_type);
static GObject * boxes_wizard_summary_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void boxes_wizard_summary_finalize (GObject* obj);

static const gchar* BOXES_WIZARD_page_names[5] = {"introduction", "source", "preparation", "setup", "review"};

GType boxes_wizard_page_get_type (void) {
	static volatile gsize boxes_wizard_page_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_wizard_page_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_WIZARD_PAGE_INTRODUCTION, "BOXES_WIZARD_PAGE_INTRODUCTION", "introduction"}, {BOXES_WIZARD_PAGE_SOURCE, "BOXES_WIZARD_PAGE_SOURCE", "source"}, {BOXES_WIZARD_PAGE_PREPARATION, "BOXES_WIZARD_PAGE_PREPARATION", "preparation"}, {BOXES_WIZARD_PAGE_SETUP, "BOXES_WIZARD_PAGE_SETUP", "setup"}, {BOXES_WIZARD_PAGE_REVIEW, "BOXES_WIZARD_PAGE_REVIEW", "review"}, {BOXES_WIZARD_PAGE_LAST, "BOXES_WIZARD_PAGE_LAST", "last"}, {0, NULL, NULL}};
		GType boxes_wizard_page_type_id;
		boxes_wizard_page_type_id = g_enum_register_static ("BoxesWizardPage", values);
		g_once_init_leave (&boxes_wizard_page_type_id__volatile, boxes_wizard_page_type_id);
	}
	return boxes_wizard_page_type_id__volatile;
}


static Block84Data* block84_data_ref (Block84Data* _data84_) {
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_atomic_int_inc (&_data84_->_ref_count_);
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return _data84_;
#line 1114 "wizard.c"
}


static void block84_data_unref (void * _userdata_) {
	Block84Data* _data84_;
	_data84_ = (Block84Data*) _userdata_;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (g_atomic_int_dec_and_test (&_data84_->_ref_count_)) {
#line 1123 "wizard.c"
		BoxesWizard* self;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		self = _data84_->self;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_data84_->progress);
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (self);
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_slice_free (Block84Data, _data84_);
#line 1133 "wizard.c"
	}
}


static void __lambda168_ (Block84Data* _data84_) {
	BoxesWizard* self;
	gdouble _tmp0_ = 0.0;
	gdouble _tmp1_ = 0.0;
	GtkProgressBar* _tmp2_ = NULL;
	gdouble _tmp3_ = 0.0;
	gdouble _tmp4_ = 0.0;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = _data84_->self;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = boxes_activity_progress_get_progress (_data84_->progress);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = _tmp0_;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = self->priv->prep_progress;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = gtk_progress_bar_get_fraction (_tmp2_);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = _tmp3_;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if ((_tmp1_ - _tmp4_) >= 0.01) {
#line 1159 "wizard.c"
		GtkProgressBar* _tmp5_ = NULL;
		gdouble _tmp6_ = 0.0;
		gdouble _tmp7_ = 0.0;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp5_ = self->priv->prep_progress;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp6_ = boxes_activity_progress_get_progress (_data84_->progress);
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp7_ = _tmp6_;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		gtk_progress_bar_set_fraction (_tmp5_, _tmp7_);
#line 1171 "wizard.c"
	}
}


static void ___lambda168__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	__lambda168_ (self);
#line 1179 "wizard.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return self ? g_object_ref (self) : NULL;
#line 1186 "wizard.c"
}


static BoxesActivityProgress* boxes_wizard_create_preparation_progress (BoxesWizard* self) {
	BoxesActivityProgress* result = NULL;
	Block84Data* _data84_;
	BoxesActivityProgress* _tmp0_ = NULL;
	GtkProgressBar* _tmp1_ = NULL;
	BoxesActivityProgress* _tmp2_ = NULL;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data84_ = g_slice_new0 (Block84Data);
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data84_->_ref_count_ = 1;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data84_->self = g_object_ref (self);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = boxes_activity_progress_new ();
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data84_->progress = _tmp0_;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_signal_connect_data ((GObject*) _data84_->progress, "notify::progress", (GCallback) ___lambda168__g_object_notify, block84_data_ref (_data84_), (GClosureNotify) block84_data_unref, 0);
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->prep_progress;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_activity_progress_set_progress (_data84_->progress, (gdouble) 0);
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_progress_bar_set_fraction (_tmp1_, (gdouble) 0);
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = _g_object_ref0 (_data84_->progress);
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	result = _tmp2_;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	block84_data_unref (_data84_);
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data84_ = NULL;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return result;
#line 1226 "wizard.c"
}


static void boxes_wizard_wizard_source_update_next (BoxesWizard* self) {
	BoxesWizardPage _tmp0_ = 0;
	BoxesWizardPage _tmp1_ = 0;
	GtkButton* _tmp2_ = NULL;
	BoxesWizardSource* _tmp3_ = NULL;
	BoxesSourcePage _tmp4_ = 0;
	BoxesSourcePage _tmp5_ = 0;
	GError * _inner_error_ = NULL;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = boxes_wizard_get_page (self);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = _tmp0_;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp1_ != BOXES_WIZARD_PAGE_SOURCE) {
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		return;
#line 1248 "wizard.c"
	}
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = self->priv->next_button;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp2_, FALSE);
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = self->priv->wizard_source;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = boxes_wizard_source_get_page (_tmp3_);
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp5_ = _tmp4_;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	switch (_tmp5_) {
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case BOXES_SOURCE_PAGE_MAIN:
#line 1264 "wizard.c"
		{
			GtkButton* _tmp6_ = NULL;
			BoxesWizardSource* _tmp7_ = NULL;
			GtkWidget* _tmp8_ = NULL;
			GtkWidget* _tmp9_ = NULL;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp6_ = self->priv->next_button;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp7_ = self->priv->wizard_source;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp8_ = boxes_wizard_source_get_selected (_tmp7_);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp9_ = _tmp8_;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			gtk_widget_set_sensitive ((GtkWidget*) _tmp6_, _tmp9_ != NULL);
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_object_unref0 (self->priv->source);
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			self->priv->source = NULL;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			break;
#line 1286 "wizard.c"
		}
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case BOXES_SOURCE_PAGE_URL:
#line 1290 "wizard.c"
		{
			GtkButton* _tmp10_ = NULL;
			BoxesWizardSource* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			gint _tmp14_ = 0;
			gint _tmp15_ = 0;
			gchar* text = NULL;
			const gchar* _tmp16_ = NULL;
			gchar* _tmp17_ = NULL;
			gchar* icon = NULL;
			gchar* _tmp18_ = NULL;
			BoxesWizardSource* _tmp35_ = NULL;
			const gchar* _tmp36_ = NULL;
			const gchar* _tmp37_ = NULL;
			const gchar* _tmp38_ = NULL;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp10_ = self->priv->next_button;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp11_ = self->priv->wizard_source;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp12_ = boxes_wizard_source_get_uri (_tmp11_);
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp13_ = _tmp12_;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp14_ = strlen (_tmp13_);
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp15_ = _tmp14_;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			gtk_widget_set_sensitive ((GtkWidget*) _tmp10_, _tmp15_ != 0);
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp16_ = _ ("Please enter desktop or collection URI");
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp17_ = g_strdup (_tmp16_);
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			text = _tmp17_;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp18_ = g_strdup ("preferences-desktop-remote-desktop");
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			icon = _tmp18_;
#line 1331 "wizard.c"
			{
				BoxesWizardSource* _tmp19_ = NULL;
				const gchar* _tmp20_ = NULL;
				const gchar* _tmp21_ = NULL;
				gboolean _tmp22_ = FALSE;
				BoxesCollectionSource* _tmp23_ = NULL;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp19_ = self->priv->wizard_source;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp20_ = boxes_wizard_source_get_uri (_tmp19_);
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp21_ = _tmp20_;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_wizard_prepare_for_location (self, _tmp21_, TRUE, NULL, &_inner_error_);
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1348 "wizard.c"
					goto __catch112_g_error;
				}
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp23_ = self->priv->source;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (_tmp23_ != NULL) {
#line 1355 "wizard.c"
					BoxesApp* _tmp24_ = NULL;
					BoxesCollectionSource* _tmp25_ = NULL;
					gchar* _tmp26_ = NULL;
					gchar* _tmp27_ = NULL;
					gchar* _tmp28_ = NULL;
					gboolean _tmp29_ = FALSE;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp24_ = boxes_app_app;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp25_ = self->priv->source;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp26_ = boxes_collection_source_get_source_type (_tmp25_);
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp27_ = _tmp26_;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp28_ = _tmp27_;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp29_ = boxes_app_has_broker_for_source_type (_tmp24_, _tmp28_);
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp22_ = _tmp29_;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_g_free0 (_tmp28_);
#line 1378 "wizard.c"
				} else {
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp22_ = FALSE;
#line 1382 "wizard.c"
				}
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (_tmp22_) {
#line 1386 "wizard.c"
					const gchar* _tmp30_ = NULL;
					gchar* _tmp31_ = NULL;
					gchar* _tmp32_ = NULL;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp30_ = _ ("Will add boxes for all systems available from this account.");
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp31_ = g_strdup (_tmp30_);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_g_free0 (text);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					text = _tmp31_;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp32_ = g_strdup ("network-workgroup");
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_g_free0 (icon);
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					icon = _tmp32_;
#line 1404 "wizard.c"
				} else {
					const gchar* _tmp33_ = NULL;
					gchar* _tmp34_ = NULL;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp33_ = _ ("Will add a single box.");
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp34_ = g_strdup (_tmp33_);
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_g_free0 (text);
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					text = _tmp34_;
#line 1416 "wizard.c"
				}
			}
			goto __finally112;
			__catch112_g_error:
			{
				GError* _error_ = NULL;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_error_ = _inner_error_;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_inner_error_ = NULL;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_error_free0 (_error_);
#line 1429 "wizard.c"
			}
			__finally112:
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_free0 (icon);
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_free0 (text);
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_clear_error (&_inner_error_);
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				return;
#line 1444 "wizard.c"
			}
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp35_ = self->priv->wizard_source;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp36_ = _ ("Desktop Access");
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp37_ = text;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp38_ = icon;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			boxes_wizard_source_update_url_page (_tmp35_, _tmp36_, _tmp37_, _tmp38_);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_free0 (icon);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_free0 (text);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			break;
#line 1462 "wizard.c"
		}
		default:
		{
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_warn_if_reached ();
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			break;
#line 1470 "wizard.c"
		}
	}
}


void boxes_wizard_cleanup (BoxesWizard* self) {
	GCancellable* _tmp0_ = NULL;
	BoxesWizardSource* _tmp2_ = NULL;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->prepare_cancellable;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp0_ != NULL) {
#line 1485 "wizard.c"
		GCancellable* _tmp1_ = NULL;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp1_ = self->priv->prepare_cancellable;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_cancellable_cancel (_tmp1_);
#line 1491 "wizard.c"
	}
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_destroy_machine (self);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_boxes_vm_creator_unref0 (self->priv->vm_creator);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->vm_creator = NULL;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->source);
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->source = NULL;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = self->priv->wizard_source;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_source_cleanup (_tmp2_);
#line 1507 "wizard.c"
}


static void boxes_wizard_create_data_free (gpointer _data) {
	BoxesWizardCreateData* _data_;
	_data_ = _data;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->self);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_slice_free (BoxesWizardCreateData, _data_);
#line 1518 "wizard.c"
}


static void boxes_wizard_create (BoxesWizard* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesWizardCreateData* _data_;
	BoxesWizard* _tmp0_ = NULL;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_ = g_slice_new0 (BoxesWizardCreateData);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_wizard_create);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_wizard_create_data_free);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->self = _tmp0_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_create_co (_data_);
#line 1537 "wizard.c"
}


static gboolean boxes_wizard_create_finish (BoxesWizard* self, GAsyncResult* _res_) {
	gboolean result;
	BoxesWizardCreateData* _data_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	result = _data_->result;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return result;
#line 1550 "wizard.c"
}


static Block85Data* block85_data_ref (Block85Data* _data85_) {
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_atomic_int_inc (&_data85_->_ref_count_);
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return _data85_;
#line 1559 "wizard.c"
}


static void block85_data_unref (void * _userdata_) {
	Block85Data* _data85_;
	_data85_ = (Block85Data*) _userdata_;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (g_atomic_int_dec_and_test (&_data85_->_ref_count_)) {
#line 1568 "wizard.c"
		BoxesWizard* self;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		self = _data85_->self;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (self);
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_slice_free (Block85Data, _data85_);
#line 1576 "wizard.c"
	}
}


static void ____lambda177_ (Block85Data* _data85_) {
	BoxesWizard* self;
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = _data85_->self;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_create_co (_data85_->_async_data_);
#line 1587 "wizard.c"
}


static void _____lambda177__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	____lambda177_ (self);
#line 1594 "wizard.c"
}


static gboolean boxes_wizard_create_co (BoxesWizardCreateData* _data_) {
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	switch (_data_->_state_) {
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case 0:
#line 1603 "wizard.c"
		goto _state_0;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case 1:
#line 1607 "wizard.c"
		goto _state_1;
		default:
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_assert_not_reached ();
#line 1612 "wizard.c"
	}
	_state_0:
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_data85_ = g_slice_new0 (Block85Data);
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_data85_->_ref_count_ = 1;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_data85_->self = g_object_ref (_data_->self);
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_data85_->_async_data_ = _data_;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp0_ = NULL;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp0_ = _data_->self->priv->vm_creator;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_tmp0_ != NULL) {
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp1_ = NULL;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp1_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp2_ = NULL;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp2_ = _data_->_tmp1_;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp2_ == NULL) {
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp3_ = NULL;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp3_ = _data_->self->priv->review_cancellable;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_return_val_if_fail (_data_->_tmp3_ != NULL, FALSE);
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp4_ = 0UL;
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp4_ = g_signal_connect_data ((GObject*) _data_->self, "notify::machine", (GCallback) _____lambda177__g_object_notify, block85_data_ref (_data_->_data85_), (GClosureNotify) block85_data_unref, 0);
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->wait = _data_->_tmp4_;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_state_ = 1;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			return FALSE;
#line 1655 "wizard.c"
			_state_1:
			;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp5_ = 0UL;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp5_ = _data_->wait;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_signal_handler_disconnect ((GObject*) _data_->self, _data_->_tmp5_);
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp6_ = NULL;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp6_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp7_ = NULL;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp7_ = _data_->_tmp6_;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (_data_->_tmp7_ == NULL) {
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->result = FALSE;
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				block85_data_unref (_data_->_data85_);
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_data85_ = NULL;
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (_data_->_state_ == 0) {
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1684 "wizard.c"
				} else {
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					g_simple_async_result_complete (_data_->_async_result);
#line 1688 "wizard.c"
				}
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_object_unref (_data_->_async_result);
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				return FALSE;
#line 1694 "wizard.c"
			}
		}
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp8_ = NULL;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp8_ = _data_->self->priv->next_button;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		gtk_widget_set_sensitive ((GtkWidget*) _data_->_tmp8_, FALSE);
#line 1703 "wizard.c"
		{
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp9_ = NULL;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp9_ = _data_->self->priv->vm_creator;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp10_ = NULL;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp10_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp11_ = NULL;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp11_ = _data_->_tmp10_;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			boxes_vm_creator_launch_vm (_data_->_tmp9_, _data_->_tmp11_, &_data_->_inner_error_);
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 1721 "wizard.c"
				goto __catch113_g_error;
			}
		}
		goto __finally113;
		__catch113_g_error:
		{
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_error_ = _data_->_inner_error_;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_inner_error_ = NULL;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp12_ = NULL;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp12_ = _data_->_error_;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp13_ = NULL;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp13_ = _data_->_tmp12_->message;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_warning ("wizard.vala:238: %s", _data_->_tmp13_);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->result = FALSE;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_error_free0 (_data_->_error_);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			block85_data_unref (_data_->_data85_);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_data85_ = NULL;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (_data_->_state_ == 0) {
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1754 "wizard.c"
			} else {
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 1758 "wizard.c"
			}
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_object_unref (_data_->_async_result);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			return FALSE;
#line 1764 "wizard.c"
		}
		__finally113:
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			block85_data_unref (_data_->_data85_);
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_data85_ = NULL;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_clear_error (&_data_->_inner_error_);
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			return FALSE;
#line 1779 "wizard.c"
		}
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp14_ = NULL;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp14_ = _data_->self->priv->vm_creator;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp15_ = NULL;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp15_ = boxes_vm_creator_get_install_media (_data_->_tmp14_);
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp16_ = NULL;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp16_ = _data_->_tmp15_;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_installer_media_clean_up_preparation_cache (_data_->_tmp16_);
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_boxes_vm_creator_unref0 (_data_->self->priv->vm_creator);
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->self->priv->vm_creator = NULL;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp17_ = NULL;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp17_ = _data_->self->priv->wizard_source;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_source_set_uri (_data_->_tmp17_, "");
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp18_ = NULL;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp18_ = _data_->self->priv->wizard_source;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp18_->libvirt_sys_import = FALSE;
#line 1811 "wizard.c"
	} else {
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp19_ = NULL;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp19_ = _data_->self->priv->source;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp19_ != NULL) {
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp20_ = NULL;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp20_ = _data_->self->priv->source;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			boxes_iconfig_save ((BoxesIConfig*) _data_->_tmp20_);
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp21_ = NULL;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp21_ = boxes_app_app;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp22_ = NULL;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp22_ = _data_->self->priv->source;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			boxes_app_add_collection_source (_data_->_tmp21_, _data_->_tmp22_, NULL, NULL);
#line 1835 "wizard.c"
		} else {
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp23_ = NULL;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp23_ = _data_->self->priv->wizard_source;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp24_ = FALSE;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp24_ = _data_->_tmp23_->libvirt_sys_import;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (_data_->_tmp24_) {
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp25_ = NULL;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp25_ = _data_->self->priv->wizard_source;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp26_ = NULL;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp26_ = boxes_wizard_source_get_libvirt_sys_importer (_data_->_tmp25_);
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp27_ = NULL;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp27_ = _data_->_tmp26_;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_libvirt_system_importer_import (_data_->_tmp27_, NULL, NULL);
#line 1861 "wizard.c"
			} else {
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_return_val_if_reached (FALSE);
#line 1865 "wizard.c"
			}
		}
	}
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_machine (_data_->self, NULL);
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->result = TRUE;
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	block85_data_unref (_data_->_data85_);
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_data85_ = NULL;
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_state_ == 0) {
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1881 "wizard.c"
	} else {
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1885 "wizard.c"
	}
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_unref (_data_->_async_result);
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	block85_data_unref (_data_->_data85_);
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_data85_ = NULL;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_state_ == 0) {
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1899 "wizard.c"
	} else {
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1903 "wizard.c"
	}
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_unref (_data_->_async_result);
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 1909 "wizard.c"
}


static gboolean string_contains (const gchar* self, const gchar* needle) {
	gboolean result = FALSE;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 1278 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1278 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, FALSE);
#line 1279 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp0_ = needle;
#line 1279 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp1_ = strstr ((gchar*) self, (gchar*) _tmp0_);
#line 1279 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	result = _tmp1_ != NULL;
#line 1279 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	return result;
#line 1929 "wizard.c"
}


static void boxes_wizard_prepare_for_location (BoxesWizard* self, const gchar* location, gboolean probing, BoxesActivityProgress* progress, GError** error) {
	gboolean _tmp0_ = FALSE;
	BoxesActivityProgress* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	GFile* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	gboolean _tmp7_ = FALSE;
	GFile* file = NULL;
	GFile* _tmp12_ = NULL;
	gchar* path = NULL;
	GFile* _tmp13_ = NULL;
	gchar* _tmp14_ = NULL;
	gboolean _tmp15_ = FALSE;
	const gchar* _tmp16_ = NULL;
	gboolean uncertain = FALSE;
	gchar* uri = NULL;
	GFile* _tmp25_ = NULL;
	gchar* _tmp26_ = NULL;
	gchar* mimetype = NULL;
	const gchar* _tmp27_ = NULL;
	gboolean _tmp28_ = FALSE;
	gchar* _tmp29_ = NULL;
	gboolean _tmp30_ = FALSE;
	const gchar* _tmp32_ = NULL;
	const gchar* _tmp33_ = NULL;
	gchar* _tmp34_ = NULL;
	gchar* _tmp35_ = NULL;
	const gchar* _tmp36_ = NULL;
	GError* _tmp37_ = NULL;
	GError * _inner_error_ = NULL;
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (location != NULL);
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = probing;
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = progress;
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (_tmp0_ || (_tmp1_ != NULL));
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = location;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (g_strcmp0 (_tmp2_, "") == 0) {
#line 1977 "wizard.c"
		const gchar* _tmp3_ = NULL;
		GError* _tmp4_ = NULL;
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp3_ = _ ("Empty location");
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp4_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _tmp3_);
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_inner_error_ = _tmp4_;
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_propagate_error (error, _inner_error_);
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		return;
#line 1990 "wizard.c"
	}
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp6_ = location;
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp7_ = string_contains (_tmp6_, "://");
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp7_) {
#line 1998 "wizard.c"
		const gchar* _tmp8_ = NULL;
		GFile* _tmp9_ = NULL;
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp8_ = location;
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp9_ = g_file_new_for_uri (_tmp8_);
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_tmp5_);
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp5_ = _tmp9_;
#line 2009 "wizard.c"
	} else {
		const gchar* _tmp10_ = NULL;
		GFile* _tmp11_ = NULL;
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp10_ = location;
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp11_ = g_file_new_for_path (_tmp10_);
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_tmp5_);
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp5_ = _tmp11_;
#line 2021 "wizard.c"
	}
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp12_ = _g_object_ref0 (_tmp5_);
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	file = _tmp12_;
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp13_ = file;
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp14_ = g_file_get_path (_tmp13_);
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	path = _tmp14_;
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp16_ = path;
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp16_ != NULL) {
#line 2037 "wizard.c"
		gboolean _tmp17_ = FALSE;
		GFile* _tmp18_ = NULL;
		gboolean _tmp19_ = FALSE;
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp18_ = file;
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp19_ = g_file_has_uri_scheme (_tmp18_, "file");
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_tmp19_) {
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp17_ = TRUE;
#line 2049 "wizard.c"
		} else {
			GFile* _tmp20_ = NULL;
			gboolean _tmp21_ = FALSE;
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp20_ = file;
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp21_ = g_file_has_uri_scheme (_tmp20_, "smb");
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp17_ = _tmp21_;
#line 2059 "wizard.c"
		}
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp15_ = _tmp17_;
#line 2063 "wizard.c"
	} else {
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp15_ = FALSE;
#line 2067 "wizard.c"
	}
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp15_) {
#line 2071 "wizard.c"
		gboolean _tmp22_ = FALSE;
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp22_ = probing;
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (!_tmp22_) {
#line 2077 "wizard.c"
			const gchar* _tmp23_ = NULL;
			BoxesActivityProgress* _tmp24_ = NULL;
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp23_ = path;
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp24_ = progress;
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			boxes_wizard_prepare_for_installer (self, _tmp23_, _tmp24_, &_inner_error_);
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_propagate_error (error, _inner_error_);
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_free0 (path);
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (file);
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (_tmp5_);
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				return;
#line 2098 "wizard.c"
			}
		}
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_free0 (path);
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (file);
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_tmp5_);
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		return;
#line 2109 "wizard.c"
	}
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp25_ = file;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp26_ = g_file_get_uri (_tmp25_);
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	uri = _tmp26_;
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp27_ = uri;
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp29_ = g_content_type_guess (_tmp27_, NULL, (gsize) 0, &_tmp28_);
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	uncertain = _tmp28_;
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	mimetype = _tmp29_;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp30_ = uncertain;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp30_) {
#line 2129 "wizard.c"
		const gchar* _tmp31_ = NULL;
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp31_ = uri;
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_prepare_for_uri (self, _tmp31_, &_inner_error_);
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_propagate_error (error, _inner_error_);
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_free0 (mimetype);
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_free0 (uri);
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_free0 (path);
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_object_unref0 (file);
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_object_unref0 (_tmp5_);
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			return;
#line 2151 "wizard.c"
		}
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_free0 (mimetype);
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_free0 (uri);
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_free0 (path);
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (file);
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_tmp5_);
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		return;
#line 2165 "wizard.c"
	}
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp32_ = uri;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp33_ = mimetype;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp34_ = g_content_type_get_mime_type (_tmp33_);
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp35_ = _tmp34_;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_debug ("wizard.vala:289: Can't handle remote location '%s' (mime type: '%s')", _tmp32_, _tmp35_);
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_free0 (_tmp35_);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp36_ = _ ("Invalid URI");
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp37_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _tmp36_);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_inner_error_ = _tmp37_;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_propagate_error (error, _inner_error_);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_free0 (mimetype);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_free0 (uri);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_free0 (path);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (file);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_tmp5_);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return;
#line 2199 "wizard.c"
}


static void boxes_wizard_prepare_for_uri (BoxesWizard* self, const gchar* uri_as_text, GError** error) {
	xmlURI* uri = NULL;
	const gchar* _tmp0_ = NULL;
	xmlURI* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	xmlURI* _tmp3_ = NULL;
	BoxesWizardSource* _tmp8_ = NULL;
	gboolean _tmp9_ = FALSE;
	gboolean _tmp10_ = FALSE;
	const gchar* _tmp22_ = NULL;
	xmlURI* _tmp23_ = NULL;
	const gchar* _tmp24_ = NULL;
	xmlURI* _tmp26_ = NULL;
	const gchar* _tmp27_ = NULL;
	const gchar* _tmp28_ = NULL;
	BoxesCollectionSource* _tmp29_ = NULL;
	xmlURI* _tmp30_ = NULL;
	const gchar* _tmp31_ = NULL;
	GError * _inner_error_ = NULL;
#line 295 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 295 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (uri_as_text != NULL);
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = uri_as_text;
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = xmlParseURI (_tmp0_);
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	uri = _tmp1_;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = uri;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp3_ == NULL) {
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp2_ = TRUE;
#line 2238 "wizard.c"
	} else {
		xmlURI* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp4_ = uri;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp5_ = _tmp4_->scheme;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp2_ = _tmp5_ == NULL;
#line 2248 "wizard.c"
	}
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp2_) {
#line 2252 "wizard.c"
		const gchar* _tmp6_ = NULL;
		GError* _tmp7_ = NULL;
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp6_ = _ ("Invalid URI");
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp7_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _tmp6_);
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_inner_error_ = _tmp7_;
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_inner_error_->domain == BOXES_ERROR) {
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_propagate_error (error, _inner_error_);
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_xmlFreeURI0 (uri);
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			return;
#line 2269 "wizard.c"
		} else {
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_xmlFreeURI0 (uri);
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_clear_error (&_inner_error_);
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			return;
#line 2279 "wizard.c"
		}
	}
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp8_ = self->priv->wizard_source;
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp9_ = boxes_wizard_source_get_download_required (_tmp8_);
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp10_ = _tmp9_;
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp10_) {
#line 2290 "wizard.c"
		GFile* file = NULL;
		const gchar* _tmp11_ = NULL;
		GFile* _tmp12_ = NULL;
		gchar* basename = NULL;
		GFile* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		gboolean _tmp15_ = FALSE;
		gboolean _tmp16_ = FALSE;
		const gchar* _tmp17_ = NULL;
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp11_ = uri_as_text;
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp12_ = g_file_new_for_uri (_tmp11_);
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		file = _tmp12_;
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp13_ = file;
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp14_ = g_file_get_basename (_tmp13_);
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		basename = _tmp14_;
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp17_ = basename;
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_tmp17_ == NULL) {
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp16_ = TRUE;
#line 2318 "wizard.c"
		} else {
			const gchar* _tmp18_ = NULL;
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp18_ = basename;
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp16_ = g_strcmp0 (_tmp18_, "") == 0;
#line 2325 "wizard.c"
		}
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_tmp16_) {
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp15_ = TRUE;
#line 2331 "wizard.c"
		} else {
			const gchar* _tmp19_ = NULL;
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp19_ = basename;
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp15_ = g_strcmp0 (_tmp19_, "/") == 0;
#line 2338 "wizard.c"
		}
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_tmp15_) {
#line 2342 "wizard.c"
			const gchar* _tmp20_ = NULL;
			GError* _tmp21_ = NULL;
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp20_ = _ ("Invalid URI");
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp21_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _tmp20_);
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_inner_error_ = _tmp21_;
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (_inner_error_->domain == BOXES_ERROR) {
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_propagate_error (error, _inner_error_);
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_free0 (basename);
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (file);
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_xmlFreeURI0 (uri);
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				return;
#line 2363 "wizard.c"
			} else {
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_free0 (basename);
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (file);
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_xmlFreeURI0 (uri);
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_clear_error (&_inner_error_);
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				return;
#line 2377 "wizard.c"
			}
		}
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_free0 (basename);
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (file);
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_xmlFreeURI0 (uri);
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		return;
#line 2388 "wizard.c"
	}
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp23_ = uri;
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp24_ = _tmp23_->server;
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp22_ = _tmp24_;
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp22_ == NULL) {
#line 2398 "wizard.c"
		const gchar* _tmp25_ = NULL;
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp25_ = uri_as_text;
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp22_ = _tmp25_;
#line 2404 "wizard.c"
	}
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp26_ = uri;
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp27_ = _tmp26_->scheme;
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp28_ = uri_as_text;
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp29_ = boxes_collection_source_new (_tmp22_, _tmp27_, _tmp28_);
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->source);
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->source = _tmp29_;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp30_ = uri;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp31_ = _tmp30_->scheme;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (g_strcmp0 (_tmp31_, "spice") == 0) {
#line 2424 "wizard.c"
		const gchar* _tmp32_ = NULL;
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp32_ = uri_as_text;
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		spice_validate_uri (_tmp32_, NULL, NULL, &_inner_error_);
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (_inner_error_->domain == BOXES_ERROR) {
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_propagate_error (error, _inner_error_);
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_xmlFreeURI0 (uri);
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				return;
#line 2440 "wizard.c"
			} else {
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_xmlFreeURI0 (uri);
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_clear_error (&_inner_error_);
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				return;
#line 2450 "wizard.c"
			}
		}
	} else {
		xmlURI* _tmp33_ = NULL;
		const gchar* _tmp34_ = NULL;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp33_ = uri;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp34_ = _tmp33_->scheme;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (g_strcmp0 (_tmp34_, "vnc") == 0) {
#line 2462 "wizard.c"
		} else {
			xmlURI* _tmp35_ = NULL;
			const gchar* _tmp36_ = NULL;
			gboolean _tmp37_ = FALSE;
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp35_ = uri;
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp36_ = _tmp35_->scheme;
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp37_ = g_str_has_prefix (_tmp36_, "qemu");
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (_tmp37_) {
#line 2475 "wizard.c"
				BoxesCollectionSource* _tmp38_ = NULL;
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp38_ = self->priv->source;
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_collection_source_set_source_type (_tmp38_, "libvirt");
#line 2481 "wizard.c"
			} else {
				BoxesApp* _tmp39_ = NULL;
				xmlURI* _tmp40_ = NULL;
				const gchar* _tmp41_ = NULL;
				gboolean _tmp42_ = FALSE;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp39_ = boxes_app_app;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp40_ = uri;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp41_ = _tmp40_->scheme;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp42_ = boxes_app_has_broker_for_source_type (_tmp39_, _tmp41_);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (_tmp42_) {
#line 2497 "wizard.c"
					BoxesCollectionSource* _tmp43_ = NULL;
					xmlURI* _tmp44_ = NULL;
					const gchar* _tmp45_ = NULL;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp43_ = self->priv->source;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp44_ = uri;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp45_ = _tmp44_->scheme;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					boxes_collection_source_set_source_type (_tmp43_, _tmp45_);
#line 2509 "wizard.c"
				} else {
					const gchar* _tmp46_ = NULL;
					xmlURI* _tmp47_ = NULL;
					const gchar* _tmp48_ = NULL;
					gchar* _tmp49_ = NULL;
					gchar* _tmp50_ = NULL;
					GError* _tmp51_ = NULL;
					GError* _tmp52_ = NULL;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp46_ = _ ("Unsupported protocol '%s'");
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp47_ = uri;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp48_ = _tmp47_->scheme;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp49_ = g_strdup_printf (_tmp46_, _tmp48_);
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp50_ = _tmp49_;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp51_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _tmp50_);
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp52_ = _tmp51_;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_g_free0 (_tmp50_);
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_inner_error_ = _tmp52_;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					if (_inner_error_->domain == BOXES_ERROR) {
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						g_propagate_error (error, _inner_error_);
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_xmlFreeURI0 (uri);
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						return;
#line 2544 "wizard.c"
					} else {
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_xmlFreeURI0 (uri);
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						g_clear_error (&_inner_error_);
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						return;
#line 2554 "wizard.c"
					}
				}
			}
		}
	}
#line 295 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_xmlFreeURI0 (uri);
#line 2562 "wizard.c"
}


static Block86Data* block86_data_ref (Block86Data* _data86_) {
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_atomic_int_inc (&_data86_->_ref_count_);
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return _data86_;
#line 2571 "wizard.c"
}


static void block86_data_unref (void * _userdata_) {
	Block86Data* _data86_;
	_data86_ = (Block86Data*) _userdata_;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (g_atomic_int_dec_and_test (&_data86_->_ref_count_)) {
#line 2580 "wizard.c"
		BoxesWizard* self;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		self = _data86_->self;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_data86_->progress);
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (self);
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_slice_free (Block86Data, _data86_);
#line 2590 "wizard.c"
	}
}


static void __lambda169_ (Block86Data* _data86_, GObject* obj, GAsyncResult* res) {
	BoxesWizard* self;
	GAsyncResult* _tmp0_ = NULL;
	BoxesActivityProgress* _tmp1_ = NULL;
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = _data86_->self;
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (res != NULL);
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = res;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = _data86_->progress;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_on_installer_media_instantiated (self, _tmp0_, _tmp1_);
#line 2609 "wizard.c"
}


static void ___lambda169__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	__lambda169_ (self, source_object, res);
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	block86_data_unref (self);
#line 2618 "wizard.c"
}


static void boxes_wizard_prepare_for_installer (BoxesWizard* self, const gchar* path, BoxesActivityProgress* progress, GError** error) {
	Block86Data* _data86_;
	BoxesActivityProgress* _tmp0_ = NULL;
	BoxesActivityProgress* _tmp1_ = NULL;
	GtkButton* _tmp2_ = NULL;
	GtkLabel* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	GtkLabel* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	BoxesMediaManager* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (path != NULL);
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (progress != NULL);
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data86_ = g_slice_new0 (Block86Data);
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data86_->_ref_count_ = 1;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data86_->self = g_object_ref (self);
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = progress;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data86_->progress);
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data86_->progress = _tmp1_;
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = self->priv->next_button;
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp2_, FALSE);
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = self->priv->prep_media_label;
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = _ ("Unknown installer media");
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_label_set_label (_tmp3_, _tmp4_);
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp5_ = self->priv->prep_status_label;
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp6_ = _ ("Analyzing…");
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_label_set_label (_tmp5_, _tmp6_);
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp7_ = self->priv->media_manager;
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp8_ = path;
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_media_manager_create_installer_media_for_path (_tmp7_, _tmp8_, NULL, ___lambda169__gasync_ready_callback, block86_data_ref (_data86_));
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	block86_data_unref (_data86_);
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data86_ = NULL;
#line 2679 "wizard.c"
}


static void boxes_wizard_on_installer_media_instantiated (BoxesWizard* self, GAsyncResult* _result_, BoxesActivityProgress* progress) {
	GError * _inner_error_ = NULL;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (_result_ != NULL);
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (progress != NULL);
#line 2691 "wizard.c"
	{
		BoxesInstallerMedia* install_media = NULL;
		BoxesMediaManager* _tmp0_ = NULL;
		GAsyncResult* _tmp1_ = NULL;
		BoxesInstallerMedia* _tmp2_ = NULL;
		BoxesInstallerMedia* _tmp3_ = NULL;
		BoxesActivityProgress* _tmp4_ = NULL;
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp0_ = self->priv->media_manager;
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp1_ = _result_;
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp2_ = boxes_media_manager_create_installer_media_for_path_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		install_media = _tmp2_;
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (g_error_matches (_inner_error_, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
#line 2711 "wizard.c"
				goto __catch114_g_io_error_cancelled;
			}
			goto __catch114_g_error;
		}
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp3_ = install_media;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp4_ = progress;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_prepare_media (self, _tmp3_, _tmp4_, NULL, NULL);
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (install_media);
#line 2724 "wizard.c"
	}
	goto __finally114;
	__catch114_g_io_error_cancelled:
	{
		GError* cancel_error = NULL;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		cancel_error = _inner_error_;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_inner_error_ = NULL;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_error_free0 (cancel_error);
#line 2736 "wizard.c"
	}
	goto __finally114;
	__catch114_g_error:
	{
		GError* _error_ = NULL;
		GError* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
		gchar* msg = NULL;
		const gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		BoxesAppWindow* _tmp9_ = NULL;
		BoxesNotificationbar* _tmp10_ = NULL;
		const gchar* _tmp11_ = NULL;
		GdNotification* _tmp12_ = NULL;
		GdNotification* _tmp13_ = NULL;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_error_ = _inner_error_;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_inner_error_ = NULL;
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp5_ = _error_;
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp6_ = _tmp5_->message;
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_debug ("wizard.vala:342: Failed to analyze installer image: %s", _tmp6_);
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp7_ = _ ("Failed to analyze installer media. Corrupted or incomplete media?");
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp8_ = g_strdup (_tmp7_);
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		msg = _tmp8_;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp9_ = self->priv->window;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp10_ = _tmp9_->notificationbar;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp11_ = msg;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp12_ = boxes_notificationbar_display_error (_tmp10_, _tmp11_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp13_ = _tmp12_;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_tmp13_);
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_page (self, BOXES_WIZARD_PAGE_SOURCE);
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_free0 (msg);
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_error_free0 (_error_);
#line 2786 "wizard.c"
	}
	__finally114:
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_clear_error (&_inner_error_);
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		return;
#line 2797 "wizard.c"
	}
}


static void boxes_wizard_prepare_media_data_free (gpointer _data) {
	BoxesWizardPrepareMediaData* _data_;
	_data_ = _data;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->install_media);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->progress);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->self);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_slice_free (BoxesWizardPrepareMediaData, _data_);
#line 2813 "wizard.c"
}


static void boxes_wizard_prepare_media (BoxesWizard* self, BoxesInstallerMedia* install_media, BoxesActivityProgress* progress, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesWizardPrepareMediaData* _data_;
	BoxesWizard* _tmp0_ = NULL;
	BoxesInstallerMedia* _tmp1_ = NULL;
	BoxesInstallerMedia* _tmp2_ = NULL;
	BoxesActivityProgress* _tmp3_ = NULL;
	BoxesActivityProgress* _tmp4_ = NULL;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_ = g_slice_new0 (BoxesWizardPrepareMediaData);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_wizard_prepare_media);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_wizard_prepare_media_data_free);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->self = _tmp0_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = install_media;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->install_media);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->install_media = _tmp2_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = progress;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->progress);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->progress = _tmp4_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_prepare_media_co (_data_);
#line 2852 "wizard.c"
}


static void boxes_wizard_prepare_media_finish (BoxesWizard* self, GAsyncResult* _res_) {
	BoxesWizardPrepareMediaData* _data_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 2860 "wizard.c"
}


static void boxes_wizard_prepare_media_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesWizardPrepareMediaData* _data_;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_ = _user_data_;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_source_object_ = source_object;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_res_ = _res_;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_prepare_media_co (_data_);
#line 2874 "wizard.c"
}


static gboolean boxes_wizard_prepare_media_co (BoxesWizardPrepareMediaData* _data_) {
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	switch (_data_->_state_) {
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case 0:
#line 2883 "wizard.c"
		goto _state_0;
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case 1:
#line 2887 "wizard.c"
		goto _state_1;
		default:
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_assert_not_reached ();
#line 2892 "wizard.c"
	}
	_state_0:
#line 350 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp0_ = NULL;
#line 350 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp0_ = _data_->install_media;
#line 350 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp1_ = NULL;
#line 350 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp1_ = _data_->_tmp0_->os;
#line 350 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_tmp1_ != NULL) {
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp2_ = NULL;
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp2_ = _data_->self->priv->prep_media_label;
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp3_ = NULL;
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp3_ = _data_->install_media;
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp4_ = NULL;
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp4_ = _data_->_tmp3_->os;
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp5_ = NULL;
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp5_ = osinfo_product_get_name ((OsinfoProduct*) _data_->_tmp4_);
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp6_ = NULL;
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp6_ = _data_->_tmp5_;
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		gtk_label_set_label (_data_->_tmp2_, _data_->_tmp6_);
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp7_ = NULL;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp7_ = _data_->self->priv->installer_image;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp8_ = NULL;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp8_ = _data_->install_media;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp9_ = NULL;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp9_ = _data_->_tmp8_->os;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_downloader_fetch_os_logo (_data_->_tmp7_, _data_->_tmp9_, 128, NULL, NULL);
#line 2941 "wizard.c"
	}
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp10_ = NULL;
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp10_ = _data_->self->priv->wizard_source;
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp11_ = FALSE;
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp11_ = boxes_wizard_source_get_download_required (_data_->_tmp10_);
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp12_ = FALSE;
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp12_ = _data_->_tmp11_;
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_tmp12_) {
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp13_ = NULL;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp13_ = _data_->progress;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp14_ = NULL;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp14_ = boxes_activity_progress_add_child_activity (_data_->_tmp13_, BOXES_WIZARD_PREPARE_PROGRESS_SCALE);
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_data_->prepare_media_progress);
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->prepare_media_progress = _data_->_tmp14_;
#line 2969 "wizard.c"
	} else {
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp15_ = NULL;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp15_ = _data_->progress;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp16_ = NULL;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp16_ = _g_object_ref0 (_data_->_tmp15_);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_data_->prepare_media_progress);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->prepare_media_progress = _data_->_tmp16_;
#line 2983 "wizard.c"
	}
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp17_ = NULL;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp17_ = _data_->prepare_media_progress;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp18_ = NULL;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp18_ = _data_->self->priv->prep_status_label;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_bind_property_with_closures ((GObject*) _data_->_tmp17_, "info", (GObject*) _data_->_tmp18_, "label", G_BINDING_DEFAULT, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp19_ = NULL;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp19_ = _data_->install_media;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp20_ = NULL;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp20_ = _data_->prepare_media_progress;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp21_ = NULL;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp21_ = _data_->self->priv->prepare_cancellable;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_state_ = 1;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_installer_media_prepare (_data_->_tmp19_, _data_->_tmp20_, _data_->_tmp21_, boxes_wizard_prepare_media_ready, _data_);
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 3013 "wizard.c"
	_state_1:
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_installer_media_prepare_finish (_data_->_tmp19_, _data_->_res_);
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp22_ = NULL;
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp22_ = _data_->install_media;
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp23_ = NULL;
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp23_ = boxes_installer_media_get_vm_creator (_data_->_tmp22_);
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_boxes_vm_creator_unref0 (_data_->self->priv->vm_creator);
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->self->priv->vm_creator = _data_->_tmp23_;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp24_ = NULL;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp24_ = _data_->self->priv->prep_progress;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_progress_bar_set_fraction (_data_->_tmp24_, 1.0);
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_page (_data_->self, BOXES_WIZARD_PAGE_SETUP);
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->prepare_media_progress);
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_state_ == 0) {
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3043 "wizard.c"
	} else {
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3047 "wizard.c"
	}
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_unref (_data_->_async_result);
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 3053 "wizard.c"
}


static gboolean boxes_wizard_prepare (BoxesWizard* self, BoxesActivityProgress* progress) {
	gboolean result = FALSE;
	GCancellable* _tmp9_ = NULL;
	BoxesWizardSource* _tmp10_ = NULL;
	gboolean _tmp11_ = FALSE;
	gboolean _tmp12_ = FALSE;
	GtkImage* _tmp18_ = NULL;
	BoxesWizardSource* _tmp19_ = NULL;
	BoxesInstallerMedia* _tmp20_ = NULL;
	BoxesInstallerMedia* _tmp21_ = NULL;
	BoxesWizardSource* _tmp30_ = NULL;
	gboolean _tmp31_ = FALSE;
	GError * _inner_error_ = NULL;
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (progress != NULL, FALSE);
#line 3074 "wizard.c"
	{
		BoxesWizardSource* _tmp0_ = NULL;
		const gchar* _tmp1_ = NULL;
		const gchar* _tmp2_ = NULL;
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp0_ = self->priv->wizard_source;
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp1_ = boxes_wizard_source_get_uri (_tmp0_);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp2_ = _tmp1_;
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_prepare_for_location (self, _tmp2_, TRUE, NULL, &_inner_error_);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3089 "wizard.c"
			goto __catch115_g_error;
		}
	}
	goto __finally115;
	__catch115_g_error:
	{
		GError* _error_ = NULL;
		BoxesAppWindow* _tmp3_ = NULL;
		BoxesNotificationbar* _tmp4_ = NULL;
		GError* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
		GdNotification* _tmp7_ = NULL;
		GdNotification* _tmp8_ = NULL;
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_error_ = _inner_error_;
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_inner_error_ = NULL;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp3_ = self->priv->window;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp4_ = _tmp3_->notificationbar;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp5_ = _error_;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp6_ = _tmp5_->message;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp7_ = boxes_notificationbar_display_error (_tmp4_, _tmp6_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp8_ = _tmp7_;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_tmp8_);
#line 375 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		result = FALSE;
#line 375 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_error_free0 (_error_);
#line 375 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		return result;
#line 3127 "wizard.c"
	}
	__finally115:
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_clear_error (&_inner_error_);
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		return FALSE;
#line 3138 "wizard.c"
	}
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp9_ = g_cancellable_new ();
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->prepare_cancellable);
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->prepare_cancellable = _tmp9_;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp10_ = self->priv->wizard_source;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp11_ = boxes_wizard_source_get_download_required (_tmp10_);
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp12_ = _tmp11_;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp12_) {
#line 3154 "wizard.c"
		GtkButton* _tmp13_ = NULL;
		BoxesWizardSource* _tmp14_ = NULL;
		const gchar* _tmp15_ = NULL;
		const gchar* _tmp16_ = NULL;
		BoxesActivityProgress* _tmp17_ = NULL;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp13_ = self->priv->continue_button;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		gtk_widget_set_sensitive ((GtkWidget*) _tmp13_, FALSE);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp14_ = self->priv->wizard_source;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp15_ = boxes_wizard_source_get_uri (_tmp14_);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp16_ = _tmp15_;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp17_ = progress;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_download_media (self, _tmp16_, _tmp17_, NULL, NULL);
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		result = TRUE;
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		return result;
#line 3178 "wizard.c"
	}
#line 386 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp18_ = self->priv->installer_image;
#line 386 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_image_set_from_icon_name (_tmp18_, "media-optical", 0);
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp19_ = self->priv->wizard_source;
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp20_ = boxes_wizard_source_get_install_media (_tmp19_);
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp21_ = _tmp20_;
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp21_ != NULL) {
#line 3192 "wizard.c"
		GtkLabel* _tmp22_ = NULL;
		const gchar* _tmp23_ = NULL;
		GtkLabel* _tmp24_ = NULL;
		const gchar* _tmp25_ = NULL;
		BoxesWizardSource* _tmp26_ = NULL;
		BoxesInstallerMedia* _tmp27_ = NULL;
		BoxesInstallerMedia* _tmp28_ = NULL;
		BoxesActivityProgress* _tmp29_ = NULL;
#line 389 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp22_ = self->priv->prep_media_label;
#line 389 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp23_ = _ ("Unknown installer media");
#line 389 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		gtk_label_set_label (_tmp22_, _tmp23_);
#line 390 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp24_ = self->priv->prep_status_label;
#line 390 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp25_ = _ ("Analyzing…");
#line 390 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		gtk_label_set_label (_tmp24_, _tmp25_);
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp26_ = self->priv->wizard_source;
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp27_ = boxes_wizard_source_get_install_media (_tmp26_);
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp28_ = _tmp27_;
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp29_ = progress;
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_prepare_media (self, _tmp28_, _tmp29_, NULL, NULL);
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		result = TRUE;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		return result;
#line 3227 "wizard.c"
	}
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp30_ = self->priv->wizard_source;
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp31_ = _tmp30_->libvirt_sys_import;
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp31_) {
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		result = TRUE;
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		return result;
#line 3239 "wizard.c"
	}
	{
		BoxesWizardSource* _tmp32_ = NULL;
		const gchar* _tmp33_ = NULL;
		const gchar* _tmp34_ = NULL;
		BoxesActivityProgress* _tmp35_ = NULL;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp32_ = self->priv->wizard_source;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp33_ = boxes_wizard_source_get_uri (_tmp32_);
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp34_ = _tmp33_;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp35_ = progress;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_prepare_for_location (self, _tmp34_, FALSE, _tmp35_, &_inner_error_);
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3258 "wizard.c"
			goto __catch116_g_error;
		}
	}
	goto __finally116;
	__catch116_g_error:
	{
		GError* _error_ = NULL;
		BoxesAppWindow* _tmp36_ = NULL;
		BoxesNotificationbar* _tmp37_ = NULL;
		GError* _tmp38_ = NULL;
		const gchar* _tmp39_ = NULL;
		GdNotification* _tmp40_ = NULL;
		GdNotification* _tmp41_ = NULL;
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_error_ = _inner_error_;
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_inner_error_ = NULL;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp36_ = self->priv->window;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp37_ = _tmp36_->notificationbar;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp38_ = _error_;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp39_ = _tmp38_->message;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp40_ = boxes_notificationbar_display_error (_tmp37_, _tmp39_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp41_ = _tmp40_;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_tmp41_);
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		result = FALSE;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_error_free0 (_error_);
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		return result;
#line 3296 "wizard.c"
	}
	__finally116:
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_clear_error (&_inner_error_);
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		return FALSE;
#line 3307 "wizard.c"
	}
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	result = TRUE;
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return result;
#line 3313 "wizard.c"
}


static void __lambda170_ (BoxesWizard* self) {
	BoxesVMCreator* _tmp0_ = NULL;
	BoxesInstallerMedia* _tmp1_ = NULL;
	BoxesInstallerMedia* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	gboolean _tmp4_ = FALSE;
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->vm_creator;
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = boxes_vm_creator_get_install_media (_tmp0_);
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = _tmp1_;
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = boxes_installer_media_get_ready_to_create (_tmp2_);
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = _tmp3_;
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp4_) {
#line 3335 "wizard.c"
		BoxesWizardPage _tmp5_ = 0;
		BoxesWizardPage _tmp6_ = 0;
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp5_ = boxes_wizard_get_page (self);
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp6_ = _tmp5_;
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_page (self, _tmp6_ + 1);
#line 3344 "wizard.c"
	}
}


static void ___lambda170__boxes_installer_media_user_wants_to_create (BoxesInstallerMedia* _sender, gpointer self) {
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	__lambda170_ ((BoxesWizard*) self);
#line 3352 "wizard.c"
}


static gboolean boxes_wizard_setup (BoxesWizard* self) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	BoxesCollectionSource* _tmp1_ = NULL;
	BoxesVMCreator* _tmp4_ = NULL;
	BoxesVMCreator* _tmp5_ = NULL;
	BoxesInstallerMedia* _tmp6_ = NULL;
	BoxesInstallerMedia* _tmp7_ = NULL;
	GtkButton* _tmp8_ = NULL;
	BoxesVMCreator* _tmp9_ = NULL;
	BoxesInstallerMedia* _tmp10_ = NULL;
	BoxesInstallerMedia* _tmp11_ = NULL;
	GtkBox* _tmp12_ = NULL;
	BoxesVMCreator* _tmp13_ = NULL;
	BoxesInstallerMedia* _tmp14_ = NULL;
	BoxesInstallerMedia* _tmp15_ = NULL;
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->source;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp1_ != NULL) {
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp0_ = TRUE;
#line 3380 "wizard.c"
	} else {
		BoxesWizardSource* _tmp2_ = NULL;
		gboolean _tmp3_ = FALSE;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp2_ = self->priv->wizard_source;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp3_ = _tmp2_->libvirt_sys_import;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp0_ = _tmp3_;
#line 3390 "wizard.c"
	}
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp0_) {
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		result = TRUE;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		return result;
#line 3398 "wizard.c"
	}
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = self->priv->vm_creator;
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (_tmp4_ != NULL);
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp5_ = self->priv->vm_creator;
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp6_ = boxes_vm_creator_get_install_media (_tmp5_);
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp7_ = _tmp6_;
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp8_ = self->priv->continue_button;
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_bind_property_with_closures ((GObject*) _tmp7_, "ready-to-create", (GObject*) _tmp8_, "sensitive", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp9_ = self->priv->vm_creator;
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp10_ = boxes_vm_creator_get_install_media (_tmp9_);
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp11_ = _tmp10_;
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp12_ = self->priv->setup_box;
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_installer_media_populate_setup_box (_tmp11_, _tmp12_);
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp13_ = self->priv->vm_creator;
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp14_ = boxes_vm_creator_get_install_media (_tmp13_);
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp15_ = _tmp14_;
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_signal_connect_object (_tmp15_, "user-wants-to-create", (GCallback) ___lambda170__boxes_installer_media_user_wants_to_create, self, 0);
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	result = TRUE;
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return result;
#line 3436 "wizard.c"
}


static void boxes_wizard_review_data_free (gpointer _data) {
	BoxesWizardReviewData* _data_;
	_data_ = _data;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->self);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_slice_free (BoxesWizardReviewData, _data_);
#line 3447 "wizard.c"
}


static void boxes_wizard_review (BoxesWizard* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesWizardReviewData* _data_;
	BoxesWizard* _tmp0_ = NULL;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_ = g_slice_new0 (BoxesWizardReviewData);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_wizard_review);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_wizard_review_data_free);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->self = _tmp0_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_review_co (_data_);
#line 3466 "wizard.c"
}


static gboolean boxes_wizard_review_finish (BoxesWizard* self, GAsyncResult* _res_) {
	gboolean result;
	BoxesWizardReviewData* _data_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	result = _data_->result;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return result;
#line 3479 "wizard.c"
}


static void boxes_wizard_review_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesWizardReviewData* _data_;
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_ = _user_data_;
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_source_object_ = source_object;
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_res_ = _res_;
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_review_co (_data_);
#line 3493 "wizard.c"
}


static gboolean boxes_wizard_review_co (BoxesWizardReviewData* _data_) {
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	switch (_data_->_state_) {
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case 0:
#line 3502 "wizard.c"
		goto _state_0;
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case 1:
#line 3506 "wizard.c"
		goto _state_1;
		default:
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_assert_not_reached ();
#line 3511 "wizard.c"
	}
	_state_0:
#line 431 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp0_ = NULL;
#line 431 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp0_ = _data_->self->priv->review_cancellable;
#line 431 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (_data_->_tmp0_ == NULL);
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp1_ = NULL;
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp1_ = g_cancellable_new ();
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->self->priv->review_cancellable);
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->self->priv->review_cancellable = _data_->_tmp1_;
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_state_ = 1;
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_do_review_cancellable (_data_->self, boxes_wizard_review_ready, _data_);
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 3534 "wizard.c"
	_state_1:
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp2_ = FALSE;
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp2_ = boxes_wizard_do_review_cancellable_finish (_data_->self, _data_->_res_);
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_result_ = _data_->_tmp2_;
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->self->priv->review_cancellable);
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->self->priv->review_cancellable = NULL;
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->self->priv->skip_review_for_live = FALSE;
#line 438 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->result = _data_->_result_;
#line 438 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_state_ == 0) {
#line 438 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3554 "wizard.c"
	} else {
#line 438 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3558 "wizard.c"
	}
#line 438 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_unref (_data_->_async_result);
#line 438 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_state_ == 0) {
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3568 "wizard.c"
	} else {
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3572 "wizard.c"
	}
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_unref (_data_->_async_result);
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 3578 "wizard.c"
}


static void boxes_wizard_do_review_cancellable_data_free (gpointer _data) {
	BoxesWizardDoReviewCancellableData* _data_;
	_data_ = _data;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->self);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_slice_free (BoxesWizardDoReviewCancellableData, _data_);
#line 3589 "wizard.c"
}


static void boxes_wizard_do_review_cancellable (BoxesWizard* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesWizardDoReviewCancellableData* _data_;
	BoxesWizard* _tmp0_ = NULL;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_ = g_slice_new0 (BoxesWizardDoReviewCancellableData);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_wizard_do_review_cancellable);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_wizard_do_review_cancellable_data_free);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->self = _tmp0_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_do_review_cancellable_co (_data_);
#line 3608 "wizard.c"
}


static gboolean boxes_wizard_do_review_cancellable_finish (BoxesWizard* self, GAsyncResult* _res_) {
	gboolean result;
	BoxesWizardDoReviewCancellableData* _data_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	result = _data_->result;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return result;
#line 3621 "wizard.c"
}


static void boxes_wizard_do_review_cancellable_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesWizardDoReviewCancellableData* _data_;
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_ = _user_data_;
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_source_object_ = source_object;
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_res_ = _res_;
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_do_review_cancellable_co (_data_);
#line 3635 "wizard.c"
}


static gpointer _boxes_pair_ref0 (gpointer self) {
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return self ? boxes_pair_ref (self) : NULL;
#line 3642 "wizard.c"
}


static void _boxes_pair_unref0_ (gpointer var) {
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	(var == NULL) ? NULL : (var = (boxes_pair_unref (var), NULL));
#line 3649 "wizard.c"
}


static void _g_list_free__boxes_pair_unref0_ (GList* self) {
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_list_foreach (self, (GFunc) _boxes_pair_unref0_, NULL);
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_list_free (self);
#line 3658 "wizard.c"
}


static Block87Data* block87_data_ref (Block87Data* _data87_) {
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_atomic_int_inc (&_data87_->_ref_count_);
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return _data87_;
#line 3667 "wizard.c"
}


static void block87_data_unref (void * _userdata_) {
	Block87Data* _data87_;
	_data87_ = (Block87Data*) _userdata_;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (g_atomic_int_dec_and_test (&_data87_->_ref_count_)) {
#line 3676 "wizard.c"
		BoxesWizard* self;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		self = _data87_->self;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_data87_->config);
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (self);
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_slice_free (Block87Data, _data87_);
#line 3686 "wizard.c"
	}
}


static void _____lambda174_ (Block87Data* _data87_, GError** error) {
	BoxesWizard* self;
	GVirConfigDomain* _tmp0_ = NULL;
	BoxesLibvirtMachine* _tmp1_ = NULL;
	BoxesLibvirtMachine* _tmp2_ = NULL;
	GVirDomain* _tmp3_ = NULL;
	GVirDomain* _tmp4_ = NULL;
	GVirConfigDomain* _tmp5_ = NULL;
	GVirConfigDomain* _tmp6_ = NULL;
	GError * _inner_error_ = NULL;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = _data87_->self;
#line 516 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = boxes_wizard_get_libvirt_machine (self);
#line 516 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = _tmp1_;
#line 516 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = boxes_libvirt_machine_get_domain (_tmp2_);
#line 516 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = _tmp3_;
#line 516 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp5_ = gvir_domain_get_config (_tmp4_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 516 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = _tmp5_;
#line 516 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 516 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_propagate_error (error, _inner_error_);
#line 516 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		return;
#line 3721 "wizard.c"
	}
#line 516 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp6_ = _tmp0_;
#line 516 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = NULL;
#line 516 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data87_->config);
#line 516 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data87_->config = _tmp6_;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_tmp0_);
#line 3733 "wizard.c"
}


static void ______lambda174__boxes_run_in_thread_func (gpointer self, GError** error) {
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_____lambda174_ (self, error);
#line 3740 "wizard.c"
}


static void _vala_GVirStorageVolInfo_free (GVirStorageVolInfo* self) {
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_boxed_free (gvir_storage_vol_info_get_type (), self);
#line 3747 "wizard.c"
}


static void ___lambda175_ (BoxesWizard* self) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesMachine* _tmp1_ = NULL;
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->window;
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->_machine;
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_app_window_select_item (_tmp0_, (BoxesCollectionItem*) _tmp1_);
#line 3760 "wizard.c"
}


static void ____lambda175__boxes_wizard_summary_customize_func (gpointer self) {
#line 543 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	___lambda175_ ((BoxesWizard*) self);
#line 3767 "wizard.c"
}


static gboolean boxes_wizard_do_review_cancellable_co (BoxesWizardDoReviewCancellableData* _data_) {
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	switch (_data_->_state_) {
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case 0:
#line 3776 "wizard.c"
		goto _state_0;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case 1:
#line 3780 "wizard.c"
		goto _state_1;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case 2:
#line 3784 "wizard.c"
		goto _state_2;
		default:
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_assert_not_reached ();
#line 3789 "wizard.c"
	}
	_state_0:
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp0_ = NULL;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp0_ = _data_->self->priv->review_cancellable;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (_data_->_tmp0_ != NULL);
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp1_ = NULL;
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp1_ = _data_->self->priv->nokvm_infobar;
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_hide ((GtkWidget*) _data_->_tmp1_);
#line 445 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp2_ = NULL;
#line 445 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp2_ = _data_->self->priv->summary;
#line 445 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_summary_clear (_data_->_tmp2_);
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp3_ = NULL;
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp3_ = _data_->self->priv->source;
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_tmp3_ != NULL) {
#line 3816 "wizard.c"
		{
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp5_ = NULL;
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp5_ = _data_->self->priv->source;
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp6_ = NULL;
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp6_ = boxes_remote_machine_new (_data_->_tmp5_, &_data_->_inner_error_);
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp4_ = _data_->_tmp6_;
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (_data_->_inner_error_->domain == BOXES_ERROR) {
#line 3832 "wizard.c"
					goto __catch117_boxes_error;
				}
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_clear_error (&_data_->_inner_error_);
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				return FALSE;
#line 3841 "wizard.c"
			}
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			boxes_wizard_set_machine (_data_->self, (BoxesMachine*) _data_->_tmp4_);
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_object_unref0 (_data_->_tmp4_);
#line 3847 "wizard.c"
		}
		goto __finally117;
		__catch117_boxes_error:
		{
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_error_ = _data_->_inner_error_;
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_inner_error_ = NULL;
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp7_ = NULL;
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp7_ = _data_->_error_;
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp8_ = NULL;
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp8_ = _data_->_tmp7_->message;
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_warning ("wizard.vala:451: %s", _data_->_tmp8_);
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_error_free0 (_data_->_error_);
#line 3868 "wizard.c"
		}
		__finally117:
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_clear_error (&_data_->_inner_error_);
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			return FALSE;
#line 3879 "wizard.c"
		}
	} else {
#line 453 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp10_ = NULL;
#line 453 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp10_ = _data_->self->priv->vm_creator;
#line 453 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp10_ != NULL) {
#line 453 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp11_ = NULL;
#line 453 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp11_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 453 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp12_ = NULL;
#line 453 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp12_ = _data_->_tmp11_;
#line 453 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp9_ = _data_->_tmp12_ == NULL;
#line 3898 "wizard.c"
		} else {
#line 453 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp9_ = FALSE;
#line 3902 "wizard.c"
		}
#line 453 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp9_) {
#line 3906 "wizard.c"
			{
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp14_ = NULL;
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp14_ = _data_->self->priv->vm_creator;
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp15_ = NULL;
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp15_ = _data_->self->priv->review_cancellable;
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_state_ = 1;
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_vm_creator_create_vm (_data_->_tmp14_, _data_->_tmp15_, boxes_wizard_do_review_cancellable_ready, _data_);
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				return FALSE;
#line 3922 "wizard.c"
				_state_1:
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp16_ = NULL;
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp16_ = boxes_vm_creator_create_vm_finish (_data_->_tmp14_, _data_->_res_, &_data_->_inner_error_);
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp13_ = _data_->_tmp16_;
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					if (g_error_matches (_data_->_inner_error_, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
#line 3934 "wizard.c"
						goto __catch118_g_io_error_cancelled;
					}
					goto __catch118_g_error;
				}
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_wizard_set_machine (_data_->self, (BoxesMachine*) _data_->_tmp13_);
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (_data_->_tmp13_);
#line 3943 "wizard.c"
			}
			goto __finally118;
			__catch118_g_io_error_cancelled:
			{
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->cancel_error = _data_->_inner_error_;
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_inner_error_ = NULL;
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_error_free0 (_data_->cancel_error);
#line 3954 "wizard.c"
			}
			goto __finally118;
			__catch118_g_error:
			{
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_vala1__error_ = _data_->_inner_error_;
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_inner_error_ = NULL;
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp17_ = NULL;
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp17_ = _data_->self->priv->window;
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp18_ = NULL;
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp18_ = _data_->_tmp17_->notificationbar;
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp19_ = NULL;
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp19_ = _ ("Box setup failed");
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp20_ = NULL;
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp20_ = boxes_notificationbar_display_error (_data_->_tmp18_, _data_->_tmp19_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp21_ = NULL;
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp21_ = _data_->_tmp20_;
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (_data_->_tmp21_);
#line 459 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp22_ = NULL;
#line 459 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp22_ = _data_->_vala1__error_;
#line 459 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp23_ = NULL;
#line 459 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp23_ = _data_->_tmp22_->message;
#line 459 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_warning ("wizard.vala:459: %s", _data_->_tmp23_);
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_error_free0 (_data_->_vala1__error_);
#line 3997 "wizard.c"
			}
			__finally118:
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_clear_error (&_data_->_inner_error_);
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				return FALSE;
#line 4008 "wizard.c"
			}
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp24_ = NULL;
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp24_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp25_ = NULL;
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp25_ = _data_->_tmp24_;
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (_data_->_tmp25_ == NULL) {
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_object_notify ((GObject*) _data_->self, "machine");
#line 465 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->result = FALSE;
#line 465 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (_data_->_state_ == 0) {
#line 465 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4028 "wizard.c"
				} else {
#line 465 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					g_simple_async_result_complete (_data_->_async_result);
#line 4032 "wizard.c"
				}
#line 465 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_object_unref (_data_->_async_result);
#line 465 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				return FALSE;
#line 4038 "wizard.c"
			}
		}
	}
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp26_ = NULL;
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp26_ = _data_->self->priv->review_cancellable;
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp27_ = FALSE;
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp27_ = g_cancellable_is_cancelled (_data_->_tmp26_);
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_tmp27_) {
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->result = FALSE;
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_data_->_state_ == 0) {
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4058 "wizard.c"
		} else {
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4062 "wizard.c"
		}
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_object_unref (_data_->_async_result);
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		return FALSE;
#line 4068 "wizard.c"
	}
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp28_ = NULL;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp28_ = _data_->self->priv->review_label;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp29_ = NULL;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp29_ = _ ("Boxes will create a new box with the following properties:");
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_label_set_text (_data_->_tmp28_, _data_->_tmp29_);
#line 474 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp30_ = NULL;
#line 474 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp30_ = _data_->self->priv->source;
#line 474 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_tmp30_ != NULL) {
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		static GQuark _tmp64_label0 = 0;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		static GQuark _tmp64_label1 = 0;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp31_ = NULL;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp31_ = _data_->self->priv->source;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp32_ = NULL;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp32_ = boxes_collection_source_get_uri (_data_->_tmp31_);
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp33_ = NULL;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp33_ = _data_->_tmp32_;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp34_ = NULL;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp34_ = _data_->_tmp33_;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp35_ = NULL;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp35_ = xmlParseURI (_data_->_tmp34_);
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp36_ = NULL;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp36_ = _data_->_tmp35_;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_free0 (_data_->_tmp34_);
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->uri = _data_->_tmp36_;
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp37_ = NULL;
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp37_ = _data_->self->priv->summary;
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp38_ = NULL;
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp38_ = _ ("Type");
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp39_ = NULL;
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp39_ = _data_->self->priv->source;
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp40_ = NULL;
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp40_ = boxes_collection_source_get_source_type (_data_->_tmp39_);
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp41_ = NULL;
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp41_ = _data_->_tmp40_;
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp42_ = NULL;
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp42_ = _data_->_tmp41_;
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_summary_add_property (_data_->_tmp37_, _data_->_tmp38_, _data_->_tmp42_);
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_free0 (_data_->_tmp42_);
#line 479 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp44_ = NULL;
#line 479 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp44_ = _data_->uri;
#line 479 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp44_ != NULL) {
#line 479 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp45_ = NULL;
#line 479 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp45_ = _data_->uri;
#line 479 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp46_ = NULL;
#line 479 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp46_ = _data_->_tmp45_->server;
#line 479 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp43_ = _data_->_tmp46_ != NULL;
#line 4162 "wizard.c"
		} else {
#line 479 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp43_ = FALSE;
#line 4166 "wizard.c"
		}
#line 479 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp43_) {
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp47_ = NULL;
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp47_ = _data_->self->priv->summary;
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp48_ = NULL;
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp48_ = _ ("Host");
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp49_ = NULL;
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp49_ = _data_->uri;
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp50_ = NULL;
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp50_ = _data_->_tmp49_->server;
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp51_ = NULL;
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp51_ = g_utf8_strdown (_data_->_tmp50_, (gssize) (-1));
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp52_ = NULL;
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp52_ = _data_->_tmp51_;
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			boxes_wizard_summary_add_property (_data_->_tmp47_, _data_->_tmp48_, _data_->_tmp52_);
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_free0 (_data_->_tmp52_);
#line 4198 "wizard.c"
		} else {
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp53_ = NULL;
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp53_ = _data_->self->priv->summary;
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp54_ = NULL;
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp54_ = _ ("URI");
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp55_ = NULL;
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp55_ = _data_->self->priv->source;
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp56_ = NULL;
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp56_ = boxes_collection_source_get_uri (_data_->_tmp55_);
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp57_ = NULL;
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp57_ = _data_->_tmp56_;
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp58_ = NULL;
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp58_ = _data_->_tmp57_;
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp59_ = NULL;
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp59_ = g_utf8_strdown (_data_->_tmp58_, (gssize) (-1));
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp60_ = NULL;
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp60_ = _data_->_tmp59_;
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			boxes_wizard_summary_add_property (_data_->_tmp53_, _data_->_tmp54_, _data_->_tmp60_);
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_free0 (_data_->_tmp60_);
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_free0 (_data_->_tmp58_);
#line 4238 "wizard.c"
		}
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp61_ = NULL;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp61_ = _data_->uri;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp62_ = NULL;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp62_ = _data_->_tmp61_->scheme;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp63_ = NULL;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp65_ = 0U;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp63_ = _data_->_tmp62_;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp65_ = (NULL == _data_->_tmp63_) ? 0 : g_quark_from_string (_data_->_tmp63_);
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp65_ == ((0 != _tmp64_label0) ? _tmp64_label0 : (_tmp64_label0 = g_quark_from_static_string ("spice")))) {
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			switch (0) {
#line 4260 "wizard.c"
				default:
				{
					{
#line 487 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->port = 0;
#line 487 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->tls_port = 0;
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp66_ = NULL;
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp66_ = _data_->self->priv->source;
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp67_ = NULL;
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp67_ = boxes_collection_source_get_uri (_data_->_tmp66_);
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp68_ = NULL;
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp68_ = _data_->_tmp67_;
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp69_ = NULL;
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp69_ = _data_->_tmp68_;
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp70_ = NULL;
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp71_ = NULL;
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						spice_validate_uri (_data_->_tmp69_, &_data_->_tmp70_, &_data_->_tmp71_, &_data_->_inner_error_);
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp72_ = NULL;
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp72_ = _data_->_tmp70_;
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->port = *_data_->_tmp72_;
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp73_ = NULL;
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp73_ = _data_->_tmp71_;
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->tls_port = *_data_->_tmp73_;
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_g_free0 (_data_->_tmp73_);
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_g_free0 (_data_->_tmp72_);
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_g_free0 (_data_->_tmp69_);
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							if (_data_->_inner_error_->domain == BOXES_ERROR) {
#line 4312 "wizard.c"
								goto __catch119_boxes_error;
							}
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_xmlFreeURI0 (_data_->uri);
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							g_clear_error (&_data_->_inner_error_);
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							return FALSE;
#line 4323 "wizard.c"
						}
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp74_ = 0;
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp74_ = _data_->port;
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						if (_data_->_tmp74_ > 0) {
#line 491 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp75_ = NULL;
#line 491 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp75_ = _data_->self->priv->summary;
#line 491 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp76_ = NULL;
#line 491 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp76_ = _ ("Port");
#line 491 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp77_ = 0;
#line 491 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp77_ = _data_->port;
#line 491 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp78_ = NULL;
#line 491 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp78_ = g_strdup_printf ("%i", _data_->_tmp77_);
#line 491 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp79_ = NULL;
#line 491 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp79_ = _data_->_tmp78_;
#line 491 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							boxes_wizard_summary_add_property (_data_->_tmp75_, _data_->_tmp76_, _data_->_tmp79_);
#line 491 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_g_free0 (_data_->_tmp79_);
#line 4355 "wizard.c"
						}
#line 492 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp80_ = 0;
#line 492 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp80_ = _data_->tls_port;
#line 492 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						if (_data_->_tmp80_ > 0) {
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp81_ = NULL;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp81_ = _data_->self->priv->summary;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp82_ = NULL;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp82_ = _ ("TLS Port");
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp83_ = 0;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp83_ = _data_->tls_port;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp84_ = NULL;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp84_ = g_strdup_printf ("%i", _data_->_tmp83_);
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp85_ = NULL;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp85_ = _data_->_tmp84_;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							boxes_wizard_summary_add_property (_data_->_tmp81_, _data_->_tmp82_, _data_->_tmp85_);
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_g_free0 (_data_->_tmp85_);
#line 4387 "wizard.c"
						}
					}
					goto __finally119;
					__catch119_boxes_error:
					{
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_vala2__error_ = _data_->_inner_error_;
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_inner_error_ = NULL;
#line 496 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp86_ = NULL;
#line 496 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp86_ = _data_->_vala2__error_;
#line 496 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp87_ = NULL;
#line 496 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp87_ = _data_->_tmp86_->message;
#line 496 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						g_critical ("wizard.vala:496: %s", _data_->_tmp87_);
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_g_error_free0 (_data_->_vala2__error_);
#line 4409 "wizard.c"
					}
					__finally119:
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_xmlFreeURI0 (_data_->uri);
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						g_clear_error (&_data_->_inner_error_);
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						return FALSE;
#line 4422 "wizard.c"
					}
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					break;
#line 4426 "wizard.c"
				}
			}
		} else if (_data_->_tmp65_ == ((0 != _tmp64_label1) ? _tmp64_label1 : (_tmp64_label1 = g_quark_from_static_string ("vnc")))) {
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			switch (0) {
#line 4432 "wizard.c"
				default:
				{
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp88_ = NULL;
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp88_ = _data_->uri;
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp89_ = 0;
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp89_ = _data_->_tmp88_->port;
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					if (_data_->_tmp89_ > 0) {
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp90_ = NULL;
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp90_ = _data_->self->priv->summary;
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp91_ = NULL;
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp91_ = _ ("Port");
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp92_ = NULL;
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp92_ = _data_->uri;
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp93_ = 0;
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp93_ = _data_->_tmp92_->port;
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp94_ = NULL;
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp94_ = g_strdup_printf ("%i", _data_->_tmp93_);
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp95_ = NULL;
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp95_ = _data_->_tmp94_;
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						boxes_wizard_summary_add_property (_data_->_tmp90_, _data_->_tmp91_, _data_->_tmp95_);
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_g_free0 (_data_->_tmp95_);
#line 4473 "wizard.c"
					}
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					break;
#line 4477 "wizard.c"
				}
			}
		}
#line 506 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp96_ = NULL;
#line 506 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp96_ = boxes_app_app;
#line 506 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp97_ = NULL;
#line 506 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp97_ = _data_->self->priv->source;
#line 506 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp98_ = NULL;
#line 506 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp98_ = boxes_collection_source_get_source_type (_data_->_tmp97_);
#line 506 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp99_ = NULL;
#line 506 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp99_ = _data_->_tmp98_;
#line 506 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp100_ = NULL;
#line 506 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp100_ = _data_->_tmp99_;
#line 506 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp101_ = FALSE;
#line 506 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp101_ = boxes_app_has_broker_for_source_type (_data_->_tmp96_, _data_->_tmp100_);
#line 506 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp102_ = FALSE;
#line 506 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp102_ = _data_->_tmp101_;
#line 506 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_free0 (_data_->_tmp100_);
#line 506 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp102_) {
#line 507 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp103_ = NULL;
#line 507 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp103_ = _data_->self->priv->review_label;
#line 507 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp104_ = NULL;
#line 507 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp104_ = _ ("Will add boxes for all systems available from this account:");
#line 507 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			gtk_label_set_text (_data_->_tmp103_, _data_->_tmp104_);
#line 4523 "wizard.c"
		}
#line 474 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_xmlFreeURI0 (_data_->uri);
#line 4527 "wizard.c"
	} else {
#line 509 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp105_ = NULL;
#line 509 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp105_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 509 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp106_ = NULL;
#line 509 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp106_ = _data_->_tmp105_;
#line 509 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp106_ != NULL) {
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp107_ = NULL;
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp107_ = _data_->self->priv->vm_creator;
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp108_ = NULL;
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp108_ = boxes_vm_creator_get_install_media (_data_->_tmp107_);
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp109_ = NULL;
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp109_ = _data_->_tmp108_;
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp110_ = NULL;
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp110_ = boxes_installer_media_get_vm_properties (_data_->_tmp109_);
#line 4555 "wizard.c"
			{
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->property_collection = _data_->_tmp110_;
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				for (_data_->property_it = _data_->property_collection; _data_->property_it != NULL; _data_->property_it = _data_->property_it->next) {
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp111_ = NULL;
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp111_ = _boxes_pair_ref0 ((BoxesPair*) _data_->property_it->data);
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->property = _data_->_tmp111_;
#line 4567 "wizard.c"
					{
#line 511 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp112_ = NULL;
#line 511 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp112_ = _data_->self->priv->summary;
#line 511 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp113_ = NULL;
#line 511 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp113_ = _data_->property;
#line 511 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp114_ = NULL;
#line 511 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp114_ = _data_->_tmp113_->first;
#line 511 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp115_ = NULL;
#line 511 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp115_ = _data_->property;
#line 511 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp116_ = NULL;
#line 511 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp116_ = _data_->_tmp115_->second;
#line 511 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						boxes_wizard_summary_add_property (_data_->_tmp112_, (const gchar*) _data_->_tmp114_, (const gchar*) _data_->_tmp116_);
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_boxes_pair_unref0 (_data_->property);
#line 4593 "wizard.c"
					}
				}
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				__g_list_free__boxes_pair_unref0_0 (_data_->property_collection);
#line 4598 "wizard.c"
			}
			{
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_data87_ = g_slice_new0 (Block87Data);
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_data87_->_ref_count_ = 1;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_data87_->self = g_object_ref (_data_->self);
#line 514 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp117_ = NULL;
#line 514 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp117_ = NULL;
#line 514 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp118_ = NULL;
#line 514 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp118_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_data_->_tmp117_, gvir_config_domain_get_type ()) ? ((GVirConfigDomain*) _data_->_tmp117_) : NULL);
#line 514 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_data87_->config = _data_->_tmp118_;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_state_ = 2;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_run_in_thread (______lambda174__boxes_run_in_thread_func, block87_data_ref (_data_->_data87_), block87_data_unref, boxes_wizard_do_review_cancellable_ready, _data_);
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				return FALSE;
#line 4623 "wizard.c"
				_state_2:
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_run_in_thread_finish (_data_->_res_, &_data_->_inner_error_);
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					block87_data_unref (_data_->_data87_);
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_data87_ = NULL;
#line 4633 "wizard.c"
					goto __catch120_g_error;
				}
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp119_ = NULL;
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp119_ = _data_->_data87_->config;
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp120_ = 0ULL;
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp120_ = gvir_config_domain_get_memory (_data_->_tmp119_);
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp121_ = 0ULL;
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp121_ = _data_->_tmp120_;
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp122_ = NULL;
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp122_ = g_format_size_full (_data_->_tmp121_ * OSINFO_KIBIBYTES, G_FORMAT_SIZE_IEC_UNITS);
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->memory = _data_->_tmp122_;
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp123_ = NULL;
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp123_ = _data_->self->priv->summary;
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp124_ = NULL;
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp124_ = _ ("Memory");
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp125_ = NULL;
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp125_ = _data_->memory;
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_wizard_summary_add_property (_data_->_tmp123_, _data_->_tmp124_, _data_->_tmp125_);
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_free0 (_data_->memory);
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				block87_data_unref (_data_->_data87_);
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_data87_ = NULL;
#line 4674 "wizard.c"
			}
			goto __finally120;
			__catch120_g_error:
			{
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_vala3__error_ = _data_->_inner_error_;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_inner_error_ = NULL;
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp126_ = NULL;
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp126_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp127_ = NULL;
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp127_ = _data_->_tmp126_;
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp128_ = NULL;
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp128_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->_tmp127_);
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp129_ = NULL;
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp129_ = _data_->_tmp128_;
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp130_ = NULL;
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp130_ = _data_->_vala3__error_;
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp131_ = NULL;
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp131_ = _data_->_tmp130_->message;
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_warning ("wizard.vala:522: Failed to get configuration for machine '%s': %s", _data_->_tmp129_, _data_->_tmp131_);
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_error_free0 (_data_->_vala3__error_);
#line 4711 "wizard.c"
			}
			__finally120:
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_clear_error (&_data_->_inner_error_);
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				return FALSE;
#line 4722 "wizard.c"
			}
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp133_ = NULL;
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp133_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp134_ = NULL;
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp134_ = _data_->_tmp133_;
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp135_ = FALSE;
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp135_ = boxes_libvirt_machine_get_importing (_data_->_tmp134_);
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp136_ = FALSE;
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp136_ = _data_->_tmp135_;
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (!_data_->_tmp136_) {
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp137_ = NULL;
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp137_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp138_ = NULL;
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp138_ = _data_->_tmp137_;
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp139_ = NULL;
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp139_ = boxes_libvirt_machine_get_storage_volume (_data_->_tmp138_);
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp140_ = NULL;
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp140_ = _data_->_tmp139_;
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp132_ = _data_->_tmp140_ != NULL;
#line 4760 "wizard.c"
			} else {
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp132_ = FALSE;
#line 4764 "wizard.c"
			}
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (_data_->_tmp132_) {
#line 4768 "wizard.c"
				{
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp141_ = NULL;
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp141_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp142_ = NULL;
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp142_ = _data_->_tmp141_;
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp143_ = NULL;
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp143_ = boxes_libvirt_machine_get_storage_volume (_data_->_tmp142_);
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp144_ = NULL;
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp144_ = _data_->_tmp143_;
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp145_ = NULL;
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp145_ = gvir_storage_vol_get_info (_data_->_tmp144_, &_data_->_inner_error_);
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->volume_info = _data_->_tmp145_;
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 4794 "wizard.c"
						goto __catch121_g_error;
					}
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp146_ = NULL;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp146_ = _data_->volume_info;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp147_ = 0ULL;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp147_ = _data_->_tmp146_->capacity;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp148_ = NULL;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp148_ = g_format_size_full (_data_->_tmp147_, G_FORMAT_SIZE_DEFAULT);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->capacity = _data_->_tmp148_;
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp149_ = NULL;
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp149_ = _data_->self->priv->summary;
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp150_ = NULL;
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp150_ = _ ("Disk");
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp151_ = NULL;
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp151_ = _data_->capacity;
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp152_ = NULL;
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp152_ = g_strdup_printf ("%s maximum", _data_->_tmp151_);
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp153_ = NULL;
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp153_ = _data_->_tmp152_;
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp154_ = NULL;
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp154_ = _ (_data_->_tmp153_);
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					boxes_wizard_summary_add_property (_data_->_tmp149_, _data_->_tmp150_, _data_->_tmp154_);
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_g_free0 (_data_->_tmp153_);
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_g_free0 (_data_->capacity);
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					__vala_GVirStorageVolInfo_free0 (_data_->volume_info);
#line 4843 "wizard.c"
				}
				goto __finally121;
				__catch121_g_error:
				{
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_vala4__error_ = _data_->_inner_error_;
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_inner_error_ = NULL;
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp155_ = NULL;
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp155_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp156_ = NULL;
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp156_ = _data_->_tmp155_;
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp157_ = NULL;
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp157_ = boxes_libvirt_machine_get_storage_volume (_data_->_tmp156_);
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp158_ = NULL;
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp158_ = _data_->_tmp157_;
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp159_ = NULL;
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp159_ = gvir_storage_vol_get_name (_data_->_tmp158_);
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp160_ = NULL;
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp160_ = _data_->_vala4__error_;
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp161_ = NULL;
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp161_ = _data_->_tmp160_->message;
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					g_warning ("wizard.vala:531: Failed to get information on volume '%s': %s", _data_->_tmp159_, _data_->_tmp161_);
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_g_error_free0 (_data_->_vala4__error_);
#line 4884 "wizard.c"
				}
				__finally121:
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					g_clear_error (&_data_->_inner_error_);
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					return FALSE;
#line 4895 "wizard.c"
				}
			}
#line 537 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp162_ = NULL;
#line 537 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp162_ = _data_->self->priv->nokvm_infobar;
#line 537 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp163_ = NULL;
#line 537 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp163_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 537 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp164_ = NULL;
#line 537 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp164_ = _data_->_tmp163_;
#line 537 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp165_ = NULL;
#line 537 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp165_ = boxes_libvirt_machine_get_domain_config (_data_->_tmp164_);
#line 537 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp166_ = NULL;
#line 537 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp166_ = _data_->_tmp165_;
#line 537 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp167_ = 0;
#line 537 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp167_ = gvir_config_domain_get_virt_type (_data_->_tmp166_);
#line 537 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			gtk_widget_set_visible ((GtkWidget*) _data_->_tmp162_, _data_->_tmp167_ != GVIR_CONFIG_DOMAIN_VIRT_KVM);
#line 4924 "wizard.c"
		} else {
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp168_ = NULL;
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp168_ = _data_->self->priv->wizard_source;
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp169_ = FALSE;
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp169_ = _data_->_tmp168_->libvirt_sys_import;
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (_data_->_tmp169_) {
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp170_ = NULL;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp170_ = _data_->self->priv->review_label;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp171_ = NULL;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp171_ = _data_->self->priv->wizard_source;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp172_ = NULL;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp172_ = boxes_wizard_source_get_libvirt_sys_importer (_data_->_tmp171_);
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp173_ = NULL;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp173_ = _data_->_tmp172_;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp174_ = NULL;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp174_ = boxes_libvirt_system_importer_get_wizard_review_label (_data_->_tmp173_);
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp175_ = NULL;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp175_ = _data_->_tmp174_;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp176_ = NULL;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp176_ = _data_->_tmp175_;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				gtk_label_set_text (_data_->_tmp170_, _data_->_tmp176_);
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_free0 (_data_->_tmp176_);
#line 4968 "wizard.c"
			}
		}
	}
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp177_ = NULL;
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp177_ = _data_->self->priv->_machine;
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_tmp177_ != NULL) {
#line 543 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp178_ = NULL;
#line 543 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp178_ = _data_->self->priv->summary;
#line 543 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_summary_append_customize_button (_data_->_tmp178_, ____lambda175__boxes_wizard_summary_customize_func, _data_->self);
#line 4984 "wizard.c"
	}
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->result = TRUE;
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_state_ == 0) {
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4992 "wizard.c"
	} else {
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4996 "wizard.c"
	}
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_unref (_data_->_async_result);
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_state_ == 0) {
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5006 "wizard.c"
	} else {
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 5010 "wizard.c"
	}
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_unref (_data_->_async_result);
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 5016 "wizard.c"
}


static gboolean boxes_wizard_skip_page (BoxesWizard* self, BoxesWizardPage page) {
	gboolean result = FALSE;
	gboolean forwards = FALSE;
	BoxesWizardPage _tmp0_ = 0;
	BoxesWizardPage _tmp1_ = 0;
	BoxesWizardPage _tmp2_ = 0;
	BoxesWizardPage skip_to = 0;
	BoxesWizardPage _tmp3_ = 0;
	gboolean _tmp4_ = FALSE;
	BoxesCollectionSource* _tmp5_ = NULL;
	gboolean _tmp12_ = FALSE;
	gboolean _tmp13_ = FALSE;
	BoxesVMCreator* _tmp16_ = NULL;
	BoxesWizardPage _tmp52_ = 0;
	BoxesWizardPage _tmp53_ = 0;
#line 551 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 552 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = page;
#line 552 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = boxes_wizard_get_page (self);
#line 552 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = _tmp1_;
#line 552 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	forwards = _tmp0_ > _tmp2_;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = page;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	skip_to = _tmp3_;
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp5_ = self->priv->source;
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp5_ != NULL) {
#line 5053 "wizard.c"
		BoxesWizardPage _tmp6_ = 0;
		BoxesWizardPage _tmp7_ = 0;
#line 557 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp6_ = page;
#line 557 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp7_ = _tmp6_;
#line 557 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp4_ = (BOXES_WIZARD_PAGE_SOURCE < _tmp7_) && (_tmp7_ < BOXES_WIZARD_PAGE_REVIEW);
#line 5062 "wizard.c"
	} else {
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp4_ = FALSE;
#line 5066 "wizard.c"
	}
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp4_) {
#line 5070 "wizard.c"
		BoxesWizardPage _tmp8_ = 0;
		gboolean _tmp9_ = FALSE;
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp9_ = forwards;
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_tmp9_) {
#line 5077 "wizard.c"
			BoxesWizardPage _tmp10_ = 0;
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp10_ = page;
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp8_ = _tmp10_ + 1;
#line 5083 "wizard.c"
		} else {
			BoxesWizardPage _tmp11_ = 0;
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp11_ = page;
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp8_ = _tmp11_ - 1;
#line 5090 "wizard.c"
		}
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		skip_to = _tmp8_;
#line 5094 "wizard.c"
	}
#line 561 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp13_ = forwards;
#line 561 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (!_tmp13_) {
#line 5100 "wizard.c"
		BoxesWizardPage _tmp14_ = 0;
#line 562 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp14_ = page;
#line 562 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp12_ = _tmp14_ == BOXES_WIZARD_PAGE_PREPARATION;
#line 5106 "wizard.c"
	} else {
#line 561 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp12_ = FALSE;
#line 5110 "wizard.c"
	}
#line 561 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp12_) {
#line 5114 "wizard.c"
		BoxesWizardPage _tmp15_ = 0;
#line 563 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp15_ = page;
#line 563 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		skip_to = _tmp15_ - 1;
#line 5120 "wizard.c"
	}
#line 565 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp16_ = self->priv->vm_creator;
#line 565 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp16_ != NULL) {
#line 5126 "wizard.c"
		gboolean _tmp17_ = FALSE;
		BoxesWizardPage _tmp18_ = 0;
		gboolean _tmp28_ = FALSE;
		gboolean _tmp29_ = FALSE;
		gboolean _tmp30_ = FALSE;
		BoxesWizardPage _tmp31_ = 0;
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp18_ = page;
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_tmp18_ == BOXES_WIZARD_PAGE_SETUP) {
#line 5137 "wizard.c"
			BoxesVMCreator* _tmp19_ = NULL;
			BoxesInstallerMedia* _tmp20_ = NULL;
			BoxesInstallerMedia* _tmp21_ = NULL;
			gboolean _tmp22_ = FALSE;
			gboolean _tmp23_ = FALSE;
#line 568 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp19_ = self->priv->vm_creator;
#line 568 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp20_ = boxes_vm_creator_get_install_media (_tmp19_);
#line 568 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp21_ = _tmp20_;
#line 568 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp22_ = boxes_installer_media_get_need_user_input_for_vm_creation (_tmp21_);
#line 568 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp23_ = _tmp22_;
#line 568 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp17_ = !_tmp23_;
#line 5155 "wizard.c"
		} else {
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp17_ = FALSE;
#line 5159 "wizard.c"
		}
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_tmp17_) {
#line 5163 "wizard.c"
			BoxesWizardPage _tmp24_ = 0;
			gboolean _tmp25_ = FALSE;
#line 569 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp25_ = forwards;
#line 569 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (_tmp25_) {
#line 5170 "wizard.c"
				BoxesWizardPage _tmp26_ = 0;
#line 569 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp26_ = page;
#line 569 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp24_ = _tmp26_ + 1;
#line 5176 "wizard.c"
			} else {
				BoxesWizardPage _tmp27_ = 0;
#line 569 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp27_ = page;
#line 569 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp24_ = _tmp27_ - 1;
#line 5183 "wizard.c"
			}
#line 569 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			skip_to = _tmp24_;
#line 5187 "wizard.c"
		}
#line 572 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp31_ = page;
#line 572 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_tmp31_ == BOXES_WIZARD_PAGE_REVIEW) {
#line 5193 "wizard.c"
			gboolean _tmp32_ = FALSE;
#line 572 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp32_ = forwards;
#line 572 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp30_ = _tmp32_;
#line 5199 "wizard.c"
		} else {
#line 572 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp30_ = FALSE;
#line 5203 "wizard.c"
		}
#line 572 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_tmp30_) {
#line 5207 "wizard.c"
			BoxesVMCreator* _tmp33_ = NULL;
			BoxesInstallerMedia* _tmp34_ = NULL;
			BoxesInstallerMedia* _tmp35_ = NULL;
			gboolean _tmp36_ = FALSE;
			gboolean _tmp37_ = FALSE;
#line 573 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp33_ = self->priv->vm_creator;
#line 573 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp34_ = boxes_vm_creator_get_install_media (_tmp33_);
#line 573 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp35_ = _tmp34_;
#line 573 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp36_ = boxes_installer_media_get_live (_tmp35_);
#line 573 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp37_ = _tmp36_;
#line 573 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp29_ = _tmp37_;
#line 5225 "wizard.c"
		} else {
#line 572 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp29_ = FALSE;
#line 5229 "wizard.c"
		}
#line 572 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_tmp29_) {
#line 5233 "wizard.c"
			gboolean _tmp38_ = FALSE;
#line 574 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp38_ = self->priv->skip_review_for_live;
#line 574 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp28_ = _tmp38_;
#line 5239 "wizard.c"
		} else {
#line 572 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp28_ = FALSE;
#line 5243 "wizard.c"
		}
#line 572 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_tmp28_) {
#line 5247 "wizard.c"
			BoxesWizardPage _tmp39_ = 0;
#line 575 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp39_ = skip_to;
#line 575 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			skip_to = _tmp39_ + 1;
#line 5253 "wizard.c"
		}
	} else {
		BoxesWizardSource* _tmp40_ = NULL;
		gboolean _tmp41_ = FALSE;
#line 576 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp40_ = self->priv->wizard_source;
#line 576 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp41_ = _tmp40_->libvirt_sys_import;
#line 576 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_tmp41_) {
#line 5264 "wizard.c"
			BoxesWizardPage _tmp42_ = 0;
#line 577 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp42_ = page;
#line 577 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (_tmp42_ == BOXES_WIZARD_PAGE_PREPARATION) {
#line 5270 "wizard.c"
				BoxesWizardPage _tmp43_ = 0;
				gboolean _tmp44_ = FALSE;
#line 578 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp44_ = forwards;
#line 578 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (_tmp44_) {
#line 5277 "wizard.c"
					BoxesWizardPage _tmp45_ = 0;
#line 578 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp45_ = page;
#line 578 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp43_ = _tmp45_ + 2;
#line 5283 "wizard.c"
				} else {
					BoxesWizardPage _tmp46_ = 0;
#line 578 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp46_ = page;
#line 578 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp43_ = _tmp46_ - 1;
#line 5290 "wizard.c"
				}
#line 578 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				skip_to = _tmp43_;
#line 5294 "wizard.c"
			} else {
				BoxesWizardPage _tmp47_ = 0;
#line 579 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp47_ = page;
#line 579 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (_tmp47_ == BOXES_WIZARD_PAGE_SETUP) {
#line 5301 "wizard.c"
					BoxesWizardPage _tmp48_ = 0;
					gboolean _tmp49_ = FALSE;
#line 580 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp49_ = forwards;
#line 580 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					if (_tmp49_) {
#line 5308 "wizard.c"
						BoxesWizardPage _tmp50_ = 0;
#line 580 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_tmp50_ = page;
#line 580 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_tmp48_ = _tmp50_ + 1;
#line 5314 "wizard.c"
					} else {
						BoxesWizardPage _tmp51_ = 0;
#line 580 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_tmp51_ = page;
#line 580 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_tmp48_ = _tmp51_ - 2;
#line 5321 "wizard.c"
					}
#line 580 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					skip_to = _tmp48_;
#line 5325 "wizard.c"
				}
			}
		}
	}
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp52_ = skip_to;
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp53_ = page;
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp52_ != _tmp53_) {
#line 5336 "wizard.c"
		BoxesWizardPage _tmp54_ = 0;
#line 584 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp54_ = skip_to;
#line 584 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_page (self, _tmp54_);
#line 585 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		result = TRUE;
#line 585 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		return result;
#line 5346 "wizard.c"
	}
#line 588 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	result = FALSE;
#line 588 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return result;
#line 5352 "wizard.c"
}


static void boxes_wizard_download_media_data_free (gpointer _data) {
	BoxesWizardDownloadMediaData* _data_;
	_data_ = _data;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_free0 (_data_->uri);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->progress);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->self);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_slice_free (BoxesWizardDownloadMediaData, _data_);
#line 5367 "wizard.c"
}


static void boxes_wizard_download_media (BoxesWizard* self, const gchar* uri, BoxesActivityProgress* progress, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesWizardDownloadMediaData* _data_;
	BoxesWizard* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	BoxesActivityProgress* _tmp3_ = NULL;
	BoxesActivityProgress* _tmp4_ = NULL;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_ = g_slice_new0 (BoxesWizardDownloadMediaData);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_wizard_download_media);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_wizard_download_media_data_free);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->self = _tmp0_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = uri;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_free0 (_data_->uri);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->uri = _tmp2_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = progress;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->progress);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->progress = _tmp4_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_download_media_co (_data_);
#line 5406 "wizard.c"
}


static void boxes_wizard_download_media_finish (BoxesWizard* self, GAsyncResult* _res_) {
	BoxesWizardDownloadMediaData* _data_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 5414 "wizard.c"
}


static void boxes_wizard_download_media_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesWizardDownloadMediaData* _data_;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_ = _user_data_;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_source_object_ = source_object;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_res_ = _res_;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_download_media_co (_data_);
#line 5428 "wizard.c"
}


static gboolean boxes_wizard_download_media_co (BoxesWizardDownloadMediaData* _data_) {
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	switch (_data_->_state_) {
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case 0:
#line 5437 "wizard.c"
		goto _state_0;
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case 1:
#line 5441 "wizard.c"
		goto _state_1;
		default:
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_assert_not_reached ();
#line 5446 "wizard.c"
	}
	_state_0:
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp0_ = NULL;
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp0_ = _data_->progress;
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp1_ = NULL;
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp1_ = boxes_activity_progress_add_child_activity (_data_->_tmp0_, BOXES_WIZARD_DOWNLOAD_PROGRESS_SCALE);
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->download_progress = _data_->_tmp1_;
#line 593 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp2_ = NULL;
#line 593 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp2_ = _data_->self->priv->prep_status_label;
#line 593 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp3_ = NULL;
#line 593 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp3_ = _ ("Downloading media…");
#line 593 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_label_set_label (_data_->_tmp2_, _data_->_tmp3_);
#line 5469 "wizard.c"
	{
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp4_ = NULL;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp4_ = _data_->uri;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp5_ = NULL;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp5_ = _data_->download_progress;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp6_ = NULL;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp6_ = _data_->self->priv->prepare_cancellable;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_state_ = 1;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_downloader_fetch_media (_data_->_tmp4_, _data_->_tmp5_, _data_->_tmp6_, boxes_wizard_download_media_ready, _data_);
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		return FALSE;
#line 5489 "wizard.c"
		_state_1:
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp7_ = NULL;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp7_ = boxes_downloader_fetch_media_finish (_data_->_res_, &_data_->_inner_error_);
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->cache_path = _data_->_tmp7_;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (g_error_matches (_data_->_inner_error_, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
#line 5501 "wizard.c"
				goto __catch122_g_io_error_cancelled;
			}
			goto __catch122_g_error;
		}
#line 597 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp8_ = NULL;
#line 597 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp8_ = _data_->cache_path;
#line 597 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp9_ = NULL;
#line 597 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp9_ = _data_->progress;
#line 597 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_prepare_downloaded_media (_data_->self, _data_->_tmp8_, _data_->_tmp9_);
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_free0 (_data_->cache_path);
#line 5518 "wizard.c"
	}
	goto __finally122;
	__catch122_g_io_error_cancelled:
	{
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->e = _data_->_inner_error_;
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_inner_error_ = NULL;
#line 599 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp10_ = NULL;
#line 599 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp10_ = _data_->uri;
#line 599 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_debug ("wizard.vala:599: Cancelled downloading media '%s'!", _data_->_tmp10_);
#line 600 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_page (_data_->self, BOXES_WIZARD_PAGE_SOURCE);
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_error_free0 (_data_->e);
#line 5537 "wizard.c"
	}
	goto __finally122;
	__catch122_g_error:
	{
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_vala1_e = _data_->_inner_error_;
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_inner_error_ = NULL;
#line 602 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp11_ = NULL;
#line 602 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp11_ = _data_->uri;
#line 602 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp12_ = NULL;
#line 602 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp12_ = _data_->_vala1_e;
#line 602 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp13_ = NULL;
#line 602 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp13_ = _data_->_tmp12_->message;
#line 602 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_warning ("wizard.vala:602: Failed downloading media '%s'! %s", _data_->_tmp11_, _data_->_tmp13_);
#line 603 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp14_ = NULL;
#line 603 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp14_ = _data_->self->priv->window;
#line 603 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp15_ = NULL;
#line 603 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp15_ = _data_->_tmp14_->notificationbar;
#line 603 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp16_ = NULL;
#line 603 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp16_ = _ ("Download failed.");
#line 603 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp17_ = NULL;
#line 603 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp17_ = boxes_notificationbar_display_error (_data_->_tmp15_, _data_->_tmp16_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 603 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp18_ = NULL;
#line 603 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp18_ = _data_->_tmp17_;
#line 603 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_data_->_tmp18_);
#line 604 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_page (_data_->self, BOXES_WIZARD_PAGE_SOURCE);
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_error_free0 (_data_->_vala1_e);
#line 5586 "wizard.c"
	}
	__finally122:
	{
#line 606 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_data_->self->priv->prepare_cancellable);
#line 606 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->self->priv->prepare_cancellable = NULL;
#line 5594 "wizard.c"
	}
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_data_->download_progress);
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_clear_error (&_data_->_inner_error_);
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		return FALSE;
#line 5606 "wizard.c"
	}
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->download_progress);
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_state_ == 0) {
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5614 "wizard.c"
	} else {
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 5618 "wizard.c"
	}
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_unref (_data_->_async_result);
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 5624 "wizard.c"
}


static void boxes_wizard_prepare_downloaded_media (BoxesWizard* self, const gchar* cache_path, BoxesActivityProgress* progress) {
	BoxesWizardSource* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	BoxesActivityProgress* _tmp4_ = NULL;
#line 610 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 610 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (cache_path != NULL);
#line 610 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (progress != NULL);
#line 611 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_cleanup (self);
#line 614 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->wizard_source;
#line 614 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = cache_path;
#line 614 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = g_strconcat ("file://", _tmp1_, NULL);
#line 614 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = _tmp2_;
#line 614 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_source_set_uri (_tmp0_, _tmp3_);
#line 614 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_free0 (_tmp3_);
#line 615 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = progress;
#line 615 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_prepare (self, _tmp4_);
#line 5658 "wizard.c"
}


static Block88Data* block88_data_ref (Block88Data* _data88_) {
#line 618 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_atomic_int_inc (&_data88_->_ref_count_);
#line 618 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return _data88_;
#line 5667 "wizard.c"
}


static void block88_data_unref (void * _userdata_) {
	Block88Data* _data88_;
	_data88_ = (Block88Data*) _userdata_;
#line 618 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (g_atomic_int_dec_and_test (&_data88_->_ref_count_)) {
#line 5676 "wizard.c"
		BoxesWizard* self;
#line 618 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		self = _data88_->self;
#line 618 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_data88_->window);
#line 618 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (self);
#line 618 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_slice_free (Block88Data, _data88_);
#line 5686 "wizard.c"
	}
}


static void __lambda179_ (Block88Data* _data88_) {
	BoxesWizard* self;
	BoxesWizardSource* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
#line 622 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = _data88_->self;
#line 623 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_cleanup (self);
#line 624 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->wizard_source;
#line 624 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_source_set_page (_tmp0_, BOXES_SOURCE_PAGE_MAIN);
#line 625 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = _data88_->window;
#line 625 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_ui_set_state ((BoxesUI*) _tmp1_, BOXES_UI_STATE_COLLECTION);
#line 5707 "wizard.c"
}


static void ___lambda179__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 622 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	__lambda179_ (self);
#line 5714 "wizard.c"
}


static void __lambda180_ (BoxesWizard* self) {
	GCancellable* _tmp0_ = NULL;
	BoxesWizardPage _tmp2_ = 0;
	BoxesWizardPage _tmp3_ = 0;
#line 629 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->prepare_cancellable;
#line 629 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp0_ != NULL) {
#line 5726 "wizard.c"
		GCancellable* _tmp1_ = NULL;
#line 630 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp1_ = self->priv->prepare_cancellable;
#line 630 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_cancellable_cancel (_tmp1_);
#line 5732 "wizard.c"
	}
#line 632 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = boxes_wizard_get_page (self);
#line 632 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = _tmp2_;
#line 632 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_page (self, _tmp3_ - 1);
#line 5740 "wizard.c"
}


static void ___lambda180__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 628 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	__lambda180_ ((BoxesWizard*) self);
#line 5747 "wizard.c"
}


static void __lambda181_ (BoxesWizard* self) {
	BoxesWizardPage _tmp0_ = 0;
	BoxesWizardPage _tmp1_ = 0;
#line 636 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = boxes_wizard_get_page (self);
#line 636 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = _tmp0_;
#line 636 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_page (self, _tmp1_ + 1);
#line 5760 "wizard.c"
}


static void ___lambda181__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	__lambda181_ ((BoxesWizard*) self);
#line 5767 "wizard.c"
}


static void __lambda182_ (BoxesWizard* self) {
#line 640 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_page (self, BOXES_WIZARD_PAGE_LAST);
#line 5774 "wizard.c"
}


static void ___lambda182__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 639 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	__lambda182_ ((BoxesWizard*) self);
#line 5781 "wizard.c"
}


void boxes_wizard_setup_ui (BoxesWizard* self, BoxesAppWindow* window) {
	Block88Data* _data88_;
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
	BoxesAppWindow* _tmp2_ = NULL;
	BoxesAppWindow* _tmp3_ = NULL;
	BoxesAppWindow* _tmp4_ = NULL;
	BoxesTopbar* _tmp5_ = NULL;
	BoxesWizardToolbar* _tmp6_ = NULL;
	GtkButton* _tmp7_ = NULL;
	GtkButton* _tmp8_ = NULL;
	GtkButton* _tmp9_ = NULL;
	BoxesAppWindow* _tmp10_ = NULL;
	BoxesTopbar* _tmp11_ = NULL;
	BoxesWizardToolbar* _tmp12_ = NULL;
	GtkButton* _tmp13_ = NULL;
	GtkButton* _tmp14_ = NULL;
	GtkButton* _tmp15_ = NULL;
	BoxesAppWindow* _tmp16_ = NULL;
	BoxesTopbar* _tmp17_ = NULL;
	BoxesWizardToolbar* _tmp18_ = NULL;
	GtkButton* _tmp19_ = NULL;
	GtkButton* _tmp20_ = NULL;
	GtkButton* _tmp21_ = NULL;
	BoxesAppWindow* _tmp22_ = NULL;
	BoxesTopbar* _tmp23_ = NULL;
	BoxesWizardToolbar* _tmp24_ = NULL;
	GtkButton* _tmp25_ = NULL;
	GtkButton* _tmp26_ = NULL;
	GtkButton* _tmp27_ = NULL;
	BoxesWizardSource* _tmp28_ = NULL;
	BoxesAppWindow* _tmp29_ = NULL;
#line 618 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 618 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (window != NULL);
#line 618 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data88_ = g_slice_new0 (Block88Data);
#line 618 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data88_->_ref_count_ = 1;
#line 618 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data88_->self = g_object_ref (self);
#line 618 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = window;
#line 618 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 618 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data88_->window);
#line 618 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data88_->window = _tmp1_;
#line 619 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = _data88_->window;
#line 619 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 619 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->window);
#line 619 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->window = _tmp3_;
#line 621 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = _data88_->window;
#line 621 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp5_ = _tmp4_->topbar;
#line 621 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp6_ = _tmp5_->wizard_toolbar;
#line 621 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp7_ = _tmp6_->cancel_btn;
#line 621 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp8_ = _g_object_ref0 (_tmp7_);
#line 621 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->cancel_button);
#line 621 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->cancel_button = _tmp8_;
#line 622 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp9_ = self->priv->cancel_button;
#line 622 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_signal_connect_data (_tmp9_, "clicked", (GCallback) ___lambda179__gtk_button_clicked, block88_data_ref (_data88_), (GClosureNotify) block88_data_unref, 0);
#line 627 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp10_ = _data88_->window;
#line 627 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp11_ = _tmp10_->topbar;
#line 627 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp12_ = _tmp11_->wizard_toolbar;
#line 627 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp13_ = _tmp12_->back_btn;
#line 627 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp14_ = _g_object_ref0 (_tmp13_);
#line 627 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->back_button);
#line 627 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->back_button = _tmp14_;
#line 628 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp15_ = self->priv->back_button;
#line 628 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_signal_connect_object (_tmp15_, "clicked", (GCallback) ___lambda180__gtk_button_clicked, self, 0);
#line 634 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp16_ = _data88_->window;
#line 634 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp17_ = _tmp16_->topbar;
#line 634 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp18_ = _tmp17_->wizard_toolbar;
#line 634 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp19_ = _tmp18_->continue_btn;
#line 634 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp20_ = _g_object_ref0 (_tmp19_);
#line 634 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->continue_button);
#line 634 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->continue_button = _tmp20_;
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp21_ = self->priv->continue_button;
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_signal_connect_object (_tmp21_, "clicked", (GCallback) ___lambda181__gtk_button_clicked, self, 0);
#line 638 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp22_ = _data88_->window;
#line 638 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp23_ = _tmp22_->topbar;
#line 638 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp24_ = _tmp23_->wizard_toolbar;
#line 638 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp25_ = _tmp24_->create_btn;
#line 638 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp26_ = _g_object_ref0 (_tmp25_);
#line 638 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->create_button);
#line 638 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->create_button = _tmp26_;
#line 639 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp27_ = self->priv->create_button;
#line 639 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_signal_connect_object (_tmp27_, "clicked", (GCallback) ___lambda182__gtk_button_clicked, self, 0);
#line 643 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp28_ = self->priv->wizard_source;
#line 643 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp29_ = _data88_->window;
#line 643 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_source_setup_ui (_tmp28_, _tmp29_);
#line 618 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	block88_data_unref (_data88_);
#line 618 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data88_ = NULL;
#line 5925 "wizard.c"
}


void boxes_wizard_open_with_uri (BoxesWizard* self, const gchar* uri, gboolean skip_review_for_live) {
	BoxesAppWindow* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	BoxesWizardSource* _tmp2_ = NULL;
	BoxesWizardSource* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
#line 646 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 646 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (uri != NULL);
#line 647 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->window;
#line 647 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_ui_set_state ((BoxesUI*) _tmp0_, BOXES_UI_STATE_WIZARD);
#line 648 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = skip_review_for_live;
#line 648 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->skip_review_for_live = _tmp1_;
#line 650 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_page (self, BOXES_WIZARD_PAGE_SOURCE);
#line 651 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = self->priv->wizard_source;
#line 651 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_source_set_page (_tmp2_, BOXES_SOURCE_PAGE_URL);
#line 652 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = self->priv->wizard_source;
#line 652 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = uri;
#line 652 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_source_set_uri (_tmp3_, _tmp4_);
#line 653 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_page (self, BOXES_WIZARD_PAGE_PREPARATION);
#line 5961 "wizard.c"
}


static void boxes_wizard_ui_state_changed (BoxesWizard* self) {
	BoxesUIState _tmp0_ = 0;
	BoxesUIState _tmp1_ = 0;
	BoxesUIState _tmp2_ = 0;
	BoxesUIState _tmp3_ = 0;
#line 656 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 657 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 657 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = _tmp0_;
#line 657 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp1_ != BOXES_UI_STATE_WIZARD) {
#line 658 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		return;
#line 5980 "wizard.c"
	}
#line 660 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = boxes_ui_get_previous_ui_state ((BoxesUI*) self);
#line 660 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = _tmp2_;
#line 660 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp3_ == BOXES_UI_STATE_PROPERTIES) {
#line 661 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_review (self, NULL, NULL);
#line 5990 "wizard.c"
	} else {
		BoxesWizardSource* _tmp4_ = NULL;
		BoxesWizardSource* _tmp5_ = NULL;
#line 663 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp4_ = self->priv->wizard_source;
#line 663 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_source_set_uri (_tmp4_, "");
#line 664 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp5_ = self->priv->wizard_source;
#line 664 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp5_->libvirt_sys_import = FALSE;
#line 665 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_page (self, BOXES_WIZARD_PAGE_INTRODUCTION);
#line 6004 "wizard.c"
	}
}


static void boxes_wizard_destroy_machine (BoxesWizard* self) {
	GCancellable* _tmp0_ = NULL;
	BoxesMachine* _tmp2_ = NULL;
#line 669 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 670 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->review_cancellable;
#line 670 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp0_ != NULL) {
#line 6018 "wizard.c"
		GCancellable* _tmp1_ = NULL;
#line 671 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp1_ = self->priv->review_cancellable;
#line 671 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_cancellable_cancel (_tmp1_);
#line 6024 "wizard.c"
	}
#line 673 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = self->priv->_machine;
#line 673 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp2_ != NULL) {
#line 6030 "wizard.c"
		BoxesApp* _tmp3_ = NULL;
		BoxesMachine* _tmp4_ = NULL;
#line 674 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp3_ = boxes_app_app;
#line 674 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp4_ = self->priv->_machine;
#line 674 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_app_delete_machine (_tmp3_, _tmp4_, TRUE);
#line 675 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_machine (self, NULL);
#line 6041 "wizard.c"
	}
}


BoxesWizard* boxes_wizard_construct (GType object_type) {
	BoxesWizard * self = NULL;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = (BoxesWizard*) g_object_new (object_type, NULL);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return self;
#line 6052 "wizard.c"
}


BoxesWizard* boxes_wizard_new (void) {
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return boxes_wizard_construct (BOXES_TYPE_WIZARD);
#line 6059 "wizard.c"
}


static BoxesUIState boxes_wizard_real_get_previous_ui_state (BoxesUI* base) {
	BoxesUIState result;
	BoxesWizard* self;
	BoxesUIState _tmp0_ = 0;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = (BoxesWizard*) base;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->_previous_ui_state;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	result = _tmp0_;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return result;
#line 6075 "wizard.c"
}


static void boxes_wizard_real_set_previous_ui_state (BoxesUI* base, BoxesUIState value) {
	BoxesWizard* self;
	BoxesUIState _tmp0_ = 0;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = (BoxesWizard*) base;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = value;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->_previous_ui_state = _tmp0_;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_notify ((GObject *) self, "previous-ui-state");
#line 6090 "wizard.c"
}


static BoxesUIState boxes_wizard_real_get_ui_state (BoxesUI* base) {
	BoxesUIState result;
	BoxesWizard* self;
	BoxesUIState _tmp0_ = 0;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = (BoxesWizard*) base;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->_ui_state;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	result = _tmp0_;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return result;
#line 6106 "wizard.c"
}


static void boxes_wizard_real_set_ui_state (BoxesUI* base, BoxesUIState value) {
	BoxesWizard* self;
	BoxesUIState _tmp0_ = 0;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = (BoxesWizard*) base;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = value;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->_ui_state = _tmp0_;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_notify ((GObject *) self, "ui-state");
#line 6121 "wizard.c"
}


BoxesMachine* boxes_wizard_get_machine (BoxesWizard* self) {
	BoxesMachine* result;
	BoxesMachine* _tmp0_ = NULL;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->_machine;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	result = _tmp0_;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return result;
#line 6136 "wizard.c"
}


void boxes_wizard_set_machine (BoxesWizard* self, BoxesMachine* value) {
	BoxesMachine* _tmp0_ = NULL;
	BoxesMachine* _tmp1_ = NULL;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = value;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->_machine);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->_machine = _tmp1_;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_notify ((GObject *) self, "machine");
#line 6155 "wizard.c"
}


static BoxesLibvirtMachine* boxes_wizard_get_libvirt_machine (BoxesWizard* self) {
	BoxesLibvirtMachine* result;
	BoxesMachine* _tmp0_ = NULL;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->_machine;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	result = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, BOXES_TYPE_LIBVIRT_MACHINE) ? ((BoxesLibvirtMachine*) _tmp0_) : NULL;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return result;
#line 6170 "wizard.c"
}


BoxesWizardPage boxes_wizard_get_page (BoxesWizard* self) {
	BoxesWizardPage result;
	BoxesWizardPage _tmp0_ = 0;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->_page;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	result = _tmp0_;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return result;
#line 6185 "wizard.c"
}


static void _boxes_wizard_page_____lambda176_ (BoxesWizard* self, GObject* obj, GAsyncResult* _result_) {
	GtkButton* _tmp0_ = NULL;
	GtkButton* _tmp1_ = NULL;
	GAsyncResult* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (_result_ != NULL);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->next_button;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, TRUE);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->create_button;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_grab_focus ((GtkWidget*) _tmp1_);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = _result_;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = boxes_wizard_review_finish (self, _tmp2_);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (!_tmp3_) {
#line 6210 "wizard.c"
		BoxesWizardPage _tmp4_ = 0;
		BoxesWizardPage _tmp5_ = 0;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp4_ = boxes_wizard_get_page (self);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp5_ = _tmp4_;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_page (self, _tmp5_ - 1);
#line 6219 "wizard.c"
	}
}


static void __boxes_wizard_page_____lambda176__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_boxes_wizard_page_____lambda176_ ((BoxesWizard*) self, source_object, res);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_unref (self);
#line 6229 "wizard.c"
}


static void _boxes_wizard_page_____lambda178_ (BoxesWizard* self, GObject* obj, GAsyncResult* _result_) {
	GAsyncResult* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (_result_ != NULL);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = _result_;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = boxes_wizard_create_finish (self, _tmp0_);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp1_) {
#line 6244 "wizard.c"
		BoxesAppWindow* _tmp2_ = NULL;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp2_ = self->priv->window;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_ui_set_state ((BoxesUI*) _tmp2_, BOXES_UI_STATE_COLLECTION);
#line 6250 "wizard.c"
	} else {
		BoxesAppWindow* _tmp3_ = NULL;
		BoxesNotificationbar* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		GdNotification* _tmp6_ = NULL;
		GdNotification* _tmp7_ = NULL;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp3_ = self->priv->window;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp4_ = _tmp3_->notificationbar;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp5_ = _ ("Box creation failed");
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp6_ = boxes_notificationbar_display_error (_tmp4_, _tmp5_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp7_ = _tmp6_;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_tmp7_);
#line 6269 "wizard.c"
	}
}


static void __boxes_wizard_page_____lambda178__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_boxes_wizard_page_____lambda178_ ((BoxesWizard*) self, source_object, res);
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_unref (self);
#line 6279 "wizard.c"
}


static void boxes_wizard_set_page (BoxesWizard* self, BoxesWizardPage value) {
	GtkButton* _tmp0_ = NULL;
	BoxesWizardPage _tmp1_ = 0;
	gboolean forwards = FALSE;
	BoxesWizardPage _tmp2_ = 0;
	BoxesWizardPage _tmp3_ = 0;
	BoxesWizardPage _tmp4_ = 0;
	BoxesWizardPage _tmp5_ = 0;
	gboolean _tmp16_ = FALSE;
	BoxesWizardPage _tmp35_ = 0;
	gboolean _tmp36_ = FALSE;
	BoxesWizardPage _tmp37_ = 0;
	BoxesAppWindow* _tmp38_ = NULL;
	BoxesSidebar* _tmp39_ = NULL;
	BoxesWizardSidebar* _tmp40_ = NULL;
	BoxesWizardPage _tmp41_ = 0;
	BoxesWizardPage _tmp42_ = 0;
	const gchar* _tmp43_ = NULL;
	BoxesWizardPage _tmp44_ = 0;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->back_button;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = value;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, _tmp1_ != BOXES_WIZARD_PAGE_INTRODUCTION);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = value;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = boxes_wizard_get_page (self);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = _tmp3_;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	forwards = _tmp2_ > _tmp4_;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp5_ = value;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	switch (_tmp5_) {
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_PAGE_INTRODUCTION:
#line 6324 "wizard.c"
		{
			GtkButton* _tmp6_ = NULL;
			GtkButton* _tmp7_ = NULL;
			GtkButton* _tmp8_ = NULL;
			GtkButton* _tmp9_ = NULL;
			GtkButton* _tmp10_ = NULL;
			GtkButton* _tmp11_ = NULL;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp6_ = self->priv->create_button;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			gtk_widget_set_visible ((GtkWidget*) _tmp6_, FALSE);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp7_ = self->priv->continue_button;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			gtk_widget_set_visible ((GtkWidget*) _tmp7_, TRUE);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp8_ = self->priv->continue_button;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp9_ = _g_object_ref0 (_tmp8_);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_object_unref0 (self->priv->next_button);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			self->priv->next_button = _tmp9_;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp10_ = self->priv->next_button;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			gtk_widget_set_sensitive ((GtkWidget*) _tmp10_, TRUE);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp11_ = self->priv->next_button;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			gtk_widget_grab_focus ((GtkWidget*) _tmp11_);
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			break;
#line 6358 "wizard.c"
		}
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_PAGE_SOURCE:
#line 6362 "wizard.c"
		{
			BoxesWizardSource* _tmp12_ = NULL;
			BoxesWizardSource* _tmp13_ = NULL;
			BoxesSourcePage _tmp14_ = 0;
			BoxesSourcePage _tmp15_ = 0;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp12_ = self->priv->wizard_source;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp13_ = self->priv->wizard_source;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp14_ = boxes_wizard_source_get_page (_tmp13_);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp15_ = _tmp14_;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			boxes_wizard_source_set_page (_tmp12_, _tmp15_);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			boxes_wizard_cleanup (self);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			break;
#line 6382 "wizard.c"
		}
		default:
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		break;
#line 6387 "wizard.c"
	}
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp16_ = forwards;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp16_) {
#line 6393 "wizard.c"
		BoxesWizardPage _tmp17_ = 0;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp17_ = value;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		switch (_tmp17_) {
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			case BOXES_WIZARD_PAGE_SOURCE:
#line 6401 "wizard.c"
			{
				BoxesWizardSource* _tmp18_ = NULL;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp18_ = self->priv->wizard_source;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_wizard_source_set_page (_tmp18_, BOXES_SOURCE_PAGE_MAIN);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				break;
#line 6410 "wizard.c"
			}
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			case BOXES_WIZARD_PAGE_PREPARATION:
#line 6414 "wizard.c"
			{
				BoxesActivityProgress* _tmp19_ = NULL;
				BoxesActivityProgress* _tmp20_ = NULL;
				gboolean _tmp21_ = FALSE;
				gboolean _tmp22_ = FALSE;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp19_ = boxes_wizard_create_preparation_progress (self);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp20_ = _tmp19_;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp21_ = boxes_wizard_prepare (self, _tmp20_);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp22_ = !_tmp21_;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (_tmp20_);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (_tmp22_) {
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					return;
#line 6434 "wizard.c"
				}
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				break;
#line 6438 "wizard.c"
			}
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			case BOXES_WIZARD_PAGE_SETUP:
#line 6442 "wizard.c"
			{
				gboolean _tmp23_ = FALSE;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp23_ = boxes_wizard_setup (self);
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (!_tmp23_) {
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					return;
#line 6451 "wizard.c"
				}
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				break;
#line 6455 "wizard.c"
			}
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			case BOXES_WIZARD_PAGE_REVIEW:
#line 6459 "wizard.c"
			{
				GtkButton* _tmp24_ = NULL;
				GtkButton* _tmp25_ = NULL;
				GtkButton* _tmp26_ = NULL;
				GtkButton* _tmp27_ = NULL;
				GtkButton* _tmp28_ = NULL;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp24_ = self->priv->continue_button;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				gtk_widget_set_visible ((GtkWidget*) _tmp24_, FALSE);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp25_ = self->priv->create_button;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				gtk_widget_set_visible ((GtkWidget*) _tmp25_, TRUE);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp26_ = self->priv->create_button;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp27_ = _g_object_ref0 (_tmp26_);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (self->priv->next_button);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				self->priv->next_button = _tmp27_;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp28_ = self->priv->next_button;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				gtk_widget_set_sensitive ((GtkWidget*) _tmp28_, FALSE);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_wizard_review (self, __boxes_wizard_page_____lambda176__gasync_ready_callback, g_object_ref (self));
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				break;
#line 6490 "wizard.c"
			}
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			case BOXES_WIZARD_PAGE_LAST:
#line 6494 "wizard.c"
			{
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_wizard_create (self, __boxes_wizard_page_____lambda178__gasync_ready_callback, g_object_ref (self));
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				return;
#line 6500 "wizard.c"
			}
			default:
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			break;
#line 6505 "wizard.c"
		}
	} else {
		BoxesWizardPage _tmp29_ = 0;
		BoxesWizardPage _tmp30_ = 0;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp29_ = boxes_wizard_get_page (self);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp30_ = _tmp29_;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		switch (_tmp30_) {
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			case BOXES_WIZARD_PAGE_REVIEW:
#line 6518 "wizard.c"
			{
				GtkButton* _tmp31_ = NULL;
				GtkButton* _tmp32_ = NULL;
				GtkButton* _tmp33_ = NULL;
				GtkButton* _tmp34_ = NULL;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp31_ = self->priv->create_button;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				gtk_widget_set_visible ((GtkWidget*) _tmp31_, FALSE);
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp32_ = self->priv->continue_button;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				gtk_widget_set_visible ((GtkWidget*) _tmp32_, TRUE);
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp33_ = self->priv->continue_button;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp34_ = _g_object_ref0 (_tmp33_);
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (self->priv->next_button);
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				self->priv->next_button = _tmp34_;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_wizard_destroy_machine (self);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				break;
#line 6544 "wizard.c"
			}
			default:
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			break;
#line 6549 "wizard.c"
		}
	}
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp35_ = value;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp36_ = boxes_wizard_skip_page (self, _tmp35_);
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp36_) {
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		return;
#line 6560 "wizard.c"
	}
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp37_ = value;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->_page = _tmp37_;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp38_ = self->priv->window;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp39_ = _tmp38_->sidebar;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp40_ = _tmp39_->wizard_sidebar;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp41_ = value;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_sidebar_set_page (_tmp40_, _tmp41_);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp42_ = value;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp43_ = BOXES_WIZARD_page_names[_tmp42_];
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_stack_set_visible_child_name ((GtkStack*) self, _tmp43_);
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp44_ = value;
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp44_ == BOXES_WIZARD_PAGE_SOURCE) {
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_wizard_source_update_next (self);
#line 6588 "wizard.c"
	}
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_notify ((GObject *) self, "page");
#line 6592 "wizard.c"
}


static void _boxes_wizard_wizard_source_update_next_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_wizard_source_update_next ((BoxesWizard*) self);
#line 6599 "wizard.c"
}


static void _boxes_wizard_wizard_source_update_next_gtk_editable_changed (GtkEditable* _sender, gpointer self) {
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_wizard_source_update_next ((BoxesWizard*) self);
#line 6606 "wizard.c"
}


static void _boxes_wizard_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_ui_state_changed ((BoxesWizard*) self);
#line 6613 "wizard.c"
}


static void _boxes_wizard___lambda183_ (BoxesWizard* self) {
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_page (self, BOXES_WIZARD_PAGE_PREPARATION);
#line 6620 "wizard.c"
}


static void __boxes_wizard___lambda183__boxes_wizard_source_activated (BoxesWizardSource* _sender, gpointer self) {
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_boxes_wizard___lambda183_ ((BoxesWizard*) self);
#line 6627 "wizard.c"
}


static GObject * boxes_wizard_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesWizard * self;
	BoxesMediaManager* _tmp0_ = NULL;
	BoxesWizardSource* _tmp1_ = NULL;
	BoxesWizardSource* _tmp2_ = NULL;
	BoxesWizardSource* _tmp3_ = NULL;
	GtkEntry* _tmp4_ = NULL;
	BoxesWizardSource* _tmp5_ = NULL;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	parent_class = G_OBJECT_CLASS (boxes_wizard_parent_class);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIZARD, BoxesWizard);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = boxes_media_manager_get_instance ();
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->media_manager);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->media_manager = _tmp0_;
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->wizard_source;
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_signal_connect_object ((GObject*) _tmp1_, "notify::page", (GCallback) _boxes_wizard_wizard_source_update_next_g_object_notify, self, 0);
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = self->priv->wizard_source;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_signal_connect_object ((GObject*) _tmp2_, "notify::selected", (GCallback) _boxes_wizard_wizard_source_update_next_g_object_notify, self, 0);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = self->priv->wizard_source;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = _tmp3_->url_entry;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_signal_connect_object ((GtkEditable*) _tmp4_, "changed", (GCallback) _boxes_wizard_wizard_source_update_next_gtk_editable_changed, self, 0);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_signal_connect_object ((GObject*) self, "notify::ui-state", (GCallback) _boxes_wizard_ui_state_changed_g_object_notify, self, 0);
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp5_ = self->priv->wizard_source;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_signal_connect_object (_tmp5_, "activated", (GCallback) __boxes_wizard___lambda183__boxes_wizard_source_activated, self, 0);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_stack_set_transition_type ((GtkStack*) self, GTK_STACK_TRANSITION_TYPE_SLIDE_LEFT_RIGHT);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return obj;
#line 6677 "wizard.c"
}


static void boxes_wizard_class_init (BoxesWizardClass * klass) {
	gint BoxesWizard_private_offset;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_parent_class = g_type_class_peek_parent (klass);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_type_class_add_private (klass, sizeof (BoxesWizardPrivate));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_wizard_get_property;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_wizard_set_property;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_wizard_constructor;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_wizard_finalize;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_PREVIOUS_UI_STATE, g_param_spec_enum ("previous-ui-state", "previous-ui-state", "previous-ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_UI_STATE, g_param_spec_enum ("ui-state", "ui-state", "ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_MACHINE, g_param_spec_object ("machine", "machine", "machine", BOXES_TYPE_MACHINE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_PAGE, g_param_spec_enum ("page", "page", "page", BOXES_TYPE_WIZARD_PAGE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	BoxesWizard_private_offset = g_type_class_get_instance_private_offset (klass);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/wizard.ui");
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "wizard_source", FALSE, BoxesWizard_private_offset + G_STRUCT_OFFSET (BoxesWizardPrivate, wizard_source));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "summary", FALSE, BoxesWizard_private_offset + G_STRUCT_OFFSET (BoxesWizardPrivate, summary));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "prep_progress", FALSE, BoxesWizard_private_offset + G_STRUCT_OFFSET (BoxesWizardPrivate, prep_progress));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "prep_media_label", FALSE, BoxesWizard_private_offset + G_STRUCT_OFFSET (BoxesWizardPrivate, prep_media_label));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "prep_status_label", FALSE, BoxesWizard_private_offset + G_STRUCT_OFFSET (BoxesWizardPrivate, prep_status_label));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "setup_box", FALSE, BoxesWizard_private_offset + G_STRUCT_OFFSET (BoxesWizardPrivate, setup_box));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "review_label", FALSE, BoxesWizard_private_offset + G_STRUCT_OFFSET (BoxesWizardPrivate, review_label));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "nokvm_infobar", FALSE, BoxesWizard_private_offset + G_STRUCT_OFFSET (BoxesWizardPrivate, nokvm_infobar));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "installer_image", FALSE, BoxesWizard_private_offset + G_STRUCT_OFFSET (BoxesWizardPrivate, installer_image));
#line 6725 "wizard.c"
}


static void boxes_wizard_boxes_ui_interface_init (BoxesUIIface * iface) {
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_boxes_ui_parent_iface = g_type_interface_peek_parent (iface);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	iface->get_previous_ui_state = boxes_wizard_real_get_previous_ui_state;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	iface->set_previous_ui_state = boxes_wizard_real_set_previous_ui_state;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	iface->get_ui_state = boxes_wizard_real_get_ui_state;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	iface->set_ui_state = boxes_wizard_real_set_ui_state;
#line 6740 "wizard.c"
}


static void boxes_wizard_instance_init (BoxesWizard * self) {
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv = BOXES_WIZARD_GET_PRIVATE (self);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_type_ensure (BOXES_TYPE_WIZARD_SUMMARY);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_type_ensure (BOXES_TYPE_WIZARD_SOURCE);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 6753 "wizard.c"
}


static void boxes_wizard_finalize (GObject* obj) {
	BoxesWizard * self;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIZARD, BoxesWizard);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->cancel_button);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->back_button);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->next_button);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->continue_button);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->create_button);
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->source);
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->wizard_source);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->summary);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->prep_progress);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->prep_media_label);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->prep_status_label);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->setup_box);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->review_label);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->nokvm_infobar);
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->installer_image);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->window);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->media_manager);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_boxes_vm_creator_unref0 (self->priv->vm_creator);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->_machine);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->prepare_cancellable);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->review_cancellable);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (boxes_wizard_parent_class)->finalize (obj);
#line 6805 "wizard.c"
}


GType boxes_wizard_get_type (void) {
	static volatile gsize boxes_wizard_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_wizard_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesWizardClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_wizard_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesWizard), 0, (GInstanceInitFunc) boxes_wizard_instance_init, NULL };
		static const GInterfaceInfo boxes_ui_info = { (GInterfaceInitFunc) boxes_wizard_boxes_ui_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType boxes_wizard_type_id;
		boxes_wizard_type_id = g_type_register_static (gtk_stack_get_type (), "BoxesWizard", &g_define_type_info, 0);
		g_type_add_interface_static (boxes_wizard_type_id, BOXES_TYPE_UI, &boxes_ui_info);
		g_once_init_leave (&boxes_wizard_type_id__volatile, boxes_wizard_type_id);
	}
	return boxes_wizard_type_id__volatile;
}


static void _vala_boxes_wizard_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesWizard * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_WIZARD, BoxesWizard);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	switch (property_id) {
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_PREVIOUS_UI_STATE:
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_value_set_enum (value, boxes_ui_get_previous_ui_state ((BoxesUI*) self));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		break;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_UI_STATE:
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_value_set_enum (value, boxes_ui_get_ui_state ((BoxesUI*) self));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		break;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_MACHINE:
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_value_set_object (value, boxes_wizard_get_machine (self));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		break;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_PAGE:
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_value_set_enum (value, boxes_wizard_get_page (self));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		break;
#line 6852 "wizard.c"
		default:
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		break;
#line 6858 "wizard.c"
	}
}


static void _vala_boxes_wizard_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesWizard * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_WIZARD, BoxesWizard);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	switch (property_id) {
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_PREVIOUS_UI_STATE:
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_ui_set_previous_ui_state ((BoxesUI*) self, g_value_get_enum (value));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		break;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_UI_STATE:
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_ui_set_ui_state ((BoxesUI*) self, g_value_get_enum (value));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		break;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_MACHINE:
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_machine (self, g_value_get_object (value));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		break;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_PAGE:
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_page (self, g_value_get_enum (value));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		break;
#line 6892 "wizard.c"
		default:
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		break;
#line 6898 "wizard.c"
	}
}


void boxes_wizard_summary_add_property (BoxesWizardSummary* self, const gchar* name, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	GtkLabel* label_name = NULL;
	const gchar* _tmp1_ = NULL;
	GtkLabel* _tmp2_ = NULL;
	GtkLabel* _tmp3_ = NULL;
	GtkStyleContext* _tmp4_ = NULL;
	GtkLabel* _tmp5_ = NULL;
	GtkLabel* _tmp6_ = NULL;
	gint _tmp7_ = 0;
	GtkLabel* label_value = NULL;
	const gchar* _tmp8_ = NULL;
	GtkLabel* _tmp9_ = NULL;
	GtkLabel* _tmp10_ = NULL;
	GtkLabel* _tmp11_ = NULL;
	GtkLabel* _tmp12_ = NULL;
	GtkLabel* _tmp13_ = NULL;
	gint _tmp14_ = 0;
	gint _tmp15_ = 0;
#line 690 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 690 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (name != NULL);
#line 691 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = value;
#line 691 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp0_ == NULL) {
#line 692 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		return;
#line 6932 "wizard.c"
	}
#line 694 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = name;
#line 694 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = (GtkLabel*) gtk_label_new (_tmp1_);
#line 694 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp2_);
#line 694 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	label_name = _tmp2_;
#line 695 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = label_name;
#line 695 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = gtk_widget_get_style_context ((GtkWidget*) _tmp3_);
#line 695 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_style_context_add_class (_tmp4_, "boxes-wizard-summary-prop-name-label");
#line 696 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp5_ = label_name;
#line 696 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp5_, GTK_ALIGN_END);
#line 697 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp6_ = label_name;
#line 697 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp7_ = self->priv->current_row;
#line 697 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_grid_attach ((GtkGrid*) self, (GtkWidget*) _tmp6_, 0, _tmp7_, 1, 1);
#line 699 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp8_ = value;
#line 699 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp9_ = (GtkLabel*) gtk_label_new (_tmp8_);
#line 699 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp9_);
#line 699 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	label_value = _tmp9_;
#line 700 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp10_ = label_value;
#line 700 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_label_set_ellipsize (_tmp10_, PANGO_ELLIPSIZE_END);
#line 701 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp11_ = label_value;
#line 701 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_label_set_max_width_chars (_tmp11_, 32);
#line 702 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp12_ = label_value;
#line 702 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp12_, GTK_ALIGN_START);
#line 703 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp13_ = label_value;
#line 703 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp14_ = self->priv->current_row;
#line 703 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_grid_attach ((GtkGrid*) self, (GtkWidget*) _tmp13_, 1, _tmp14_, 1, 1);
#line 705 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp15_ = self->priv->current_row;
#line 705 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->current_row = _tmp15_ + 1;
#line 706 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_show_all ((GtkWidget*) self);
#line 690 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (label_value);
#line 690 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (label_name);
#line 6994 "wizard.c"
}


static Block89Data* block89_data_ref (Block89Data* _data89_) {
#line 709 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_atomic_int_inc (&_data89_->_ref_count_);
#line 709 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return _data89_;
#line 7003 "wizard.c"
}


static void block89_data_unref (void * _userdata_) {
	Block89Data* _data89_;
	_data89_ = (Block89Data*) _userdata_;
#line 709 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (g_atomic_int_dec_and_test (&_data89_->_ref_count_)) {
#line 7012 "wizard.c"
		BoxesWizardSummary* self;
#line 709 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		self = _data89_->self;
#line 709 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (self);
#line 709 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_slice_free (Block89Data, _data89_);
#line 7020 "wizard.c"
	}
}


static void __lambda167_ (Block89Data* _data89_) {
	BoxesWizardSummary* self;
	BoxesWizardSummaryCustomizeFunc _tmp0_ = NULL;
	void* _tmp0__target = NULL;
#line 718 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = _data89_->self;
#line 718 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = _data89_->customize_func;
#line 718 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0__target = _data89_->customize_func_target;
#line 718 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ (_tmp0__target);
#line 7037 "wizard.c"
}


static void ___lambda167__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 718 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	__lambda167_ (self);
#line 7044 "wizard.c"
}


void boxes_wizard_summary_append_customize_button (BoxesWizardSummary* self, BoxesWizardSummaryCustomizeFunc customize_func, void* customize_func_target) {
	Block89Data* _data89_;
	BoxesWizardSummaryCustomizeFunc _tmp0_ = NULL;
	void* _tmp0__target = NULL;
	gint _tmp1_ = 0;
	GtkButton* button = NULL;
	const gchar* _tmp2_ = NULL;
	GtkButton* _tmp3_ = NULL;
	GtkButton* _tmp4_ = NULL;
	gint _tmp5_ = 0;
	GtkButton* _tmp6_ = NULL;
	GtkButton* _tmp7_ = NULL;
#line 709 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 709 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data89_ = g_slice_new0 (Block89Data);
#line 709 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data89_->_ref_count_ = 1;
#line 709 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data89_->self = g_object_ref (self);
#line 709 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = customize_func;
#line 709 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0__target = customize_func_target;
#line 709 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data89_->customize_func = _tmp0_;
#line 709 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data89_->customize_func_target = _tmp0__target;
#line 711 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->current_row;
#line 711 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp1_ == 0) {
#line 712 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		block89_data_unref (_data89_);
#line 712 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data89_ = NULL;
#line 712 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		return;
#line 7086 "wizard.c"
	}
#line 714 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = _ ("C_ustomize…");
#line 714 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = (GtkButton*) gtk_button_new_with_mnemonic (_tmp2_);
#line 714 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp3_);
#line 714 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	button = _tmp3_;
#line 715 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = button;
#line 715 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp5_ = self->priv->current_row;
#line 715 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_grid_attach ((GtkGrid*) self, (GtkWidget*) _tmp4_, 2, _tmp5_ - 1, 1, 1);
#line 716 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp6_ = button;
#line 716 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_show ((GtkWidget*) _tmp6_);
#line 718 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp7_ = button;
#line 718 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_signal_connect_data (_tmp7_, "clicked", (GCallback) ___lambda167__gtk_button_clicked, block89_data_ref (_data89_), (GClosureNotify) block89_data_unref, 0);
#line 709 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (button);
#line 709 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	block89_data_unref (_data89_);
#line 709 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data89_ = NULL;
#line 7116 "wizard.c"
}


void boxes_wizard_summary_clear (BoxesWizardSummary* self) {
	GList* _tmp0_ = NULL;
#line 721 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 722 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = gtk_container_get_children ((GtkContainer*) self);
#line 7126 "wizard.c"
	{
		GList* child_collection = NULL;
		GList* child_it = NULL;
#line 722 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		child_collection = _tmp0_;
#line 722 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		for (child_it = child_collection; child_it != NULL; child_it = child_it->next) {
#line 7134 "wizard.c"
			GtkWidget* child = NULL;
#line 722 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			child = (GtkWidget*) child_it->data;
#line 7138 "wizard.c"
			{
				GtkWidget* _tmp1_ = NULL;
#line 723 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp1_ = child;
#line 723 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				gtk_container_remove ((GtkContainer*) self, _tmp1_);
#line 7145 "wizard.c"
			}
		}
#line 722 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_list_free0 (child_collection);
#line 7150 "wizard.c"
	}
#line 726 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->current_row = 0;
#line 7154 "wizard.c"
}


BoxesWizardSummary* boxes_wizard_summary_construct (GType object_type) {
	BoxesWizardSummary * self = NULL;
#line 681 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = (BoxesWizardSummary*) g_object_new (object_type, NULL);
#line 681 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return self;
#line 7164 "wizard.c"
}


BoxesWizardSummary* boxes_wizard_summary_new (void) {
#line 681 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return boxes_wizard_summary_construct (BOXES_TYPE_WIZARD_SUMMARY);
#line 7171 "wizard.c"
}


static GObject * boxes_wizard_summary_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesWizardSummary * self;
#line 686 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	parent_class = G_OBJECT_CLASS (boxes_wizard_summary_parent_class);
#line 686 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 686 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIZARD_SUMMARY, BoxesWizardSummary);
#line 687 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->current_row = 0;
#line 686 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return obj;
#line 7189 "wizard.c"
}


static void boxes_wizard_summary_class_init (BoxesWizardSummaryClass * klass) {
	gint BoxesWizardSummary_private_offset;
#line 681 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_summary_parent_class = g_type_class_peek_parent (klass);
#line 681 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_type_class_add_private (klass, sizeof (BoxesWizardSummaryPrivate));
#line 681 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_wizard_summary_constructor;
#line 681 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_wizard_summary_finalize;
#line 681 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	BoxesWizardSummary_private_offset = g_type_class_get_instance_private_offset (klass);
#line 681 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/wizard-summary.ui");
#line 7207 "wizard.c"
}


static void boxes_wizard_summary_instance_init (BoxesWizardSummary * self) {
#line 681 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv = BOXES_WIZARD_SUMMARY_GET_PRIVATE (self);
#line 681 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 7216 "wizard.c"
}


static void boxes_wizard_summary_finalize (GObject* obj) {
	BoxesWizardSummary * self;
#line 681 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIZARD_SUMMARY, BoxesWizardSummary);
#line 681 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (boxes_wizard_summary_parent_class)->finalize (obj);
#line 7226 "wizard.c"
}


GType boxes_wizard_summary_get_type (void) {
	static volatile gsize boxes_wizard_summary_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_wizard_summary_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesWizardSummaryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_wizard_summary_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesWizardSummary), 0, (GInstanceInitFunc) boxes_wizard_summary_instance_init, NULL };
		GType boxes_wizard_summary_type_id;
		boxes_wizard_summary_type_id = g_type_register_static (gtk_grid_get_type (), "BoxesWizardSummary", &g_define_type_info, 0);
		g_once_init_leave (&boxes_wizard_summary_type_id__volatile, boxes_wizard_summary_type_id);
	}
	return boxes_wizard_summary_type_id__volatile;
}



